package pstsp.functional_tests;

/**
 * Test suite where one of tests fails
 * it serves for debugging purposes only
 *
 * @author Pavel Herout
 * @version 2022-01-25
 */

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.basic.Url;
import pstsp.support.pageobjects.login.Login_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.PstspTags;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import static pstsp.support.test_utils.PstspTags.FAIL;

@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("FAIL test - for debugging purposes")
public class Fail_Test {
  static Login_Page loginPage;

  @BeforeAll
  public static void setUpBeforeAll() {
    Click.openUrlAndWait(Url.URL_LOGIN);
    loginPage = new Login_Page();
  }

  @Test
  @Order(1)
  @DisplayName("Login username placeholder")
  void placeholder() {
    String actual = loginPage.getUsernameInputPlaceholderText();
    Check.checkPlaceholder(Login_Page.TXT_USERNAME_INPUT_PLACEHOLDER, actual,
            Login_Page.USERNAME_INPUT);
  }

  @Test
  @Order(2)
  @DisplayName("Login username text - set")
  void setText() {
    loginPage.setUsername("mentor");
    String actual = loginPage.getUsername();
    Check.checkText("mentor", actual, Login_Page.USERNAME_INPUT);
  }

  @Test
  @Order(3)
  @DisplayName("Login username text - FAILS")
  @Tag(FAIL)
  void usernameEmptyText() {
    String actual = loginPage.getUsername();
    Check.checkText("Error -- for debugging only", actual, Login_Page.USERNAME_INPUT);
  }
}
