package pstsp.functional_tests.c_one_change.ts_c_01;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.login.Login_Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;
import pstsp.support.test_utils.PstspTags;

/**
 * Login page
 *
 * @author David Kuta
 * @version 2022-03-17
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ONE_CHANGE)
@Tag(PstspTags.ACTIVE)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.C.01.01: Login page")
public class TS_C_01 {


    @Order(1)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @Tag(PstspTags.UNLOGGED)
    @DisplayName("TC.C.01.01: mentor login")
    void test_1() {
        Login_Actions.loginIfNecessary("mentor");
        Login_Check.checkLoginProcess("Pan Mentor", "Mentor");
    }

    @Order(2)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @Tag(PstspTags.UNLOGGED)
    @DisplayName("TC.C.01.02: leader login")
    void test_2() {
        Login_Actions.loginIfNecessary("leader");
        Login_Check.checkLoginProcess("Pan Vedoucí", "Vedoucí");
    }

    @Order(3)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @Tag(PstspTags.UNLOGGED)
    @DisplayName("TC.C.01.03: garant login")
    void test_3() {
        Login_Actions.loginIfNecessary("garant");
        Login_Check.checkLoginProcess("Pan Garant", "Garant");
    }

    @Order(4)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @Tag(PstspTags.MENTOR)
    @DisplayName("TC.C.01.04: mentor logout")
    void test_4() {
        Login_Actions.loginIfNecessary("mentor");
        Login_Check.checkLoginProcess("Pan Mentor", "Mentor");
        Login_Actions.logoutIfPossible();
        Login_Check.checkLogoutSuccessAlert();
    }

    @Order(5)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @Tag(PstspTags.LEADER)
    @DisplayName("TC.C.01.05: leader logout")
    void test_5() {
        Login_Actions.loginIfNecessary("leader");
        Login_Check.checkLoginProcess("Pan Vedoucí", "Vedoucí");
        Login_Actions.logoutIfPossible();
        Login_Check.checkLogoutSuccessAlert();
    }

    @Order(6)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @Tag(PstspTags.GARANT)
    @DisplayName("TC.C.01.06: garant logout")
    void test_6() {
        Login_Actions.loginIfNecessary("garant");
        Login_Check.checkLoginProcess("Pan Garant", "Garant");
        Login_Actions.logoutIfPossible();
        Login_Check.checkLogoutSuccessAlert();
    }
}
