package pstsp.functional_tests.c_one_change.ts_c_02;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.login.Home_Actions;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.team.Team_Actions;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;
import pstsp.support.test_utils.PstspTags;

import java.util.HashSet;
import java.util.Set;

/**
 * Edit team members
 *
 * @author David Kuta
 * @version 2022-03-17
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ONE_CHANGE)
@Tag(PstspTags.ACTIVE)
@Tag(PstspTags.LEADER)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.C.02.02: Edit team members")
public class TS_C_02_02 {

    @BeforeAll
    public static void setup() {
        Home_Actions.resetDB();
    }

    @AfterAll
    public static void tearDownAfterAll() {
        Login_Actions.logoutIfPossible();
    }

    @Order(1)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.02.01: add one member")
    void test_1() {
        Set<String> expected = new HashSet<>();
        expected.add("Jakub ŠMRHA (A19B0206P)");
        Team_Actions.editTeamMembersAsLeaderSuccess(expected,"leader");
    }

    @Order(2)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.02.02: remove one member")
    void test_2() {
        Set<String> expected = new HashSet<>();
        Team_Actions.editTeamMembersAsLeaderSuccess(expected,"leader");
    }

    @Order(3)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.02.03: add two members")
    void test_3() {
        Set<String> expected = new HashSet<>();
        expected.add("Jakub ŠMRHA (A19B0206P)");
        expected.add("Radek ŠVAMBERG (A19B0211P)");
        Team_Actions.editTeamMembersAsLeaderSuccess(expected,"leader");
    }

    @Order(4)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.C.02.02.04: remove one member from two")
    void test_4() {
        Set<String> expected = new HashSet<>();
        expected.add("Jakub ŠMRHA (A19B0206P)");
        Team_Actions.editTeamMembersAsLeaderSuccess(expected,"leader");
    }

    @Order(5)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.02.05: add 6 members")
    void test_5() {
        Set<String> expected = new HashSet<>();
        expected.add("Jan PELIKÁN (A19B0157P)");
        expected.add("Josef OUŘEDNÍK (A19B0153P)");
        expected.add("David MORÁVEK (A19B0141P)");
        expected.add("Radomír KESL (A19B0088P)");
        expected.add("Jakub ŠMRHA (A19B0206P)");
        expected.add("Radek ŠVAMBERG (A19B0211P)");
        Team_Actions.editTeamMembersAsLeaderSuccess(expected,"leader");
    }

    @Order(6)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.02.06: remove half members")
    void test_6() {
        Set<String> expected = new HashSet<>();
        expected.add("Radomír KESL (A19B0088P)");
        expected.add("Jakub ŠMRHA (A19B0206P)");
        expected.add("Radek ŠVAMBERG (A19B0211P)");
        Team_Actions.editTeamMembersAsLeaderSuccess(expected,"leader");
    }

    @Order(7)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.02.07: add 10 members")
    void test_7() {
        Set<String> expected = new HashSet<>();
        expected.add("Jan PELIKÁN (A19B0157P)");
        expected.add("Josef OUŘEDNÍK (A19B0153P)");
        expected.add("David MORÁVEK (A19B0141P)");
        expected.add("Radomír KESL (A19B0088P)");
        expected.add("Jakub ŠMRHA (A19B0206P)");
        expected.add("Radek ŠVAMBERG (A19B0211P)");
        expected.add("Dominik JEŽ (A19B0078P)");
        expected.add("Martin JAKUBAŠEK (A19B0069P)");
        expected.add("Václav HRABÍK (A19B0061P)");
        expected.add("Matěj HOLUBEC (A20B0104P)");
        Team_Actions.editTeamMembersAsLeaderSuccess(expected,"leader");
    }

    @Order(8)
    @Test
    @Tag(PstspTags.IMP_MINOR)
    @DisplayName("TC.C.02.02.08: remove all members")
    void test_8() {
        Set<String> expected = new HashSet<>();
        Team_Actions.editTeamMembersAsLeaderSuccess(expected,"leader");
    }




}
