package pstsp.functional_tests.c_one_change.ts_c_02;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.team.Team_Actions;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;
import pstsp.support.test_utils.PstspTags;

import java.util.HashSet;
import java.util.Set;

/**
 * Team member roles
 *
 * @author David Kuta
 * @version 2022-03-17
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ONE_CHANGE)
@Tag(PstspTags.ACTIVE)
@Tag(PstspTags.LEADER)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.C.02.04: Edit team member roles")
public class TS_C_02_04 {

    @AfterAll
    public static void tearDownAfterAll() {
        Login_Actions.logoutIfPossible();
    }

    @Order(1)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.04.01: one role - leader")
    void test_1() {
        String student = "Jan KUBALA (A19B0113P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Programátor");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(2)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.C.02.04.02: two roles - leader")
    void test_2() {
        String student = "Jan KUBALA (A19B0113P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Programátor");
        expectedRoles.add("Tester");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(3)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @Tag(PstspTags.BOUNDARY)
    @DisplayName("TC.C.02.04.03: three roles - leader")
    void test_3() {
        String student = "Jan KUBALA (A19B0113P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Programátor");
        expectedRoles.add("Tester");
        expectedRoles.add("Grafik");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(4)
    @Test
    @Tag(PstspTags.IMP_MINOR)
    @DisplayName("TC.C.02.04.04: no next role - leader")
    void test_4() {
        String student = "Jan KUBALA (A19B0113P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Programátor");
        expectedRoles.add("Tester");
        expectedRoles.add("Grafik");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(5)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.04.05: remove roles - leader")
    void test_5() {
        String student = "Jan KUBALA (A19B0113P)";
        Set<String> expectedRoles = new HashSet<>();
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(6)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.04.06: one role - other")
    void test_6() {
        String student = "Jan KUBICE (A19B0114P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Grafik");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(7)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.C.02.04.07: two roles - other")
    void test_7() {
        String student = "Jan KUBICE (A19B0114P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Grafik");
        expectedRoles.add("Designer");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(8)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @Tag(PstspTags.BOUNDARY)
    @DisplayName("TC.C.02.04.08: three roles - other")
    void test_8() {
        String student = "Jan KUBICE (A19B0114P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Grafik");
        expectedRoles.add("Designer");
        expectedRoles.add("Dokumentarista");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(9)
    @Test
    @Tag(PstspTags.IMP_MINOR)
    @DisplayName("TC.C.02.04.09: no next role - other")
    void test_9() {
        String student = "Jan KUBICE (A19B0114P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Grafik");
        expectedRoles.add("Designer");
        expectedRoles.add("Dokumentarista");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(10)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.04.10: remove roles - other")
    void test_10() {
        String student = "Jan KUBICE (A19B0114P)";
        Set<String> expectedRoles = new HashSet<>();
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"kubala");
    }

    @Order(11)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.04.11: one role - leader with incomplete team")
    void test_11() {
        String student = "Hana HRKALOVÁ (A19B0064P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Dokumentarista");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"stricz");
    }

    @Order(12)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.C.02.04.12: two roles - leader with incomplete team")
    void test_12() {
        String student = "Hana HRKALOVÁ (A19B0064P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Dokumentarista");
        expectedRoles.add("Designer");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"stricz");
    }

    @Order(13)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @Tag(PstspTags.BOUNDARY)
    @DisplayName("TC.C.02.04.13: three roles - leader with incomplete team")
    void test_13() {
        String student = "Hana HRKALOVÁ (A19B0064P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Dokumentarista");
        expectedRoles.add("Designer");
        expectedRoles.add("Tester");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"stricz");
    }

    @Order(14)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @Tag(PstspTags.BOUNDARY)
    @DisplayName("TC.C.02.04.14: three roles - leader with incomplete team other student")
    void test_14() {
        String student = "Patrik ŠTRICZ (A19B0207P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Dokumentarista");
        expectedRoles.add("Designer");
        expectedRoles.add("Tester");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"stricz");
    }

    @Order(15)
    @Test
    @Tag(PstspTags.IMP_MINOR)
    @DisplayName("TC.C.02.04.15: no next roles - leader with incomplete team")
    void test_15() {
        String student = "Hana HRKALOVÁ (A19B0064P)";
        Set<String> expectedRoles = new HashSet<>();
        expectedRoles.add("Dokumentarista");
        expectedRoles.add("Designer");
        expectedRoles.add("Tester");
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"stricz");
    }

    @Order(16)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.04.16: remove roles - leader with incomplete team")
    void test_16() {
        String student = "Hana HRKALOVÁ (A19B0064P)";
        Set<String> expectedRoles = new HashSet<>();
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"stricz");
    }




}
