package pstsp.functional_tests.c_one_change.ts_c_02;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.team.Team_Actions;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;
import pstsp.support.test_utils.PstspTags;

import java.util.HashSet;
import java.util.Set;

/**
 * Edit team profile
 *
 * @author David Kuta
 * @version 2022-03-17
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ONE_CHANGE)
@Tag(PstspTags.ACTIVE)
@Tag(PstspTags.LEADER)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.C.02.06: Edit team profile")
public class TS_C_02_06 {

    @AfterAll
    public static void tearDownAfterAll() {
        Login_Actions.logoutIfPossible();
    }

    @Order(1)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.06.01: add one profile")
    void test_1() {
        Set<String> expectedProfile = new HashSet<>();
        expectedProfile.add("PHP");
        Team_Actions.setTeamProfileAsLeaderSuccess(expectedProfile,"leader");
    }

    @Order(2)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.C.02.06.02: remove three profiles")
    void test_2() {
        Set<String> expectedProfile = new HashSet<>();
        expectedProfile.add("PHP");
        expectedProfile.add("Frontend");
        expectedProfile.add("JavaScript");;
        Team_Actions.setTeamProfileAsLeaderSuccess(expectedProfile,"leader");
    }

    @Order(3)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.06.03: remove one profile")
    void test_3() {
        Set<String> expectedProfile = new HashSet<>();
        expectedProfile.add("Frontend");
        expectedProfile.add("JavaScript");
        Team_Actions.setTeamProfileAsLeaderSuccess(expectedProfile,"leader");
    }

    @Order(4)
    @Test
    @Tag(PstspTags.IMP_MINOR)
    @Tag(PstspTags.BOUNDARY)
    @DisplayName("TC.C.02.06.04: add 8 profiles")
    void test_4() {
        Set<String> expectedProfile = new HashSet<>();
        expectedProfile.add("PHP");
        expectedProfile.add("Frontend");
        expectedProfile.add("JavaScript");
        expectedProfile.add("Backend");
        expectedProfile.add("C");
        expectedProfile.add("C#");
        expectedProfile.add("Java");
        expectedProfile.add("C++");
        Team_Actions.setTeamProfileAsLeaderSuccess(expectedProfile,"leader");
    }

    @Order(5)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.C.02.06.05: remove three profiles")
    void test_5() {
        Set<String> expectedProfile = new HashSet<>();
        expectedProfile.add("PHP");
        expectedProfile.add("Frontend");
        expectedProfile.add("JavaScript");
        expectedProfile.add("Backend");
        expectedProfile.add("C");
        Team_Actions.setTeamProfileAsLeaderSuccess(expectedProfile,"leader");
    }

    @Order(6)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.02.06.06: remove all profiles")
    void test_6() {
        Set<String> expectedProfile = new HashSet<>();
        Team_Actions.setTeamProfileAsLeaderSuccess(expectedProfile,"leader");
    }




}
