package pstsp.functional_tests.c_one_change.ts_c_04;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.project.Project_Leader_Actions;
import pstsp.support.test_utils.PstspTags;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.ArrayList;
import java.util.List;

/**
 * edit project links
 *
 * @author David Kuta
 * @version 2022-03-25
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ONE_CHANGE)
@Tag(PstspTags.ACTIVE)
@Tag(PstspTags.LEADER)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.C.04.04: edit project links")
public class TS_C_04_04 {

    @AfterAll
    public static void tearDownAfterAll() {
        Login_Actions.logoutIfPossible();
    }

    @Order(1)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.04.04.01: add storage")
    void test_1() {
        String storage = "https://www.seznam.cz/";
        String management = "";
        String production = "";
        List<String> other = new ArrayList<>();
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(2)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.04.04.02: add management")
    void test_2() {
        String storage = "https://www.seznam.cz/";
        String management = "https://www.github.com/";
        String production = "";
        List<String> other = new ArrayList<>();
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(3)
    @Test
    @Tag(PstspTags.IMP_CRITICAL)
    @DisplayName("TC.C.04.04.03: add production")
    void test_3() {
        String storage = "https://www.seznam.cz/";
        String management = "https://www.github.com/";
        String production = "https://www.guthib.com/";
        List<String> other = new ArrayList<>();
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(4)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.C.04.04.04: remove management")
    void test_4() {
        String storage = "https://www.seznam.cz/";
        String management = "";
        String production = "https://www.guthib.com/";
        List<String> other = new ArrayList<>();
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(5)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.C.04.04.05: remove storage")
    void test_5() {
        String storage = "";
        String management = "";
        String production = "https://www.guthib.com/";
        List<String> other = new ArrayList<>();
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(6)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.C.04.04.06: remove production")
    void test_6() {
        String storage = "";
        String management = "";
        String production = "";
        List<String> other = new ArrayList<>();
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(7)
    @Test
    @Tag(PstspTags.IMP_MINOR)
    @DisplayName("TC.C.04.04.07: add one other link")
    void test_7() {
        String storage = "";
        String management = "";
        String production = "";
        List<String> other = new ArrayList<>();
        other.add("GG;https://www.google.com/");

        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(8)
    @Test
    @Tag(PstspTags.IMP_MINOR)
    @DisplayName("TC.C.04.04.08: add 2 other links")
    void test_8() {
        String storage = "";
        String management = "";
        String production = "";
        List<String> other = new ArrayList<>();
        other.add("GG;https://www.google.com/");
        other.add("PORTAL;https://www.portal.zcu.cz/");
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(9)
    @Test
    @Tag(PstspTags.IMP_MINOR)
    @Tag(PstspTags.BOUNDARY)
    @DisplayName("TC.C.04.04.09: 10 other links")
    void test_9() {
        String storage = "https://www.seznam.cz/";
        String management = "https://www.github.com/";
        String production = "https://www.guthib.com/";
        List<String> other = new ArrayList<>();
        other.add("GG;https://www.google.com/");
        other.add("PORTAL;https://www.portal.zcu.cz/");
        other.add("PSTaP;https://www.pstsp.hintak.cz/");
        other.add("Go;https://www.go.com/");
        other.add("IDNES;https://www.idnes.cz/");
        other.add("SNAKE;https://www.snake.com/");
        other.add("PACMAN;https://www.pacman.com/");
        other.add("JeTbRaInS;https://www.jetbrains.com/");
        other.add("eclipse;https://www.eclipse.com/");
        other.add("CI/CD;https://www.continuousintegration.com/");
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(10)
    @Test
    @Tag(PstspTags.IMP_MINOR)
    @DisplayName("TC.C.04.04.10: remove one other link")
    void test_10() {
        String storage = "https://www.seznam.cz/";
        String management = "https://www.github.com/";
        String production = "https://www.guthib.com/";
        List<String> other = new ArrayList<>();
        other.add("PORTAL;https://www.portal.zcu.cz/");
        other.add("PSTaP;https://www.pstsp.hintak.cz/");
        other.add("Go;https://www.go.com/");
        other.add("IDNES;https://www.idnes.cz/");
        other.add("SNAKE;https://www.snake.com/");
        other.add("PACMAN;https://www.pacman.com/");
        other.add("JeTbRaInS;https://www.jetbrains.com/");
        other.add("eclipse;https://www.eclipse.com/");
        other.add("CI/CD;https://www.continuousintegration.com/");
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }

    @Order(11)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @Tag(PstspTags.BOUNDARY)
    @DisplayName("TC.C.04.04.11: remove all links")
    void test_11() {
        String storage = "";
        String management = "";
        String production = "";
        List<String> other = new ArrayList<>();
        Project_Leader_Actions.setProjectUrls(storage,management,production,other,"leader");
    }


}
