package pstsp.functional_tests.c_one_change.ts_c_08;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.Arguments;
import org.junit.jupiter.params.provider.MethodSource;
import pstsp.support.services.assignmentswithoutteam.Assignments_Without_Team_Actions;
import pstsp.support.services.entities.storage.MentorInterrestTopicTable;
import pstsp.support.services.login.Home_Actions;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.PstspTags;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Stream;

/**
 * Mentors leader interest evaluation
 *
 * @author David Kuta
 * @version 2022-03-25
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ONE_CHANGE)
@Tag(PstspTags.ACTIVE)
@Tag(PstspTags.MENTOR)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.C.08.01.: Mentors leader interest evaluation")
public class TS_C_08_01 {

    @BeforeAll
    public static void setup() {
        Home_Actions.resetDB();
    }

    @AfterAll
    public static void tearDownAfterAll() {
        Login_Actions.logoutIfPossible();
    }

    @Order(1)
    @Tag(PstspTags.IMP_CRITICAL)
    @ParameterizedTest(name = "TC.C.08.{index}: assignmentName: {0} - teamName: {1} - choice: {2}")
    @MethodSource("streamForUsedExp")
    @DisplayName("TS.C.08.01: all evaluations on site")
    void test_1(String assignmentName, String teamName, int choice) {

        Assignments_Without_Team_Actions.changeAssignmentSuitabilityForTeam(assignmentName,teamName,choice,"mentor");
    }

    static Stream<Arguments> streamForUsedExp() {
        List<String[]> usedExp = new ArrayList<>();
        usedExp.add(new String[]{"Administrativní klient pro systém SensLog","Papírníci"});
        usedExp.add(new String[]{"Převedení vizualizace scény pro rehabilitaci paže pomocí rehabilitačního robota do virtuální reality","Čtyři stateční"});
        usedExp.add(new String[]{"Rozšíření Genealogy pluginu","Čtyři stateční"});

        List<Arguments> args = new ArrayList<>();
        for (String[] subj: usedExp) {
            for(int i = MentorInterrestTopicTable.MIN_OPTION; i <= MentorInterrestTopicTable.MAX_OPTION; i++){
                args.add(Arguments.of(subj[0],subj[1],i));
            }
        }
        return args.stream();
    }





}
