package pstsp.functional_tests.c_one_change.ts_c_13;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.assignmentmanagement.Assignment_Management_Actions;
import pstsp.support.services.login.Home_Actions;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.PstspTags;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.HashSet;
import java.util.Set;

/**
 * add assignment
 *
 * @author David Kuta
 * @version 2022-04-22
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ONE_CHANGE)
@Tag(PstspTags.ACTIVE)
@Tag(PstspTags.GARANT)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.C.13.01: add assignment")
public class TS_C_13_01 {

    @BeforeAll
    public static void setup() {
        Home_Actions.resetDB();
    }

    @AfterAll
    public static void tearDownAfterAll() {
        Login_Actions.logoutIfPossible();
    }

    @Order(1)
    @Tag(PstspTags.IMP_CRITICAL)
    @Test
    @DisplayName("TC.C.13.01.01: classic assignment")
    void test_01() {
        String assignmentName = "Rozšíření aplikace pro strojové vidění";
        String assignmentDesc = "Far far away, behind the word mountains, far from the countries Vokalia and Consonantia, there live the blind texts. Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences fly into your mouth. Even the all-powerful Pointing has no control about the blind texts it is an almost unorthographic life One day however a small line of blind text by the name of Lorem Ipsum decided to leave for the far World of Grammar. The Big Oxmox advised her not to do so, because there were thousands of bad Commas, wild Question Marks and devious Semikoli, but the Little Blind Text didn’t listen. She packed her seven versalia, put her initial into the belt and made herself on the way. When she reached the first hills of the Italic Mountains, she had a last view back on the skyline of her hometown Bookmarksgrove, the headline of Alphabet Village and the subline of her own road, the Line Lane.";
        String ownerFirsName = "Jaromír";
        String ownerLastName = "Dohnal";
        String ownerEmail = "jdoh@example.com";
        String ownerPhone = "123456789";
        String ownerOtherInfo = "NCSoft s.r.o";
        String timeNeeded = "1322";
        String teamSize = "7";
        Set<String> expTeamProfile = new HashSet<>();
        expTeamProfile.add("C");
        expTeamProfile.add("C#");
        expTeamProfile.add("HTML");
        String mentor = "Pan Mentor";
        String period = "LS 21/22 - ZS 22/23";
        String visibility = "Publikováno pro všechny";
        String currUser = "garant";
        String assignmentMentorLogin = "mentor";
        Assignment_Management_Actions.addAssignmentSuccess(assignmentName, assignmentDesc, ownerFirsName, ownerLastName, ownerEmail, ownerPhone, ownerOtherInfo, timeNeeded, teamSize, expTeamProfile,
                mentor, period, visibility, currUser, assignmentMentorLogin);
    }

    @Order(2)
    @Tag(PstspTags.IMP_MAJOR)
    @Test
    @DisplayName("TC.C.13.01.02: half clear assignment without mentor hidden")
    void test_02() {
        String assignmentName = "Poloprazdne tema 1";
        String assignmentDesc = "";
        String ownerFirsName = "";
        String ownerLastName = "";
        String ownerEmail = "";
        String ownerPhone = "";
        String ownerOtherInfo = "";
        String timeNeeded = "";
        String teamSize = "";
        Set<String> expTeamProfile = new HashSet<>();
        String mentor = "";
        String period = "LS 21/22 - ZS 22/23";
        String visibility = "Skryté";
        String currUser = "garant";
        String assignmentMentorLogin = "";
        Assignment_Management_Actions.addAssignmentSuccess(assignmentName, assignmentDesc, ownerFirsName, ownerLastName, ownerEmail, ownerPhone, ownerOtherInfo, timeNeeded, teamSize, expTeamProfile,
                mentor, period, visibility, currUser, assignmentMentorLogin);
    }

    @Order(3)
    @Tag(PstspTags.IMP_MINOR)
    @Test
    @DisplayName("TC.C.13.01.03: half clear assignment without mentor visible for all")
    void test_03() {
        String assignmentName = "Poloprazdne tema 2";
        String assignmentDesc = "";
        String ownerFirsName = "";
        String ownerLastName = "";
        String ownerEmail = "";
        String ownerPhone = "";
        String ownerOtherInfo = "";
        String timeNeeded = "";
        String teamSize = "";
        Set<String> expTeamProfile = new HashSet<>();
        String mentor = "";
        String period = "LS 21/22 - ZS 22/23";
        String visibility = "Publikováno pro všechny";
        String currUser = "garant";
        String assignmentMentorLogin = "";
        Assignment_Management_Actions.addAssignmentSuccess(assignmentName, assignmentDesc, ownerFirsName, ownerLastName, ownerEmail, ownerPhone, ownerOtherInfo, timeNeeded, teamSize, expTeamProfile,
                mentor, period, visibility, currUser, assignmentMentorLogin);
    }

    @Order(4)
    @Tag(PstspTags.IMP_MINOR)
    @Test
    @DisplayName("TC.C.13.01.04: half clear assignment without mentor visible for mentors")
    void test_04() {
        String assignmentName = "Poloprazdne tema 3";
        String assignmentDesc = "";
        String ownerFirsName = "";
        String ownerLastName = "";
        String ownerEmail = "";
        String ownerPhone = "";
        String ownerOtherInfo = "";
        String timeNeeded = "";
        String teamSize = "";
        Set<String> expTeamProfile = new HashSet<>();
        String mentor = "";
        String period = "LS 21/22 - ZS 22/23";
        String visibility = "Viditelné pouze pro mentory";
        String currUser = "garant";
        String assignmentMentorLogin = "";
        Assignment_Management_Actions.addAssignmentSuccess(assignmentName, assignmentDesc, ownerFirsName, ownerLastName, ownerEmail, ownerPhone, ownerOtherInfo, timeNeeded, teamSize, expTeamProfile,
                mentor, period, visibility, currUser, assignmentMentorLogin);
    }

    @Order(5)
    @Tag(PstspTags.IMP_MAJOR)
    @Test
    @DisplayName("TC.C.13.01.05: half full assignment with mentor hidden")
    void test_05() {
        String assignmentName = "Polovyplnene tema 1";
        String assignmentDesc = "Far far away, behind the word mountains, far from the countries Vokalia and Consonantia, there live the blind texts. Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences fly into your mouth. Even the all-powerful Pointing has no control about the blind texts it is an almost unorthographic life One day however a small line of blind text by the name of Lorem Ipsum decided to leave for the far World of Grammar. The Big Oxmox advised her not to do so, because there were thousands of bad Commas, wild Question Marks and devious Semikoli, but the Little Blind Text didn’t listen. She packed her seven versalia, put her initial into the belt and made herself on the way. When she reached the first hills of the Italic Mountains, she had a last view back on the skyline of her hometown Bookmarksgrove, the headline of Alphabet Village and the subline of her own road, the Line Lane.";
        String ownerFirsName = "Jaroslav";
        String ownerLastName = "Kábrt";
        String ownerEmail = "kbrt@example.com";
        String ownerPhone = "123456789";
        String ownerOtherInfo = "NahodnaFirma s.r.o";
        String timeNeeded = "";
        String teamSize = "";
        Set<String> expTeamProfile = new HashSet<>();
        String mentor = "One Mentor";
        String period = "LS 21/22 - ZS 22/23";
        String visibility = "Skryté";
        String currUser = "garant";
        String assignmentMentorLogin = "oneMentor";
        Assignment_Management_Actions.addAssignmentSuccess(assignmentName, assignmentDesc, ownerFirsName, ownerLastName, ownerEmail, ownerPhone, ownerOtherInfo, timeNeeded, teamSize, expTeamProfile,
                mentor, period, visibility, currUser, assignmentMentorLogin);
    }

    @Order(6)
    @Tag(PstspTags.IMP_MAJOR)
    @Test
    @DisplayName("TC.C.13.01.06: half full assignment with mentor visible for all")
    void test_06() {
        String assignmentName = "Polovyplnene tema 2";
        String assignmentDesc = "Far far away, behind the word mountains, far from the countries Vokalia and Consonantia, there live the blind texts. Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences fly into your mouth. Even the all-powerful Pointing has no control about the blind texts it is an almost unorthographic life One day however a small line of blind text by the name of Lorem Ipsum decided to leave for the far World of Grammar. The Big Oxmox advised her not to do so, because there were thousands of bad Commas, wild Question Marks and devious Semikoli, but the Little Blind Text didn’t listen. She packed her seven versalia, put her initial into the belt and made herself on the way. When she reached the first hills of the Italic Mountains, she had a last view back on the skyline of her hometown Bookmarksgrove, the headline of Alphabet Village and the subline of her own road, the Line Lane.";
        String ownerFirsName = "Jaroslav";
        String ownerLastName = "Kábrt";
        String ownerEmail = "kbrt@example.com";
        String ownerPhone = "123456789";
        String ownerOtherInfo = "NahodnaFirma s.r.o";
        String timeNeeded = "";
        String teamSize = "";
        Set<String> expTeamProfile = new HashSet<>();
        String mentor = "One Mentor";
        String period = "LS 21/22 - ZS 22/23";
        String visibility = "Publikováno pro všechny";
        String currUser = "garant";
        String assignmentMentorLogin = "oneMentor";
        Assignment_Management_Actions.addAssignmentSuccess(assignmentName, assignmentDesc, ownerFirsName, ownerLastName, ownerEmail, ownerPhone, ownerOtherInfo, timeNeeded, teamSize, expTeamProfile,
                mentor, period, visibility, currUser, assignmentMentorLogin);
    }

    @Order(7)
    @Tag(PstspTags.IMP_MAJOR)
    @Test
    @DisplayName("TC.C.13.01.07: half full assignment with mentor visible for all")
    void test_07() {
        String assignmentName = "Polovyplnene tema 3";
        String assignmentDesc = "Far far away, behind the word mountains, far from the countries Vokalia and Consonantia, there live the blind texts. Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary regelialia. It is a paradisematic country, in which roasted parts of sentences fly into your mouth. Even the all-powerful Pointing has no control about the blind texts it is an almost unorthographic life One day however a small line of blind text by the name of Lorem Ipsum decided to leave for the far World of Grammar. The Big Oxmox advised her not to do so, because there were thousands of bad Commas, wild Question Marks and devious Semikoli, but the Little Blind Text didn’t listen. She packed her seven versalia, put her initial into the belt and made herself on the way. When she reached the first hills of the Italic Mountains, she had a last view back on the skyline of her hometown Bookmarksgrove, the headline of Alphabet Village and the subline of her own road, the Line Lane.";
        String ownerFirsName = "Jaroslav";
        String ownerLastName = "Kábrt";
        String ownerEmail = "kbrt@example.com";
        String ownerPhone = "123456789";
        String ownerOtherInfo = "NahodnaFirma s.r.o";
        String timeNeeded = "";
        String teamSize = "";
        Set<String> expTeamProfile = new HashSet<>();
        String mentor = "One Mentor";
        String period = "LS 21/22 - ZS 22/23";
        String visibility = "Viditelné pouze pro mentory";
        String currUser = "garant";
        String assignmentMentorLogin = "oneMentor";
        Assignment_Management_Actions.addAssignmentSuccess(assignmentName, assignmentDesc, ownerFirsName, ownerLastName, ownerEmail, ownerPhone, ownerOtherInfo, timeNeeded, teamSize, expTeamProfile,
                mentor, period, visibility, currUser, assignmentMentorLogin);
    }


}
