package pstsp.functional_tests.d_negative.ts_d_01;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.negative.login.Neg_Login_Actions;
import pstsp.support.test_utils.PstspTags;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.ArrayList;
import java.util.List;

/**
 * Unsuccesfull login activity
 *
 * @author David Kuta
 * @version 2022-04-25
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ACTIVE)
@Tag(PstspTags.UNLOGGED)
@Tag(PstspTags.NEGATIVE)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.D.01: Login page")
public class TS_D_01 {

  @AfterAll
  public static void tearDownAfterAll() {
    Login_Actions.logoutIfPossible();
  }

  @Order(1)
  @Test
  @Tag(PstspTags.IMP_CRITICAL)
  @DisplayName("TC.D.01.01: invalid name, valid password")
  void test_1() {
    Neg_Login_Actions.invalidLogin("xyz","tsp");
  }

  @Order(2)
  @Test
  @Tag(PstspTags.IMP_CRITICAL)
  @DisplayName("TC.D.01.02: invalid password, valid name")
  void test_2() {
    Neg_Login_Actions.invalidLogin("mentor","xyz");
  }

  @Order(3)
  @Test
  @Tag(PstspTags.IMP_CRITICAL)
  @DisplayName("TC.D.01.03: valid name, no password")
  void test_3() {
    List<String> expectedMessages = new ArrayList<>();
    expectedMessages.add("Prosím vyplňte své heslo.");
    Neg_Login_Actions.invalidLogin_blankInput("leader","",expectedMessages);
  }

  @Order(4)
  @Test
  @Tag(PstspTags.IMP_CRITICAL)
  @DisplayName("TC.D.01.03: no name, valid password")
  void test_4() {
    List<String> expectedMessages = new ArrayList<>();
    expectedMessages.add("Prosím vyplňte své uživatelské jméno.");
    Neg_Login_Actions.invalidLogin_blankInput("","tsp",expectedMessages);
  }

  @Order(5)
  @Test
  @Tag(PstspTags.IMP_CRITICAL)
  @DisplayName("TC.D.01.05: no name, no password")
  void test_5() {
    List<String> expectedMessages = new ArrayList<>();
    expectedMessages.add("Prosím vyplňte své uživatelské jméno.");
    expectedMessages.add("Prosím vyplňte své heslo.");

    Neg_Login_Actions.invalidLogin_blankInput("","",expectedMessages);
  }

  @Order(6)
  @Test
  @Tag(PstspTags.IMP_CRITICAL)
  @DisplayName("TC.D.01.06: long password, long name")
  void test_6() {
    Neg_Login_Actions.invalidLogin("h21NDqnyOb9Wr9BHqRzNvTw5wW3Irx7R243fkhJtk9vm6w","jg6kFbztYuVEd3IMXJD8bzGZqWoQi4hI5RV1XWyHBDZqm157JtFHNiO6Y5lTQF4IyPXMdqUVzPYex36zY2crko3zxlo3Ae3ku78dupZXPNbpRnLQqGbFh9KpNkzUAgevYYg8qi1RkjNo0AwvX2OIz8");
  }

}
