package pstsp.functional_tests.e_endtoend;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.login.Home_Actions;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.negative.login.Neg_Login_Actions;
import pstsp.support.services.negative.team.Neg_Team_Actions;
import pstsp.support.services.project.Project_Leader_Actions;
import pstsp.support.services.scenario.Scenario_Leader_Actions;
import pstsp.support.services.team.Team_Actions;
import pstsp.support.test_utils.PstspTags;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.*;

/**
 * leader e2e tests
 *
 * @author David Kuta
 * @version 2022-04-25
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ACTIVE)
@Tag(PstspTags.LEADER)
@Tag(PstspTags.END_TO_END)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.E.01: leader e2e tests")
public class TS_E_01 {

    @BeforeEach
    public void init() {
        Home_Actions.resetDB();
    }

    @Order(1)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.E.01.01: leader start flow")
    void test_01() {

        String leaderInfo = "Druhý Kmazání (A15C1022P)";
        Set<String> expectedMembers = new HashSet<>();
        expectedMembers.add("Dominik JEŽ (A19B0078P)");
        expectedMembers.add("Petr HOLICKÝ (A19B0056P)");
        expectedMembers.add("Václav HRABÍK (A19B0061P)");
        expectedMembers.add("Martin JAKUBAŠEK (A19B0069P)");
        expectedMembers.add("David MORÁVEK (A19B0141P)");
        expectedMembers.add("Josef OUŘEDNÍK (A19B0153P)");
        boolean complete = false;
        Map<String, Set<String>> expectedTeamRoles = new HashMap<>();
        Set<String> m1Roles = new HashSet<>();
        m1Roles.add("Programátor");
        m1Roles.add("Grafik");
        expectedTeamRoles.put(leaderInfo,m1Roles);

        Set<String> m2Roles = new HashSet<>();
        m2Roles.add("Tester");
        m2Roles.add("Designer");
        expectedTeamRoles.put("Dominik JEŽ (A19B0078P)",m2Roles);

        Set<String> m3Roles = new HashSet<>();
        m3Roles.add("Tester");
        m3Roles.add("Dokumentarista");
        expectedTeamRoles.put("Petr HOLICKÝ (A19B0056P)",m3Roles);

        Set<String> m4Roles = new HashSet<>();
        m4Roles.add("Programátor");
        m4Roles.add("Designer");
        expectedTeamRoles.put("Václav HRABÍK (A19B0061P)",m4Roles);

        Set<String> m5Roles = new HashSet<>();
        m5Roles.add("Programátor");
        m5Roles.add("Tester");
        expectedTeamRoles.put("Martin JAKUBAŠEK (A19B0069P)",m5Roles);

        Set<String> m6Roles = new HashSet<>();
        m6Roles.add("Tester");
        expectedTeamRoles.put("David MORÁVEK (A19B0141P)",m6Roles);

        Set<String> m7Roles = new HashSet<>();
        m7Roles.add("Dokumentarista");
        expectedTeamRoles.put("Josef OUŘEDNÍK (A19B0153P)",m7Roles);

        Set<String> teamProfile = new HashSet<>();
        teamProfile.add("C");
        teamProfile.add("C++");
        teamProfile.add("Python");
        teamProfile.add("Backend");

        String interrestAssignmentName = "Administrativní klient pro systém SensLog";
        String interrestPriority = "Velmi velký";
        String mentorLogin = "mentor";
        String currentUser = "secondStudToDel";
        Scenario_Leader_Actions.leaderStartFlow("Nejlepší tým",expectedMembers,complete,expectedTeamRoles,teamProfile,interrestAssignmentName,interrestPriority,currentUser,mentorLogin);
    }

    @Order(2)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.E.01.02: project page edit")
    void test_02() {
        String leaderLogin = "motlm";
        String mentorLogin = "mentor";
        Project_Leader_Actions.editMinCritTblSuccess("Plán projektu",2,leaderLogin,mentorLogin);
        List<String> otherUrls = new ArrayList<>();
        otherUrls.add("PSTSP;https://pstsp.hintik.cz/");
        otherUrls.add("GUTHIB;https://guthib.com/");
        otherUrls.add("PPPPP;https://pstsp.hintik.cz/");

        Project_Leader_Actions.setProjectUrls("https://github.com/","","https://pstsp.hintik.cz/", otherUrls, leaderLogin);

        Project_Leader_Actions.editProjStateTblSuccess("Odkaz na úložiště",2,leaderLogin,mentorLogin);
        Project_Leader_Actions.addUsedExpSuccess("KIV/ODP","TEST INFO",leaderLogin);
        Project_Leader_Actions.editUsedExpTblSuccess("KIV/ODP","TEST INFO",2,leaderLogin,mentorLogin);
    }

    @Order(3)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.E.01.02: add meeting with topic description")
    void test_03() {
        String leaderLogin = "vikkot";
        String mentorLogin = "mentor";
            Team_Actions.addMeetingAsLeaderSuccess("23.3.2023 14:23","FAV","Kavárna","Mentor",leaderLogin,mentorLogin);
        Team_Actions.editMeetingTopicDescriptionAsLeaderSuccess("23.3.2023 14:23","Team building byl velice úspěšný",leaderLogin);
    }


}
