package pstsp.functional_tests.e_endtoend;

import org.junit.jupiter.api.*;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.assignmentmanagement.Assignment_Management_Actions;
import pstsp.support.services.login.Home_Actions;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.negative.login.Neg_Login_Actions;
import pstsp.support.services.negative.team.Neg_Team_Actions;
import pstsp.support.services.project.Project_Garant_Actions;
import pstsp.support.services.project.Project_Leader_Actions;
import pstsp.support.services.project.Project_Mentor_Actions;
import pstsp.support.services.scenario.Scenario_Leader_Actions;
import pstsp.support.services.studentmanagement.Student_Management_Actions;
import pstsp.support.services.team.Team_Actions;
import pstsp.support.services.teammanagement.Team_Management_Actions;
import pstsp.support.test_utils.PstspTags;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.*;

/**
 * garant e2e tests
 *
 * @author David Kuta
 * @version 2022-04-25
 */
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
@Tag(PstspTags.ACTIVE)
@Tag(PstspTags.GARANT)
@Tag(PstspTags.END_TO_END)
@TestMethodOrder(MethodOrderer.OrderAnnotation.class)
@DisplayName("TS.E.03: garant e2e tests")
public class TS_E_03 {

    @BeforeEach
    public void init() {
        Home_Actions.resetDB();
    }

    @Order(1)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.E.03.01: garant project page edit")
    void test_01() {

        String leaderName = "garant";
        String teamName = "Sedm statečných";
        String assignmentName = "Modularizovatelná webová aplikace s modulem pro správu cílů";
        String mentorName = "Pan Mentor";

        Project_Garant_Actions.editMinimalCriteriaTableFromMentorManagementSuccess("Plán projektu", 0, teamName, assignmentName,
                mentorName, leaderName);

        Project_Garant_Actions.editProjStateTableFromMentorManagementSuccess("Odkaz na dokument předání výsledků zadavateli", 1, teamName, assignmentName,
                mentorName, leaderName);
        Project_Garant_Actions.editProjStateTableFromMentorManagementSuccess("Odkaz na softwarové řízení projektu", 3, teamName, assignmentName,
                mentorName, leaderName);
        Project_Garant_Actions.editUsedExpTableFromMentorManagementSuccess("KIV/PPA2", "Využití datových struktur", 2, teamName, assignmentName, mentorName, leaderName);
    }

    @Order(2)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.E.03.02: edit team")
    void test_02() {
        String expTeamName = "Sedm hrdinů";
        String destTeamName = "Sedm statečných";
        String user = "garant";
        String leaderName = "vikkot";
        Team_Management_Actions.editTeamNameSuccess(expTeamName, destTeamName, user);
        Set<String> expected = new HashSet<>();
        expected.add("Marián KADLEČÍK (A19B0083P)");
        expected.add("David MORÁVEK (A19B0141P)");
        expected.add("Matěj HOLUBEC (A20B0104P)");
        Team_Management_Actions.editTeamMembersSuccess(expected, expTeamName, user);
        Team_Management_Actions.editTeamCompletnessSuccess(true, expTeamName, user);
        Team_Management_Actions.setFirstCreditSuccess("25052022", expTeamName, leaderName, user);
    }

    @Order(3)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.E.03.03: assignment create and edit flow")
    void test_03() {
        String user = "garant";
        String assignmentName = "Nové zadání";
        String assignmentDesc = "";
        String ownerFirsName = "";
        String ownerLastName = "";
        String ownerEmail = "";
        String ownerPhone = "";
        String ownerOtherInfo = "";
        String timeNeeded = "";
        String teamSize = "";
        Set<String> expTeamProfile = new HashSet<>();
        String mentor = "";
        String period = "LS 21/22 - ZS 22/23";
        String visibility = "Publikováno pro všechny";
        String assignmentMentorLogin = "";
        Assignment_Management_Actions.addAssignmentSuccess(assignmentName, assignmentDesc, ownerFirsName, ownerLastName, ownerEmail, ownerPhone, ownerOtherInfo, timeNeeded, teamSize, expTeamProfile,
                mentor, period, visibility, user, assignmentMentorLogin);

        Assignment_Management_Actions.editAssignmentDescriptionSuccess("Toto je dlouhý a vyčerpávající popis, který " +
                "detailně vystihuje účel a náročnost tohoto tématu",assignmentName,"",user);

        ownerFirsName = "Karel";
        ownerLastName = "Dobrý";
        Assignment_Management_Actions.editAssignmentOwnerNameSuccess(ownerFirsName,ownerLastName,assignmentName,"",user);
        String ownerFullName = ownerFirsName + " " + ownerLastName;
        Assignment_Management_Actions.editAssignmentOwnerMailSuccess(ownerEmail="kdobry@example.com", assignmentName, ownerFullName, user);
        Assignment_Management_Actions.editAssignmentOwnerPhoneSuccess("123456789",assignmentName,ownerFullName,user);
        Assignment_Management_Actions.editAssignmentOwnerOtherInfoSuccess("Jsem Karel Dobrý z Dobré firmy a přináším dobré zadání",assignmentName,ownerFullName,user);
        Assignment_Management_Actions.editAssignmentTimeNeededSuccess("1234",assignmentName,ownerFullName,user);
        Assignment_Management_Actions.editAssignmentExpTeamSizeSuccess("5",assignmentName,ownerFullName,user);
        Set<String> expected = new HashSet<>();
        expected.add("PHP");
        expected.add("Frontend");
        expected.add("JavaScript");
        Assignment_Management_Actions.editAssignmentExpTeamProfileSuccess(expected, assignmentName, ownerFullName, "garant");
        Assignment_Management_Actions.editAssignmentVisibilitySuccess("Skryté",assignmentName,ownerFullName,user,false);

        Assignment_Management_Actions.editAssignmentMentorSuccess("One Mentor","oneMentor",assignmentName,ownerFullName,user);
        Assignment_Management_Actions.editAssignmentVisibilitySuccess("Publikováno pro všechny",assignmentName,ownerFullName,user,true);

    }

    @Order(4)
    @Test
    @Tag(PstspTags.IMP_MAJOR)
    @DisplayName("TC.E.03.04: team creation and edit")
    void test_04() {

        String firstName ="Student";
        String lastName ="BudVedoucí";
        String email ="studToLead@example.com";
        String personalID ="A15B1011C";
        String teamName = "Nový právě vytvořený tým";
        String user= "garant";
        Student_Management_Actions.makeStudentLeader(firstName,lastName,email,personalID,teamName,user);

        Set<String> expected = new HashSet<>();
        expected.add("Marián KADLEČÍK (A19B0083P)");
        expected.add("David MORÁVEK (A19B0141P)");
        expected.add("Matěj HOLUBEC (A20B0104P)");
        Team_Management_Actions.editTeamMembersSuccess(expected, teamName, user);
        Team_Management_Actions.editTeamCompletnessSuccess(false, teamName, user);

    }

}