package pstsp.run_tests;

/**
 * Class for external running any package | subpackage | class of test
 *
 * wih possibility of usage of tests' tags
 *
 * @author Pavel Herout
 * @version 2022-01-25
 */

import org.junit.platform.launcher.Launcher;
import org.junit.platform.launcher.LauncherDiscoveryRequest;
import org.junit.platform.launcher.core.LauncherDiscoveryRequestBuilder;
import org.junit.platform.launcher.core.LauncherFactory;

import java.util.ArrayList;
import java.util.List;

import static org.junit.platform.engine.discovery.DiscoverySelectors.selectClass;
import static org.junit.platform.engine.discovery.DiscoverySelectors.selectPackage;
import static org.junit.platform.launcher.TagFilter.excludeTags;
import static org.junit.platform.launcher.TagFilter.includeTags;

public class RunAnyTest {

  public static void main(String[] args) {
    if (args.length == 0) {
      help();
      return;
    }
    String packageName = "";
    String className = "";
    List<String> includeTags = new ArrayList<>();
    List<String> excludeTags = new ArrayList<>();

    for (int i = 0;  i < args.length;  i += 2) {
      switch (args[i]) {
        case "p":  // package
          packageName = args[i + 1];
          break;
        case "c":  // class
          className = args[i + 1];
          break;
        case "i":  // include tag
          includeTags.add(args[i + 1]);
          break;
        case "e":  // exclude tag
          excludeTags.add(args[i + 1]);
          break;
      }
    }

    String[] include = includeTags.toArray(new String[0]);
    String[] exclude = excludeTags.toArray(new String[0]);

    LauncherDiscoveryRequestBuilder builder = LauncherDiscoveryRequestBuilder.request();
    if (packageName.isEmpty() == false) {
      builder.selectors(selectPackage(packageName));
    }
    else if (className.isEmpty() == false) {
      builder.selectors(selectClass(className));
    }
    if (include.length > 0) {
      builder.filters(includeTags(include));
    }
    if (exclude.length > 0) {
      builder.filters(excludeTags(exclude));
    }

    LauncherDiscoveryRequest request = builder.build();
    Launcher launcher = LauncherFactory.create();
    launcher.execute(request);
  }

  public static void help() {
    System.out.println("Usage:");
    System.out.println("RunAnyTest p fullPackageName | c fullClassName [i includeTag]* [e excludeTag]*");
    System.out.println("Examples:");
    System.out.println("RunAnyTest p pstsp.functional_tests");
    System.out.println("RunAnyTest p pstsp.functional_tests i ACTIVE e GARANT");
    System.out.println("RunAnyTest c pstsp.functional_tests.c_one_change.ts_c_01.TS_C_01" +
            " i IMP_CRITICAL i IMP_MAJOR e SMOKE e LINK");
  }

}
