package pstsp.support.pageobjects;

/**
 * The parent class of each page object class
 *
 * @author Pavel Herout
 * @version 2019-24-11
 */

import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.PageFactory;
import pstsp.support.test_utils.Fail;
import pstsp.support.tools.Drivers;

import java.util.List;

public class PageObject {
  /**
   * Initialization of each web element annotated by @FindBy()
   */
  public PageObject() {
    PageFactory.initElements(Drivers.getDriver(), this);
  }

  /**
   * When a web element was initialized by PageFactory.initElements()
   * (e.g. web element was found on the web page = displayed)
   * the reference at it is an only one element of the list
   *
   * if a web element has not been initialized, the list is empty
   *
   * @param list list with one reference to a web element, or empty list
   * @return true, when list is not empty, false otherwise
   */
  public boolean isDisplayed(List<WebElement> list) {
    return list.size() == 1;
  }

  /**
   * Getting an initialized reference to a web element
   * or failing test by Fail.failTestDueToMissingElement(id);
   *
   * @param list list with one reference to a web element, or empty list
   * @param id ID of the web element - it is necessary for logging of a possible failed test
   * @return reference to a web element
   */
  public WebElement getElement(List<WebElement> list, String id) {
    if (isDisplayed(list) == true) {
      return list.get(0);
    }
    else {
      Fail.failTestDueToMissingElement(id);
      return null;
    }
  }
}