package pstsp.support.pageobjects.assignment;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;
import pstsp.support.tools.Drivers;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Assignment page
 * Unlogged
 * @author David Kuta
 */
public class Assignment_Page extends PageObject {
    public static final String PAGE_ID = "assignmentPage-show-title";
    public static final String AS_NAME = "assignmentPage-assignment-name";
    public static final String AS_DESCRIPTION = "assignmentPage-assignment-description";
    public static final String PDF_LINK = "assignmentPage-assignment-pdfLinkBTN";
    public static final String AS_STATE = "assignmentPage-assignment-state";
    public static final String AS_PREF_TEAM_SIZE = "assignmentPage-assignment-prefTeamSize";
    public static final String AS_EXP_TIME = "assignmentPage-assignment-expTime";
    public static final String AS_TAGS = "assignmentPage-assignment-tags";
    public static final String AS_CREATOR_NAME = "assignmentPage-assignment-creator-name";
    public static final String AS_CREATOR_EMAIL = "assignmentPage-assignment-creator-email";
    public static final String AS_CREATOR_PHONE = "assignmentPage-assignment-creator-phone";
    public static final String AS_CREATOR_INFO = "assignmentPage-assignment-creator-nextInfo";
    public static final String AS_INTERREST_BTN = "assignmentPage-assignBTN";
    public static final String AS_MENTOR_NAME = "assignmentPage-assignment-mentor-name";
    public static final String AS_MENTOR_EMAIL = "assignmentPage-assignment-mentor-email";
    public static final String AS_MENTOR_INFO = "assignmentPage-assignment-mentor-nextInfo";
    public static final String MENTOR_ASSIGN_BTN = "assignmentPage-mentorAssignBTN";

    public static final String UNSPECIFIED = "Dosud nespecifikováno";

    @FindBy(id = AS_NAME)
    private List<WebElement> assignmentName;

    @FindBy(id = AS_DESCRIPTION)
    private List<WebElement> assignmentDescription;

    @FindBy(id = PDF_LINK)
    private List<WebElement> pdfLink;

    @FindBy(id = AS_STATE)
    private List<WebElement> assignmentState;

    @FindBy(id = AS_INTERREST_BTN)
    private List<WebElement> interrestBTN;

    @FindBy(id = MENTOR_ASSIGN_BTN)
    private List<WebElement> mentorAssignBtn;

    @FindBy(id = AS_CREATOR_NAME)
    private List<WebElement> creatorName;

    @FindBy(id = AS_CREATOR_EMAIL)
    private List<WebElement> creatorEmail;

    @FindBy(id = AS_MENTOR_NAME)
    private List<WebElement> mentorName;

    @FindBy(id = AS_MENTOR_EMAIL)
    private List<WebElement> mentorEmail;


    public String getState() {
        WebElement element = getElement(assignmentState, AS_STATE);
        return element.getText().strip();
    }

    public String getName() {
        WebElement element = getElement(assignmentName, AS_NAME);
        return element.getText().strip();
    }

    public String getDescription() {
        WebElement element = getElement(assignmentDescription, AS_DESCRIPTION);
        return element.getText().strip();
    }

    @FindBy(id = AS_TAGS)
    private List<WebElement> tags;
    /**
     *
     * @return set of profile, related to whole team
     */
    public Set<String> getAssignmentTags(){
        Set<String> profiles = new HashSet<>();
        WebElement element = getElement(tags,AS_TAGS);
        List<WebElement> badges = element.findElements(By.tagName("span"));
        for (WebElement badge: badges) {
            profiles.add(badge.getText());
        }
        return profiles;
    }

    @FindBy(id = AS_PREF_TEAM_SIZE)
    private List<WebElement> prefTeamSize;

    public String getPrefTeamSize() {
        WebElement element = getElement(prefTeamSize, AS_PREF_TEAM_SIZE);
        if(element.getText().strip().equals(UNSPECIFIED)) {
            return "";
        }
        return element.getText().strip().split(" ")[0];
    }

    @FindBy(id = AS_EXP_TIME)
    private List<WebElement> expectedTime;

    public String getExpectedTime() {
        WebElement element = getElement(expectedTime, AS_EXP_TIME);
        if(element.getText().strip().equals(UNSPECIFIED)) {
            return "";
        }
        return element.getText().split(" ")[0];
    }


    public Assignment_Page_Leader_Interrest_Modal clickOnInterestButton() {
        WebElement element = getElement(interrestBTN, AS_INTERREST_BTN);
        Click.clickAndWaitId(element, Assignment_Page_Leader_Interrest_Modal.PAGE_ID);
        return new Assignment_Page_Leader_Interrest_Modal();
    }

    public Assignment_Page_Mentor_Assign_Modal clickOnMentorAssignButton() {
        WebElement element = getElement(mentorAssignBtn, MENTOR_ASSIGN_BTN);
        Click.clickAndWaitId(element, Assignment_Page_Mentor_Assign_Modal.PAGE_ID);
        return new Assignment_Page_Mentor_Assign_Modal();
    }

    public String getMentorName(){
        WebElement element = getElement(mentorName, AS_MENTOR_NAME);
        return element.getText().strip();
    }

    public String getMentorEmail(){
        WebElement element = getElement(mentorEmail, AS_MENTOR_EMAIL);
        return element.getText().strip();
    }


    /*public String getMentorNextInfo(){
        List<WebElement> l= Drivers.getDriver().findElements(By.id(AS_CREATOR_INFO));
        if(l.size()== 0){
            // empty list if no matching element
            return "";
        } else {
            return l.get(0).getText().strip();
        }
    }*/

    public String getOwnerName(){
        WebElement element = getElement(creatorName, AS_CREATOR_NAME);
        return element.getText().strip();
    }

    public String getOwnerPhone(){
        List<WebElement> l= Drivers.getDriver().findElements(By.id(AS_CREATOR_PHONE));
        if(l.size()== 0){
            // empty list if no matching element
            return "";
        } else {
            return l.get(0).getText().strip();
        }
    }

    public String getOwnerOtherInfo(){
        List<WebElement> l= Drivers.getDriver().findElements(By.id(AS_CREATOR_INFO));
        if(l.size()== 0){
            // empty list if no matching element
            return "";
        } else {
            return l.get(0).getText().strip();
        }
    }

    public String getOwnerEmail(){
        //WebElement element = getElement(creatorEmail, AS_CREATOR_EMAIL);

        List<WebElement> l= Drivers.getDriver().findElements(By.id(AS_CREATOR_EMAIL));
        if(l.size()== 0){
            // empty list if no matching element
            return "";
        } else {
            return l.get(0).getText().strip();
        }
    }

}
