package pstsp.support.pageobjects.assignmentswithmentor;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.services.entities.Assignment;

import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Assignments with mentor
 * Garant
 * @author David Kuta
 */
public class Assignments_With_Mentor_Page extends PageObject {

    public static final String PAGE_ID = "assignmentWithMentorPage-default-title";
    public static final String ASSIGNMENT_SECTION = "assignmentWithMentorPage-assignments";
    public static final String ASSIGNMENT_DIV_CLS = "assignmentWithMentorPage-assignments-divClass";

    // assignment classes
    public static final String NAME_CLS = "assignmentWithMentorPage-assignment-name";
    public static final String STATUS_CLS = "assignmentWithMentorPage-assignment-status";
    public static final String DESCRIPTION_CLS = "assignmentWithMentorPage-assignment-description";
    public static final String TEAM_SIZE_CLS = "assignmentWithMentorPage-assignment-teamSize";
    public static final String TIME_NEEDED_CLS = "assignmentWithMentorPage-assignment-timeNeeded";
    public static final String MENTOR_NAME_CLS = "assignmentWithMentorPage-assignment-mentorName";
    public static final String ASSIGNMENT_OWNER_CLS = "assignmentWithMentorPage-assignment-topicOwner";
    public static final String TAGS_CLS = "assignmentWithMentorPage-assignment-tags";
    public static final String DETAILS_BTN_CLS = "assignmentWithMentorPage-assignment-detailsBTN";


    @FindBy(id = ASSIGNMENT_SECTION)
    private List<WebElement> assignments;

    public HashMap<String, Assignment> getAssignments(){
        WebElement element = getElement(assignments, ASSIGNMENT_SECTION);

        List<WebElement> assignmentList = element.findElements(By.className(ASSIGNMENT_DIV_CLS));
        HashMap<String, Assignment> map = new HashMap<>();
        for (WebElement e: assignmentList) {

            String name = e.findElement(By.className(NAME_CLS)).getText();
            String status = e.findElement(By.className(STATUS_CLS)).getText();
            String desc = e.findElement(By.className(DESCRIPTION_CLS)).getText();
            String teamSize = e.findElement(By.className(TEAM_SIZE_CLS)).getText();
            String timeNeeded = e.findElement(By.className(TIME_NEEDED_CLS)).getText().split(" ")[0];
            if(timeNeeded.equals("č-h"))
            {
                timeNeeded = "";
            }
            String mentor = e.findElement(By.className(MENTOR_NAME_CLS)).getText();
            String owner = e.findElement(By.className(ASSIGNMENT_OWNER_CLS)).getText();
            Set<String> tags = new HashSet<>();

            WebElement tagsE = e.findElement(By.className(TAGS_CLS));
            List<WebElement> tagsL = tagsE.findElements(By.tagName("span"));

            tagsL.forEach(el -> {
                if(!el.getText().equals("Požadovaný profil týmu nestanoven")){
                    tags.add(el.getText());
                }
            });

            WebElement button = e.findElement(By.className(DETAILS_BTN_CLS));
            Assignment assignment = new Assignment(name,desc, teamSize, timeNeeded, mentor, owner, tags, button);
            assignment.setStatus(status);
            map.put(name, assignment);
        }
        return map;
    }
}
