package pstsp.support.pageobjects.assignmentswithoutteam;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Table;
import pstsp.support.services.entities.InterrestedTopicMentorTableRow;
import pstsp.support.services.entities.storage.MentorInterrestTopicTable;
import pstsp.support.services.entities.AssignmentInfo;
import pstsp.support.test_utils.Fail;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
/**
 * Assignments without team page
 * Mentor
 * @author David Kuta
 */
public class Assignments_Without_Team_Page extends PageObject {

    public static final String PAGE_ID = "assignmentsWithoutTeamPage-default-title";
    public static final String NOT_INTERRESTED_ASSIGNMENTS_TABLE = "assignmentsWithoutTeamPage-table-notInterestedAssignments";
    public static final String ASSIGNMENTS_WITH_INTERREST_TABLE = "assignmentsWithoutTeamPage-table-interrestedAssignments";

    //prefixes
    public static final String ASSIGNMENT_WITH_INT_INFO_BUTTON = "assignmentsWithoutTeamPage-table-interAssign-infoBtn-";
    public static final String ASSIGNMENT_WITH_INT_TOGGLE = "assignmentsWithoutTeamPage-table-interAssign-toggle-";

    @FindBy(id = NOT_INTERRESTED_ASSIGNMENTS_TABLE)
    private List<WebElement> notInterrested;

    @FindBy(id = ASSIGNMENTS_WITH_INTERREST_TABLE)
    private List<WebElement> interrestedAssignments;

    public List<AssignmentInfo> getAllNotInterrestedAssignments() {
        WebElement element = getElement(notInterrested, NOT_INTERRESTED_ASSIGNMENTS_TABLE);
        List<AssignmentInfo> result = new ArrayList<>();
        List<List<WebElement>> tableContent = Table.getTableContent(element);

        for (List<WebElement> row : tableContent) {
            if(row.size() != 2) continue;
            AssignmentInfo semiResult = new AssignmentInfo();
            for (int i = 0; i < row.size(); i++) {
                switch (i) {
                    case 0: {
                        WebElement btn = row.get(i).findElement(By.tagName("a"));
                        semiResult.setNameLink(btn);
                        break;
                    }
                    case 1: {
                        semiResult.setOwner(row.get(i).getText().strip());
                        break;
                    }
                }
            }
            if (row.size() > 0) {
                result.add(semiResult);
            }
        }

        return result;
    }


    public MentorInterrestTopicTable getAllTopicInterrests() {

        WebElement table = getElement(interrestedAssignments, ASSIGNMENTS_WITH_INTERREST_TABLE);
        List<List<WebElement>> tableContent = Table.getTableContent(table);
        List<InterrestedTopicMentorTableRow> result = new ArrayList<>();
        int tableRowCnt = 0;
        for (List<WebElement> row : tableContent) {

            if(row.size() != 6) continue;

            InterrestedTopicMentorTableRow semiResult = new InterrestedTopicMentorTableRow();
            for (int i = 0; i < row.size(); i++) {
                switch (i) {
                    case 0: {
                        WebElement asignName = row.get(i).findElement(By.tagName("a"));
                        semiResult.setAssignmentName(asignName);
                        break;
                    }
                    case 1: {
                        WebElement teamName = row.get(i).findElement(By.tagName("a"));
                        semiResult.setTeamName(teamName);
                        break;
                    }
                    case 3: {
                        String interLevel = row.get(i).getText().strip();
                        semiResult.setInterrestLevel(interLevel);
                        break;
                    }
                    case 4: {
                        String date = row.get(i).getText();
                        try {
                            semiResult.setInterrestDate(date);
                        } catch (ParseException e) {
                            Fail.failTestDueToMissingTextInTable(ASSIGNMENTS_WITH_INTERREST_TABLE, "Unexpected date format");
                            throw new IllegalStateException("Unexpected date format in " + ASSIGNMENTS_WITH_INTERREST_TABLE
                                    + " with text " + date);
                        }
                        break;
                    }
                    case 5:{
                        String color = row.get(i).findElement(By.id(ASSIGNMENT_WITH_INT_INFO_BUTTON + tableRowCnt)).getAttribute("data-colorvalue");
                        WebElement toggle = row.get(i).findElement(By.id(ASSIGNMENT_WITH_INT_TOGGLE + tableRowCnt));
                        semiResult.setButtonColor(color.split("-")[1]);
                        semiResult.setButtonToggle(toggle);
                        break;
                    }
                }

            }
            if(row.size()>0){
                result.add(semiResult);
                tableRowCnt++;
            }

        }
        return new MentorInterrestTopicTable(result);
    }
}
