package pstsp.support.pageobjects.assignmenttoteammanagement;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Table;
import pstsp.support.services.entities.AsToTeamManagTeamInterrest;
import pstsp.support.services.entities.AssignmentToTeamManagementTableRow;

import java.util.ArrayList;
import java.util.List;
/**
 * Assignments to team management page
 * Garant
 * @author David Kuta
 */
public class Assignment_To_Team_Management_Page extends PageObject {
    public static final String PAGE_ID = "assignmentToTeamManagementPage-default-title";
    public static final String TEAM_NAME_CLS = "team-name";
    public static final String MANAGEMENT_TABLE = "assignmentToTeamManagementPage-table";

    public static final String TABLE_INTERREST_CELL_INFO = "assignmentToTeamManagementPage-teamInterrest";
    public static final String TABLE_GAR_ACT_CELL_INFO = "assignmentToTeamManagementPage-garantAction";
    public static final String TABLE_CELL_TYPE_ATTR = "data-cellType";
    public static final String TABLE_INTER_TEAM_PRIORITY = "assignmentToTeamManagementPage-table-action-priority";
    public static final String TABLE_INTER_MENTOR_STATUS = "assignmentToTeamManagementPage-table-action-mentorStatus";
    public static final String TABLE_INTER_DATETIME = "assignmentToTeamManagementPage-table-action-dateTime";
    public static final String TABLE_INTER_ACTION_BTN = "assignmentToTeamManagementPage-table-action-assignBtn";


    @FindBy(id = MANAGEMENT_TABLE)
    private List<WebElement> managementTable;

    public List<AssignmentToTeamManagementTableRow> getManagementTable(){
        WebElement tableEl = getElement(managementTable, MANAGEMENT_TABLE);
        List<WebElement> teamNames = tableEl.findElements(By.className(TEAM_NAME_CLS));
        //teamNames.forEach(a -> System.out.println(a.getText()));
        List<AssignmentToTeamManagementTableRow> result = new ArrayList<>();
        List<List<WebElement>> tableContent = Table.getTableContent(tableEl);
        int teamsCount = teamNames.size();
        int columnCount = 1 + teamsCount;

        for (List<WebElement> row: tableContent) {
            if(row.size() != columnCount) continue;
            AssignmentToTeamManagementTableRow tbRow = new AssignmentToTeamManagementTableRow();
            List<AsToTeamManagTeamInterrest> teamInterInfoList = new ArrayList<>();
            tbRow.setListOfInterrests(teamInterInfoList);
            for(int i = 0; i < row.size(); i++){

                    if (i == 0){
                        WebElement nameLink = row.get(i).findElement(By.tagName("a"));
                        tbRow.setAssignmentName(nameLink);
                    }
                    else {
                        String type = row.get(i).getAttribute(TABLE_CELL_TYPE_ATTR).strip();
                        if(type.equals(TABLE_INTERREST_CELL_INFO)) {
                            WebElement teamName = teamNames.get(i-1);
                            String priority = row.get(i).findElement(By.className(TABLE_INTER_TEAM_PRIORITY)).findElement(By.tagName("i")).getAttribute("data-original-title");
                            String date = row.get(i).findElement(By.className(TABLE_INTER_DATETIME)).getText().strip();
                            String color = row.get(i).findElement(By.className(TABLE_INTER_MENTOR_STATUS)).getAttribute("data-colorvalue");
                            WebElement button = row.get(i).findElement(By.className(TABLE_INTER_ACTION_BTN));
                            AsToTeamManagTeamInterrest info =
                                    new AsToTeamManagTeamInterrest(teamName,priority,date,color,button);
                        teamInterInfoList.add(info);
                        }

                    }
                }
            if(row.size() > 0){
                result.add(tbRow);
            }
            }


        return result;
    }

    public List<String> getAllTeamsWithoutAssignment(){
        List<String> result = new ArrayList<>();
        WebElement tableEl = getElement(managementTable, MANAGEMENT_TABLE);
        List<WebElement> elList = tableEl.findElements(By.className(TEAM_NAME_CLS));
        elList.forEach(a -> result.add(a.getText().strip()));
        return result;
    }

}
