package pstsp.support.pageobjects.commonparts;

/**
 * Header bar for all roles
 *
 * @author Pavel Herout
 * @version 2022-01-20
 */

import org.openqa.selenium.*;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.ui.ExpectedConditions;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.pageobjects.homepage.Home_Page;
import pstsp.support.pageobjects.login.Login_Page;
import pstsp.support.selenium_utils.Click;


import java.util.List;

public class HeaderBar_Page extends PageObject {

  // ID's on web page
  public static final String USER_NAME = "base-upperNavbar-profileName";
//  public static final String CL_USER_ROLE = "badge badge-danger";
  public static final String PROFILE = "base-upperNavbar-profileSettings";
  public static final String LOGOUT = "base-upperNavbar-logout";
  public static final String LOGIN_BTN = "base-upperNavBar-loginBtn";
  public static final String RESET_DB = "base-upperNavbar-resetDB";
  public static final String INTERNAL_ERROR_ID = "nette-error";
  public static final String TRACY_ERROR = "tracy_error";

  //////////
  @FindBy(id = USER_NAME)
  private List<WebElement> userName;

  /**
   * Get logged user full name
   *
   * @return user full name
   */
  public String getLoggedUserFullName() {
    if(userName.isEmpty()) {
      return Const.NOT_LOGGED_INFO;
    }
    else {
      String all = getElement(userName, USER_NAME).getText();
      int space = all.indexOf(" ") + 1;
      return all.substring(space);
    }
  }

  @FindBy(id = RESET_DB)
  private List<WebElement> resetDBBTN;

  public void clickOnResetDB(){
    WebElement element = getElement(resetDBBTN, RESET_DB);
    element.click();
    Alert alert = Click.wait.until(ExpectedConditions.alertIsPresent());
    alert.accept();
  }



  /**
   * Get user role
   *
   * @return user role
   */
  public String getLoggedUserRole() {
    String all = getElement(userName, USER_NAME).getText();
    int space = all.indexOf(" ");
    return all.substring(0, space);
  }

  //////////
  @FindBy(id = LOGOUT)
  private List<WebElement> logoutLink;

  /**
   * Performs logout activity and without any alert
   *  waits for login page visible
   *  goes to Login page
   *
   * @return Login_Page
   */
  public PageObject clickOnLogoutLink() {
    WebElement dropDown = getElement(userName, USER_NAME);
    By by = By.id(LOGOUT);
    Click.clickAndWaitBy(dropDown, by);
    HeaderBar_Page tmp = new HeaderBar_Page();
    WebElement logout = tmp.getElement(logoutLink, LOGOUT);
    Click.clickAndWaitId(logout, Home_Page.LOGIN_BTN);
    return new Login_Page();
  }

  //////////
  @FindBy(id = LOGIN_BTN)
  private List<WebElement> loginBTN;

  public Login_Page clickOnLoginBTN(){
    WebElement element = getElement(loginBTN,LOGIN_BTN);
    Click.clickAndWaitId(element,Login_Page.USERNAME_INPUT);
    return new Login_Page();
  }

  public boolean canClickOnLoginBTN() {
    return !loginBTN.isEmpty();
  }

  @FindBy(id=INTERNAL_ERROR_ID)
  private List<WebElement> internalError;

  @FindBy(id=TRACY_ERROR)
  private List<WebElement> tracyError;

  /**
   * Checks if application is still running and not fell
   */
  public boolean isApplicationErrorPresent(){

    if(internalError.isEmpty() && tracyError.isEmpty()){
      return false;
    }
    else {
      return true;
    }
  }
}
