package pstsp.support.pageobjects.commonparts;

/**
 * General modal window
 *   it has the same closing icon for each modal window
 *
 * @author Pavel Herout
 * @version 2019-24-11
 */

import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;

import java.util.List;

public class ModalClose_Page extends PageObject {
  /** returning page depends on parents page */
  private PageObject returningPage;

  /**
   * Constructor
   *
   * @param returningPage specified parents page
   */
  public ModalClose_Page(PageObject returningPage) {
    this.returningPage = returningPage;
  }

  // ID's on web page
  public static final String GENERAL_MODAL_CLOSE_BUTTON = "closeModalButtonCross";

  //////////
  @FindBy(id = GENERAL_MODAL_CLOSE_BUTTON)
  private List<WebElement> close;

  /**
   * Get close icon web element
   *
   * @return close icon web element
   */
  public WebElement getCloseIcon() {
    return getElement(close, GENERAL_MODAL_CLOSE_BUTTON);
  }

  /**
   * Check close icon enabled
   *
   * @return true=enabled, false=disabled
   */
  public boolean isCloseIconEnabled() {
    return getElement(close, GENERAL_MODAL_CLOSE_BUTTON).isEnabled();
  }

  /**
   * Close any modal window
   */
  public PageObject clickOnCloseIcon() {
    WebElement closeIcon = getElement(close, GENERAL_MODAL_CLOSE_BUTTON);
    Click.clickIconAndWaitHideModal(closeIcon);
    return returningPage;
  }
}
