package pstsp.support.pageobjects.commonparts;



import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.pageobjects.assignment.Assignment_Page;
import pstsp.support.pageobjects.assignmentlist.Assignment_List_Page;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.selenium_utils.Click;

import java.util.List;
/**
 * Side Navbar for leader
 *
 * @author David Kuta
 * @version 2022-02-16
 */
public class SideNavBarLeader_Page extends PageObject {

  // ID's on web page
  public static final String ASSIGNMENT_LIST = "base-sideNavbar-leader-assignmentList";
  public static final String PROJECT_ASSIGNMENT = "base-sideNavbar-leader-projectAssignment";
  public static final String PROJECT = "base-sideNavbar-leader-projectPage";
  public static final String TEAM = "base-sideNavbar-leader-teamPage";
  public static final String BASE_LEFT_MENU_TOGGLE = "base-upperNavbar-pushMenuToggle";

  //////////
  @FindBy(id = ASSIGNMENT_LIST)
  private List<WebElement> assignmentList;

  @FindBy(id = PROJECT)
  private List<WebElement> project;

  @FindBy(id = PROJECT_ASSIGNMENT)
  private List<WebElement> projectAssignment;

  @FindBy(id = TEAM)
  private List<WebElement> teamPage;

  @FindBy(id = BASE_LEFT_MENU_TOGGLE)
  private List<WebElement> leftMenuToggle;

  /**
   * Performs clicking on teamPage link on sidenav menu
   *
   * @return TeamPage
   */
  public Team_Page clickOnTeamPageLink() {
    WebElement link = getElement(teamPage, TEAM);
    Click.clickAndWaitId(link, Team_Page.PAGE_ID);
    return new Team_Page();
  }

  /**
   * Performs clicking on ProjectPage link on sidenav menu
   *
   * @return ProjectPage
   */
  public Project_Page clickOnProjectPageLink() {
    WebElement link = getElement(project, PROJECT);
    Click.clickAndWaitId(link, Project_Page.PAGE_ID);
    return new Project_Page();
  }

  /**
   * Performs clicking on Project assignment link on sidenav menu
   *
   * @return ProjectPage
   */
  public Project_Page clickOnProjectAssigment() {
    WebElement link = getElement(projectAssignment, PROJECT_ASSIGNMENT);
    Click.clickAndWaitId(link, Assignment_Page.PAGE_ID);
    return new Project_Page();
  }

  /**
   * Performs clicking on teamPage link on sidenav menu
   *
   * @return Assignment_List_Page
   */
  public Assignment_List_Page clickAssignmentListPageLink() {
    WebElement link = getElement(assignmentList, ASSIGNMENT_LIST);
    Click.clickAndWaitId(link, Assignment_List_Page.PAGE_ID);
    return new Assignment_List_Page();
  }

}
