package pstsp.support.pageobjects.commonparts;

import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.pageobjects.assignmentswithouthmentor.Assignments_Without_Mentor_Page;
import pstsp.support.pageobjects.assignmentswithoutteam.Assignments_Without_Team_Page;
import pstsp.support.pageobjects.mentoredprojects.Mentored_Projects_Page;
import pstsp.support.pageobjects.mentoredprojectshistory.Mentored_Projects_History_Page;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.selenium_utils.Click;

import java.util.List;
/**
 * Side Navbar for mentor
 *
 * @author David Kuta
 * @version 2022-02-16
 */
public class SideNavBarMentor_Page extends PageObject {

    // ID's on web page
    public static final String ASSIGNMENT_LIST = "base-sideNavbar-leader-assignmentList";
    public static final String MENTORED_PROJECTS = "base-sideNavbar-mentor-metoredProjects";
    public static final String TOPICS_WITHOUT_TEAM = "base-sideNavbar-mentor-topicsWithoutTeam";
    public static final String TOPICS_WITHOUT_MENTOR = "base-sideNavbar-mentor-topicsWithoutMentor";
    public static final String MENTORED_PROJECTS_HISTORY = "base-sideNavbar-mentor-mentoredProjectsHistory";

    //////////
    @FindBy(id = ASSIGNMENT_LIST)
    private List<WebElement> assignmentList;

    @FindBy(id = TOPICS_WITHOUT_TEAM)
    private List<WebElement> topicsWithoutTeam;

    @FindBy(id = MENTORED_PROJECTS)
    private List<WebElement> mentoredProjects;

    @FindBy(id = TOPICS_WITHOUT_MENTOR)
    private List<WebElement> topicsWithoutMentor;

    @FindBy(id = MENTORED_PROJECTS_HISTORY)
    private List<WebElement> mentoredProjectsHistory;

    /**
     * Performs clicking on AssignmentsWithoutMentor link on sidenav menu
     *
     * @return TeamPage
     */
    public Assignments_Without_Mentor_Page clickOnAssignmentsWithoutMentor() {
        WebElement link = getElement(topicsWithoutMentor, TOPICS_WITHOUT_MENTOR);
        Click.clickAndWaitId(link, Assignments_Without_Mentor_Page.PAGE_ID);
        return new Assignments_Without_Mentor_Page();
    }

    /**
     * Performs clicking on TopicsWithoutTeam link on sidenav menu
     *
     * @return Assignments_Without_Team_Page
     */
    public Assignments_Without_Team_Page clickOnAssignmentsWithoutTeam() {
        WebElement link = getElement(topicsWithoutTeam, TOPICS_WITHOUT_TEAM);
        Click.clickAndWaitId(link, Assignments_Without_Team_Page.PAGE_ID);
        return new Assignments_Without_Team_Page();
    }

    /**
     * Performs clicking on MentoredProjects link on sidenav menu
     *
     * @return Mentored_Projects_Page
     */
    public Mentored_Projects_Page clickOnMentoredProjects() {
        WebElement link = getElement(mentoredProjects, MENTORED_PROJECTS);
        Click.clickAndWaitId(link, Mentored_Projects_Page.PAGE_ID);
        return new Mentored_Projects_Page();
    }

    /**
     * Performs clicking on MentoredProjectsHistory link on sidenav menu
     *
     * @return ProjectPage
     */
    public Mentored_Projects_History_Page clickOnMentoredProjectsHistory() {
        WebElement link = getElement(mentoredProjectsHistory, MENTORED_PROJECTS_HISTORY);
        Click.clickAndWaitId(link, Mentored_Projects_History_Page.PAGE_ID);
        return new Mentored_Projects_History_Page();
    }
}
