package pstsp.support.pageobjects.commonparts;

/**
 * Side Navbar for unlogged
 *
 * @author David Kuta
 * @version 2022-02-16
 */

import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.incompleteTeam.Incomplete_Team_Page;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.pageobjects.assignmentlist.Assignment_List_Page;
import pstsp.support.selenium_utils.Click;

import java.util.List;

public class SideNavBarUnlogged_Page extends PageObject {

  // ID's on web page
  public static final String ASSIGNMENT_LIST = "base-sideNavbar-leader-assignmentList";
  public static final String INCOMPLETE_TEAMS = "base-sideNavbar-leader-incompleteTeams";
  public static final String HOME_LINK = "base-sideNavbar-caption";

  //////////
  @FindBy(id = ASSIGNMENT_LIST)
  private List<WebElement> assignmentList;

  @FindBy(id = INCOMPLETE_TEAMS)
  private List<WebElement> incompleteTeams;

  @FindBy(id = HOME_LINK)
  private List<WebElement> homeLink;


  /**
   * Performs clicking on teamPage link on sidenav menu
   *
   * @return Assignment_List_Page
   */
  public Assignment_List_Page clickAssignmentListPageLink() {
    WebElement link = getElement(assignmentList, ASSIGNMENT_LIST);
    Click.clickAndWaitId(link, Assignment_List_Page.PAGE_ID);
    return new Assignment_List_Page();
  }


  public Incomplete_Team_Page clickOnIncompleteTeamsPageLink() {
    WebElement link = getElement(incompleteTeams, INCOMPLETE_TEAMS);
    Click.clickAndWaitId(link, Incomplete_Team_Page.PAGE_ID);
    return new Incomplete_Team_Page();
  }

  /**
   * Performs clicking on home link on sidenav menu
   * Goes to site based on context(logged user role)
   */
  public void clickHomePageLink() {
    WebElement link = getElement(homeLink, HOME_LINK);
    Click.clickAndWaitId(link, Const.BASE_TITLE_ID);
  }


}
