package pstsp.support.pageobjects.incompleteTeam;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.services.entities.Assignment;
import pstsp.support.services.entities.IncompleteTeam;
import pstsp.support.test_utils.Fail;

import java.util.*;
/**
 * Incomplete team page
 * Unlogged
 * @author David Kuta
 */
public class Incomplete_Team_Page extends PageObject {

    public static final String PAGE_ID = "incompleteTeamsPage-default-title";

    public static final String TEAM_DIV = "incompleteTeamsPage-teams";

    //classes
    public static final String TEAM_CARD_CLS = "incompleteTeamsPage-team-card";
    public static final String TEAM_NAME_CLS = "incompleteTeamsPage-team-name";
    public static final String LEADER_NAME_CLS = "incompleteTeamsPage-team-leader-name";
    public static final String LEADER_EMAIL_CLS = "incompleteTeamsPage-team-leader-email";
    public static final String TEAM_MEMBER_ROLE_CLS = "incompleteTeamsPage-team-role-aggregation";
    public static final String TEAM_SIZE_CLS = "incompleteTeamsPage-team-teamSize";
    public static final String TEAM_PROFILE_CLS = "incompleteTeamsPage-team-profile";

    @FindBy(id = TEAM_DIV)
    private List<WebElement> teamDiv;

    public HashMap<String, IncompleteTeam> getIncompleteTeams() {
        WebElement element = getElement(teamDiv, TEAM_DIV);

        List<WebElement> incompleteTeamList = element.findElements(By.className(TEAM_CARD_CLS));
        HashMap<String, IncompleteTeam> map = new HashMap<>();
        for (WebElement e : incompleteTeamList) {

            String name = e.findElement(By.className(TEAM_NAME_CLS)).getText();
            String teamSizeStr = e.findElement(By.className(TEAM_SIZE_CLS)).getText();
            int teamSize = Integer.parseInt(teamSizeStr);
            String leaderName = e.findElement(By.className(LEADER_NAME_CLS)).getText();
            String leaderEmail = e.findElement(By.className(LEADER_EMAIL_CLS)).getText();

            List<WebElement> tagsList = e.findElements(By.className(TEAM_MEMBER_ROLE_CLS));
            
            List<String> teamMemberRoles = new ArrayList<>();
            for (WebElement tagElement : tagsList) {
                String[] data = tagElement.getText().split("x ");
                if (data.length != 2) {
                    Fail.failTestDueToWrongValue("Team = " + name + " ,TEAM_MEMBER_ROLE_CLS", "wrong value of member role aggregation");
                    throw new IllegalStateException("Invalid values in team member role field");
                }
                int roleCount = Integer.parseInt(data[0]);
                String role = data[1];
                for (int i = 0; i < roleCount; i++){
                    teamMemberRoles.add(role);
                }
            }

            Set<String> teamProfile = new HashSet<>();
            List<WebElement> profileE = e.findElements(By.className(TEAM_PROFILE_CLS));
            profileE.forEach(el -> teamProfile.add(el.getText()));

            //Assignment assignment = new Assignment(name,desc, teamSize, timeNeeded, mentor, owner, tags, button);
            IncompleteTeam incompleteTeam = new IncompleteTeam(name,leaderName,leaderEmail,teamMemberRoles,teamSize,teamProfile);
            map.put(name, incompleteTeam);
        }
        return map;
    }
}
