package pstsp.support.pageobjects.mentoredprojects;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.Table;
import pstsp.support.services.entities.MentUpcomingMeeting;
import pstsp.support.services.entities.TeamStateTableRow;
import pstsp.support.test_utils.Fail;

import java.util.ArrayList;
import java.util.List;
/**
 * Mentored projects page
 * Mentor
 * @author David Kuta
 */
public class Mentored_Projects_Page extends PageObject {
    public static final String PAGE_ID = "mentoredProjectsPage-default-title";
    public static final String MENTORER_PROJECTS_TBL = "mentoredProjectsPage-projects-table";
    public static final String UPCOMING_MEETINGS_TBL = "mentoredProjectsPage-meetings-table";

    @FindBy(id = PAGE_ID)
    private List<WebElement> title;

    public String getMentorNameFromGarantView(){
        WebElement element = getElement(title,PAGE_ID);
        String[] parts = element.getText().split("-");
        return parts[0].strip();
    }

    @FindBy(id = MENTORER_PROJECTS_TBL)
    private List<WebElement> mentoredProjectsTable;

    public List<TeamStateTableRow> getMentoredProjectsTable() {

        WebElement element = getElement(mentoredProjectsTable, MENTORER_PROJECTS_TBL);
        List<TeamStateTableRow> tableContent = new ArrayList<>();
        List<List<WebElement>> rawTable = Table.getTableContent(element);


        for (List<WebElement> elementList : rawTable) {

            if(elementList.size() != 5) continue;

            TeamStateTableRow row = new TeamStateTableRow();
            for (int i = 0; i < elementList.size(); i++) {
                switch (i) {
                    case 0: {
                        row.setProject(elementList.get(i).findElement(By.tagName("a")));
                        break;
                    }
                    case 1: {
                        row.setTeam(elementList.get(i).findElement(By.tagName("a")));
                        break;
                    }
                    case 2: {
                        WebElement progress = elementList.get(i).findElement(By.className("progress"));
                        int minCritGreen = Integer.parseInt(progress.findElement(By.className("bg-success")).getText());
                        int minCritOrange = Integer.parseInt(progress.findElement(By.className("bg-warning")).getText());
                        int minCritRed = Integer.parseInt(progress.findElement(By.className("bg-danger")).getText());
                        row.setMinCritGreen(minCritGreen);
                        row.setMinCritOrange(minCritOrange);
                        row.setMinCritRed(minCritRed);
                        break;
                    }
                    case 3: {
                        WebElement progress = elementList.get(i).findElement(By.className("progress"));
                        int prjStateGreen = Integer.parseInt(progress.findElement(By.className("bg-success")).getText());
                        int prjStateOrange = Integer.parseInt(progress.findElement(By.className("bg-warning")).getText());
                        int prjStateRed = Integer.parseInt(progress.findElement(By.className("bg-danger")).getText());
                        row.setPrjStateGreen(prjStateGreen);
                        row.setPrjStateOrange(prjStateOrange);
                        row.setPrjStateRed(prjStateRed);
                        break;
                    }
                    case 4: {
                        String date = elementList.get(i).getText();
                        row.setDate(date);
                    }
                }
            }

            if (elementList.size() > 0) {
                tableContent.add(row);

            }
        }
        return tableContent;
    }

    @FindBy(id = UPCOMING_MEETINGS_TBL)
    private List<WebElement> upcomingMeetingsTbl;

    public List<MentUpcomingMeeting> getAllUpcomingMeetings() {
        WebElement table = getElement(upcomingMeetingsTbl, UPCOMING_MEETINGS_TBL);
        Click.scrollToElement(table);
        List<List<WebElement>> a = Table.getTableContent(table);
        List<MentUpcomingMeeting> meetings = new ArrayList<>();

        for (List<WebElement> row : a) {
            MentUpcomingMeeting meeting = new MentUpcomingMeeting();
            for (int i = 0; i < row.size(); i++) {
                switch (i) {
                    case 0: {
                        try {
                            meeting.setDatetime(row.get(i).getText().strip());
                        } catch (Exception e) {
                            Fail.failTestDueToMissingTextInTable(UPCOMING_MEETINGS_TBL, "Missing datetime in correct format");
                        }
                        break;
                    }
                    case 1: {
                        meeting.setRoom(row.get(i).getText().strip());
                        break;
                    }
                    case 2: {
                        meeting.setTopic(row.get(i).getText());
                        break;
                    }
                    case 3: {
                        meeting.setProject(row.get(i).findElement(By.tagName("a")));
                        break;
                    }
                }
            }
            if (row.size() > 0) {
                meetings.add(meeting);
            }
        }
        return meetings;
    }
}
