package pstsp.support.pageobjects.project;

import org.openqa.selenium.Keys;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.devtools.v85.page.Page;
import org.openqa.selenium.support.FindBy;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;

import java.util.List;
/**
 * Edit project links page
 * Leader
 * @author David Kuta
 */
public class Edit_Links_Page extends PageObject {

    public static final String PAGE_ID = "projectPage-editLinks-title";
    public static final String STORAGE_INPUT = "frm-editLinksForm-prj_storage";
    public static final String MANAGEMENT_INPUT = "frm-editLinksForm-project_management";
    public static final String PRODUCTION_INPUT = "frm-editLinksForm-app_production";
    public static final String OTHER_INPUT = "frm-editLinksForm-other_links";
    public static final String SUBMIT_BUTTON = "frm-projectLinksForm-submit";
    public static final String CANCEL_BUTTON = "frm-projectLinksForm-cancel";

    ////////////////////////////////////////////////////////////////
    ///  Warning: all texts serve for external testing purposses ///
    ////////////////////////////////////////////////////////////////

    // Texts on web page
    public static final String TXT_SUBMIT_BUTTON = "Potvrdit změny";
    public static final String TXT_CANCEL_BUTTON = "Zrušit";
    // placeholders' texts on web page
    public static final String TXT_STORAGE_INPUT_PLACEHOLDER = "Vložte odkaz";
    public static final String TXT_MANAGEMENT_INPUT_PLACEHOLDER = "Vložte odkaz";
    public static final String TXT_PRODUCTION_INPUT_PLACEHOLDER = "Vložte odkaz";
    public static final String TXT_OTHER_INPUT_PLACEHOLDER = "Vložte odkazy ve tvaru\n" +
            "<nazev>;url\n" +
            "<nazev>;url";

    @FindBy(id = STORAGE_INPUT)
    private List<WebElement> storageInput;

    /**
     * Get storage input placeholder text
     *
     * @return storage input placeholder text
     */
    public String getStorageInputPlaceholderText() {
        String text = getElement(storageInput, STORAGE_INPUT).getAttribute("placeholder").trim();
        return text;
    }

    /**
     * Get storage link
     *
     * @return storage link
     */
    public String getStorage() {
        String text = getElement(storageInput, STORAGE_INPUT).getAttribute("value").trim();
        return text;
    }

    /**
     * Check storage link input enabled
     *
     * @return true = enabled, false = disabled
     */
    public boolean isStorageEnabled() {
        return getElement(storageInput, STORAGE_INPUT).isEnabled();
    }

    /**
     * Set storage link
     *
     * @param storage new storage link
     */
    public void setStorage(String storage) {
        WebElement element = getElement(storageInput, STORAGE_INPUT);
        element.clear();
        element.sendKeys(storage);
    }

    ////////////

    @FindBy(id = MANAGEMENT_INPUT)
    private List<WebElement> managementInput;

    /**
     * Get management input placeholder text
     *
     * @return management input placeholder text
     */
    public String getManagementInputPlaceholderText() {
        String text = getElement(managementInput, MANAGEMENT_INPUT).getAttribute("placeholder").trim();
        return text;
    }

    /**
     * Get management link
     *
     * @return management link
     */
    public String getManagement() {
        String text = getElement(managementInput, MANAGEMENT_INPUT).getAttribute("value").trim();
        return text;
    }

    /**
     * Check management link input enabled
     *
     * @return true = enabled, false = disabled
     */
    public boolean isManagementEnabled() {
        return getElement(managementInput, MANAGEMENT_INPUT).isEnabled();
    }

    /**
     * Set management link
     *
     * @param management new management link
     */
    public void setManagement(String management) {
        WebElement element = getElement(managementInput, MANAGEMENT_INPUT);
        element.clear();
        element.sendKeys(management);
    }

    ////////////

    @FindBy(id = PRODUCTION_INPUT)
    private List<WebElement> productionInput;

    /**
     * Get production input placeholder text
     *
     * @return production input placeholder text
     */
    public String getProductionInputPlaceholderText() {
        String text = getElement(productionInput, PRODUCTION_INPUT).getAttribute("placeholder").trim();
        return text;
    }

    /**
     * Get production link
     *
     * @return production link
     */
    public String getProduction() {
        String text = getElement(productionInput, PRODUCTION_INPUT).getAttribute("value").trim();
        return text;
    }

    /**
     * Check production link input enabled
     *
     * @return true = enabled, false = disabled
     */
    public boolean isProductionEnabled() {
        return getElement(productionInput, PRODUCTION_INPUT).isEnabled();
    }

    /**
     * Set production link
     *
     * @param production new production link
     * @return EditLinksPage for chain commands
     */
    public void setProduction(String production) {
        WebElement element = getElement(productionInput, PRODUCTION_INPUT);
        element.clear();
        element.sendKeys(production);
    }

    ////////////

    @FindBy(id = OTHER_INPUT)
    private List<WebElement> otherInput;

    /**
     * Get other input placeholder text
     *
     * @return other input placeholder text
     */
    public String getOtherInputPlaceholderText() {
        String text = getElement(otherInput, OTHER_INPUT).getAttribute("placeholder").trim();
        return text;
    }

    /**
     * Get other link
     *
     * @return other link
     */
    public String getOther() {
        String text = getElement(otherInput, OTHER_INPUT).getAttribute("value").trim();
        return text;
    }

    /**
     * Check other link input enabled
     *
     * @return true = enabled, false = disabled
     */
    public boolean isOtherEnabled() {
        return getElement(otherInput, OTHER_INPUT).isEnabled();
    }

    /**
     * Set other link
     *
     * @param other new production link
     * @return EditLinksPage for chain commands
     */
    public void setOther(List<String> other) {
        WebElement element = getElement(otherInput, OTHER_INPUT);
        element.clear();
        other.forEach(el -> {
            element.sendKeys(el);
            element.sendKeys(Keys.ENTER);
        });
    }

    ////////////

    @FindBy(id = CANCEL_BUTTON)
    private List<WebElement> cancelButton;

    /**
     * Get submit button text
     *
     * @return submit button text
     */
    public String getCancelButtonText() {
        String text = getElement(cancelButton, CANCEL_BUTTON).getText().trim();
        return text;
    }

    /**
     * Check submit button enabled
     *
     * @return true = enabled, false = disabled
     */
    public boolean isCancelButtonEnabled() {
        return getElement(cancelButton, CANCEL_BUTTON).isEnabled();
    }

    /**
     * Performs sumbit of link form.
     *
     */
    public void clickOnCancelButton() {
        Click.clickAndWaitId(getElement(cancelButton, CANCEL_BUTTON),
                Project_Page.PAGE_ID);
    }

    ////////////

    @FindBy(id = SUBMIT_BUTTON)
    private List<WebElement> submitButton;

    /**
     * Get cancel button text
     *
     * @return submit button text
     */
    public String getSubmitCancelText() {
        String text = getElement(submitButton, SUBMIT_BUTTON).getText().trim();
        return text;
    }

    /**
     * Check cancel button enabled
     *
     * @return true = enabled, false = disabled
     */
    public boolean isSubmitCancelEnabled() {
        return getElement(submitButton, SUBMIT_BUTTON).isEnabled();
    }

    /**
     * Performs cancel action of link form.
     *
     */
    public void clickOnSubmitButton() {
        Click.clickAndWaitId(getElement(submitButton, SUBMIT_BUTTON),
                Const.BASE_TITLE_ID);
    }

}
