package pstsp.support.pageobjects.project;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.Table;
import pstsp.support.services.entities.ProjectLink;
import pstsp.support.services.entities.ProjectTableRow;
import pstsp.support.services.entities.storage.ProjectTable;
import pstsp.support.test_utils.Fail;

import java.util.ArrayList;
import java.util.List;
/**
 * Project page from mentor view
 * Mentor
 * @author David Kuta
 */
public class Mentor_View_On_Project_Page extends PageObject {

    public static final String PAGE_ID = "projectPage-showProject-title";

    public static final String MINIMAL_CRITERIA_TABLE = "projectPage-minimalCriteria-table";
    public static final String PROJECT_STATE_TABLE = "projectPage-projectState-table";
    public static final String PROJECT_USED_EXP_TABLE = "projectPage-usedExp-table";

    //classes
    public static final String DISABLED_ACTION = "projectPage-table-action-disabled";

    //colors for identify color and choice

    public static final String MIN_CRIT_MENTOR_TOGGLE_PREF = "projectPage-minimalCriteria-table-mentor-toggle-";

    public static final String USED_EXP_MENTOR_TOGGLE_PREF = "projectPage-usedExp-table-mentor-toggle-";

    public static final String PROJ_STATE_MENTOR_TOGGLE_PREF = "projectPage-projectState-table-mentor-toggle-";


    //info btn prefixes
    public static final String MIN_CRIT_MENTOR_INFO_PREF = "projectPage-minimalCriteria-mentor-infoBtn-";
    public static final String USED_EXP_MENTOR_INFO_PREF = "projectPage-usedExp-mentor-infoBtn-";

    public static final String PROJ_STATE_MENTOR_INFO_PREF = "projectPage-projectState-mentor-infoBtn-";

    @FindBy(id = MINIMAL_CRITERIA_TABLE)
    private List<WebElement> minimalCriteriaTable;

    @FindBy(id = PROJECT_USED_EXP_TABLE)
    private List<WebElement> usedExpTable;

    @FindBy(id = PROJECT_STATE_TABLE)
    private List<WebElement> projectStateTable;

    public ProjectTable getMinimalCriteriaMentorTable() {
        return getMentorTable(MINIMAL_CRITERIA_TABLE);
    }

    public ProjectTable getUsedExpMentorTable() {
        return getMentorTable(PROJECT_USED_EXP_TABLE);
    }

    public ProjectTable getProjectStateMentorTable() {
        return getMentorTable(PROJECT_STATE_TABLE);
    }

    private ProjectTable getMentorTable(String tableType) {
        WebElement element;
        final String toggleTypePref;
        final String infoTypePref;
        switch (tableType) {
            case MINIMAL_CRITERIA_TABLE: {
                element = getElement(minimalCriteriaTable, MINIMAL_CRITERIA_TABLE);
                toggleTypePref = MIN_CRIT_MENTOR_TOGGLE_PREF;
                infoTypePref = MIN_CRIT_MENTOR_INFO_PREF;
                break;
            }
            case PROJECT_USED_EXP_TABLE: {
                element = getElement(usedExpTable, PROJECT_USED_EXP_TABLE);
                toggleTypePref = USED_EXP_MENTOR_TOGGLE_PREF;
                infoTypePref = USED_EXP_MENTOR_INFO_PREF;
                break;
            }
            case PROJECT_STATE_TABLE: {
                element = getElement(projectStateTable, PROJECT_STATE_TABLE);
                toggleTypePref = PROJ_STATE_MENTOR_TOGGLE_PREF;
                infoTypePref = PROJ_STATE_MENTOR_INFO_PREF;
                break;
            }
            default: {
                Fail.failTestDueToProblemInOracleStorage("Unknown table definition.");
                return null;
            }
        }


        List<List<WebElement>> tableContent = Table.getTableContent(element);

        List<ProjectTableRow> result = new ArrayList<>();
        int tableRowCnt = 0;
        for (List<WebElement> row : tableContent) {
            ProjectTableRow contentRow = new ProjectTableRow();
            for (int i = 0; i < row.size(); i++) {
                if (tableType.equals(PROJECT_USED_EXP_TABLE)) {

                    if(row.size() != 4) continue;

                    switch (i) {
                        case 0: {
                            contentRow.setStepName(row.get(i).getText());
                            break;
                        }
                        case 1:{
                            contentRow.setOtherTextInfo(row.get(i).getText());
                            break;
                        }
                        case 2: {
                            String color = row.get(i).findElement(By.className(DISABLED_ACTION)).getAttribute("data-colorvalue");
                            contentRow.setOtherButtonColor(color.split("-")[1]);
                            break;
                        }
                        case 3: {
                            String color = row.get(i).findElement(By.id(infoTypePref + tableRowCnt)).getAttribute("data-colorvalue");
                            WebElement toggle = row.get(i).findElement(By.id(toggleTypePref + tableRowCnt));
                            contentRow.setChangeButtonColor(color.split("-")[1]);
                            contentRow.setChangeButtonToggle(toggle);
                        }
                    }


                } else {

                    if(row.size() != 3) continue;

                    switch (i) {
                        case 0: {
                            contentRow.setStepName(row.get(i).getText());
                            break;
                        }
                        case 1: {
                            String color = row.get(i).findElement(By.className(DISABLED_ACTION)).getAttribute("data-colorvalue");
                            contentRow.setOtherButtonColor(color.split("-")[1]);
                            break;
                        }
                        case 2: {
                            String color = row.get(i).findElement(By.id(infoTypePref + tableRowCnt)).getAttribute("data-colorvalue");
                            WebElement toggle = row.get(i).findElement(By.id(toggleTypePref + tableRowCnt));
                            contentRow.setChangeButtonColor(color.split("-")[1]);
                            contentRow.setChangeButtonToggle(toggle);
                        }
                    }
                }

            }
            if (row.size() > 0) {
                result.add(contentRow);
                tableRowCnt++;
            }
        }

        return new ProjectTable(result, tableType, Const.ROLE_MENTOR);
    }



}
