package pstsp.support.pageobjects.project;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.pageobjects.teammanagement.Team_Manag_Edit_Defence_Modal_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.Table;
import pstsp.support.services.entities.DefenceInfo;
import pstsp.support.services.entities.ProjectLink;
import pstsp.support.services.entities.ProjectTableRow;
import pstsp.support.services.entities.storage.ProjectTable;
import pstsp.support.test_utils.Fail;
import pstsp.support.tools.Drivers;

import java.util.ArrayList;
import java.util.List;
/**
 * Project page
 * Leader
 * @author David Kuta
 */
public class Project_Page extends PageObject {

    public static final String PAGE_ID = "projectPage-showProject-title";

    public static final String MINIMAL_CRITERIA_TABLE = "projectPage-minimalCriteria-table";
    public static final String PROJECT_STATE_TABLE = "projectPage-projectState-table";
    public static final String PROJECT_USED_EXP_TABLE = "projectPage-usedExp-table";
    public static final String EDIT_LINKS_BTN = "projectPage-projectInfo-card-url-edit";
    public static final String REQ_URL_LIST = "projectPage-projectInfo-card-reqUrl-list";
    public static final String OPT_URL_LIST = "projectPage-projectInfo-card-optUrl-list";
    public static final String ADD_USED_EXP_BUTTON = "projectPage-usedExp-table-addExpButton";
    public static final String ASSIGNMENT_NAME = "projectPage-projectInfo-card-assignment-name";
    public static final String TEAM_NAME = "projectPage-projectInfo-card-team-name";

    public static final String CREDIT_TSP1_DATE = "projectPage-projectInfo-creditTsp1";
    public static final String CREDIT_TSP2_DATE = "projectPage-projectInfo-creditTsp2";

    public static final String DEFENCE_CARD = "projectPage-projectInfo-card-defence";
    public static final String DEFENCE_ATTEMPT_PREF = "projectPage-projectInfo-card-defence-attempt-";
    public static final String DEFENCE_DATE_PREF = "projectPage-projectInfo-card-defence-date-";
    public static final String DEFENCE_RESULT_PREF = "projectPage-projectInfo-card-defence-result-";

    //classes
    public static final String ACTION_TOGGLE = "projectPage-table-action-toggle";
    public static final String DISABLED_ACTION = "projectPage-table-action-disabled";
    public static final String INFO_COLOR_BTN = "projectPage-table-infoBtn";

    //colors for identify color and choice

    public static final String MIN_CRIT_LEADER_TOGGLE_PREF = "projectPage-minimalCriteria-table-leader-toggle-";

    public static final String USED_EXP_LEADER_TOGGLE_PREF = "projectPage-usedExp-table-leader-toggle-";

    public static final String PROJ_STATE_LEADER_TOGGLE_PREF = "projectPage-projectState-table-leader-toggle-";

    //info btn prefixes
    public static final String MIN_CRIT_LEADER_INFO_PREF = "projectPage-minimalCriteria-leader-infoBtn-";

    public static final String USED_EXP_LEADER_INFO_PREF = "projectPage-usedExp-leader-infoBtn-";

    public static final String PROJ_STATE_LEADER_INFO_PREF = "projectPage-projectState-leader-infoBtn-";

    @FindBy(id = MINIMAL_CRITERIA_TABLE)
    private List<WebElement> minimalCriteriaTable;

    @FindBy(id = PROJECT_USED_EXP_TABLE)
    private List<WebElement> usedExpTable;

    @FindBy(id = PROJECT_STATE_TABLE)
    private List<WebElement> projectStateTable;

    public ProjectTable getMinimalCriteriaLeaderTable() {
        return getLeaderTable(MINIMAL_CRITERIA_TABLE);
    }

    public ProjectTable getUsedExpLeaderTable() {
        return getLeaderTable(PROJECT_USED_EXP_TABLE);
    }

    public ProjectTable getProjectStateLeaderTable() {
        return getLeaderTable(PROJECT_STATE_TABLE);
    }

    private ProjectTable getLeaderTable(String tableType) {
        WebElement element;
        final String toggleTypePref;
        final String infoTypePref;
        switch (tableType) {
            case MINIMAL_CRITERIA_TABLE: {
                element = getElement(minimalCriteriaTable, MINIMAL_CRITERIA_TABLE);
                toggleTypePref = MIN_CRIT_LEADER_TOGGLE_PREF;
                infoTypePref = MIN_CRIT_LEADER_INFO_PREF;
                break;
            }
            case PROJECT_USED_EXP_TABLE: {
                element = getElement(usedExpTable, PROJECT_USED_EXP_TABLE);
                toggleTypePref = USED_EXP_LEADER_TOGGLE_PREF;
                infoTypePref = USED_EXP_LEADER_INFO_PREF;
                break;
            }
            case PROJECT_STATE_TABLE: {
                element = getElement(projectStateTable, PROJECT_STATE_TABLE);
                toggleTypePref = PROJ_STATE_LEADER_TOGGLE_PREF;
                infoTypePref = PROJ_STATE_LEADER_INFO_PREF;
                break;
            }
            default: {
                Fail.failTestDueToProblemInOracleStorage("Unknown table definition.");
                return null;
            }
        }


        List<List<WebElement>> tableContent = Table.getTableContent(element);

        List<ProjectTableRow> result = new ArrayList<>();
        int tableRowCnt = 0;
        for (List<WebElement> row : tableContent) {
            ProjectTableRow contentRow = new ProjectTableRow();
            for (int i = 0; i < row.size(); i++) {
                if (tableType.equals(PROJECT_USED_EXP_TABLE)) {
                    if(row.size() != 4) continue;
                    switch (i) {
                        case 0: {
                            contentRow.setStepName(row.get(i).getText());
                            break;
                        }
                        case 1:{
                            contentRow.setOtherTextInfo(row.get(i).getText());
                            break;
                        }
                        case 2: {
                            String color = row.get(i).findElement(By.id(infoTypePref + tableRowCnt)).getAttribute("data-colorvalue");
                            WebElement toggle = row.get(i).findElement(By.id(toggleTypePref + tableRowCnt));
                            contentRow.setChangeButtonColor(color.split("-")[1]);
                            contentRow.setChangeButtonToggle(toggle);
                            break;
                        }
                        case 3: {
                            String color = row.get(i).findElement(By.className(DISABLED_ACTION)).getAttribute("data-colorvalue");
                            contentRow.setOtherButtonColor(color.split("-")[1]);
                        }
                    }


                } else {
                    if(row.size() != 3) continue;
                    switch (i) {

                        case 0: {
                            contentRow.setStepName(row.get(i).getText());
                            break;
                        }
                        case 1: {
                            String color = row.get(i).findElement(By.id(infoTypePref + tableRowCnt)).getAttribute("data-colorvalue");
                            WebElement toggle = row.get(i).findElement(By.id(toggleTypePref + tableRowCnt));
                            contentRow.setChangeButtonColor(color.split("-")[1]);
                            contentRow.setChangeButtonToggle(toggle);
                            break;
                        }
                        case 2: {
                            String color = row.get(i).findElement(By.className(DISABLED_ACTION)).getAttribute("data-colorvalue");
                            contentRow.setOtherButtonColor(color.split("-")[1]);
                        }
                    }
                }

            }
            if (row.size() > 0) {
                result.add(contentRow);
                tableRowCnt++;
            }
        }

        return new ProjectTable(result, tableType, Const.ROLE_LEADER);
    }


    @FindBy(id = EDIT_LINKS_BTN)
    private List<WebElement> editLinksBtn;

    public Edit_Links_Page clickOnEditLinksBtn(){
        WebElement link = getElement(editLinksBtn, EDIT_LINKS_BTN);
        Click.clickAndWaitId(link, Edit_Links_Page.PAGE_ID);
        return new Edit_Links_Page();
    }

    @FindBy(id = ADD_USED_EXP_BUTTON)
    private List<WebElement> addUsedExpBTN;


    public Project_Page_Add_Exp_Modal openAddExpModal(){
        WebElement link = getElement(addUsedExpBTN, ADD_USED_EXP_BUTTON);
        Click.clickAndWaitId(link, Project_Page_Add_Exp_Modal.ID);
        return new Project_Page_Add_Exp_Modal();
    }

    @FindBy(id = REQ_URL_LIST)
    private List<WebElement> requieredLinks;

    public List<ProjectLink> getRequiredLinks(){
        WebElement element = getElement(requieredLinks, REQ_URL_LIST);
        List<WebElement> liItems = element.findElements(By.className("list-group-item"));
        List<ProjectLink> links = new ArrayList<>();
        liItems.forEach(a -> links.add(new ProjectLink(a.getText(),a.getAttribute("href"))));
        return links;
    }

    @FindBy(id = OPT_URL_LIST)
    private List<WebElement> optionalLinks;

    public List<ProjectLink> getOptionalLinks(){
        WebElement element = getElement(optionalLinks, OPT_URL_LIST);
        List<WebElement> liItems = element.findElements(By.className("list-group-item"));
        List<ProjectLink> links = new ArrayList<>();
        liItems.forEach(a -> links.add(new ProjectLink(a.getText(),a.getAttribute("href"))));
        return links;
    }

    @FindBy(id = ASSIGNMENT_NAME)
    private List<WebElement> assignmentName;

    public String getAssignmentName(){
        WebElement element = getElement(assignmentName, ASSIGNMENT_NAME);
        return element.getText().strip();
    }

    @FindBy(id = TEAM_NAME)
    private List<WebElement> teamName;

    public String getTeamName(){
        WebElement element = getElement(teamName, TEAM_NAME);
        return element.getText().strip();
    }


    ///
    @FindBy(id = CREDIT_TSP1_DATE)
    private List<WebElement> credit1Date;

    @FindBy(id = CREDIT_TSP2_DATE)
    private List<WebElement> credit2Date;



    public String getCredit1Date(){
        if(credit1Date.size() > 0) {
            WebElement dateDT = getElement(credit1Date, CREDIT_TSP1_DATE);
            String[] dateParts = dateDT.getText().strip().split("\\. ");

            return dateParts[0] + dateParts[1] + dateParts[2];
        }
        else
            return "";
    }

    public String getCredit2Date(){
        if(credit2Date.size() > 0) {
            WebElement dateDT = getElement(credit2Date, CREDIT_TSP2_DATE);
            String[] dateParts = dateDT.getText().strip().split("\\. ");

            return dateParts[0] + dateParts[1] + dateParts[2];
        }
        else
            return "";
    }



    @FindBy(id = DEFENCE_CARD)
    private List<WebElement> defenceCard;


    public List<DefenceInfo> getAllDefences() {
        List<DefenceInfo> result = new ArrayList<>();
        if (defenceCard.size() > 0) {
            WebElement elementCard = getElement(defenceCard, DEFENCE_CARD);
            int defenceCount = Integer.parseInt(elementCard.getAttribute("data-defencecnt"));
            for (int i = 0; i < defenceCount; i++) {
                WebElement attempt = Drivers.getDriver().findElement(By.id(DEFENCE_ATTEMPT_PREF+i));
                int attemptNumber = Integer.parseInt(attempt.getText().strip());
                WebElement date = Drivers.getDriver().findElement(By.id(DEFENCE_DATE_PREF + i));
                WebElement defResult = Drivers.getDriver().findElement(By.id(DEFENCE_RESULT_PREF + i));
                result.add(new DefenceInfo(attemptNumber, date.getText(), defResult.getText()));

            }
        }

        return result;
    }


}
