package pstsp.support.pageobjects.tagsmanagement;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.Table;
import pstsp.support.services.entities.InterrestedTopicMentorTableRow;
import pstsp.support.services.entities.TagTableRow;
import pstsp.support.test_utils.Fail;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;
/**
 * Tag management page
 * Garant
 * @author David Kuta
 */
public class TagsManagement_Page extends PageObject {
    public static final String PAGE_ID = "tagManagementPage-default-title";
    public static final String TEAM_PROFLIE_TABLE = "tagManagementPage-teamProfileTable";
    public static final String TEAM_ROLE_TABLE = "tagManagementPage-teamRoleTable";
    public static final String ADD_TEAM_PROFILE_BTN = "tagManagementPage-teamProfileTable-addBtn";
    public static final String TAG_STATUS = "tagManagementPage-tag-status";
    public static final String ADD_TEAM_ROLE_BTN = "tagManagementPage-teamRoleTable-addBtn";


    public static final String AVAILABLE_TAG_TEXT = "Štítek je dostupný pro užití.";
    public static final String NOT_AVAILABLE_TAG_TEXT = "Štítek již nebude možné nově použít.";

    @FindBy(id = TEAM_PROFLIE_TABLE)
    private List<WebElement> teamProfileTable;

    public List<TagTableRow> getTeamProfileTagTable(){
        WebElement tableEl = getElement(teamProfileTable, TEAM_PROFLIE_TABLE);
        List<List<WebElement>> tableContent = Table.getTableContent(tableEl);
        List<TagTableRow> result = new ArrayList<>();
        for (List<WebElement> row : tableContent) {

            if(row.size() != 3) continue;

            TagTableRow semiResult = new TagTableRow();
            for (int i = 0; i < row.size(); i++) {
                switch (i) {
                    case 0: {
                        String tagText = row.get(i).getText().strip();
                        semiResult.setTagText(tagText);
                        semiResult.setTagColor("danger");
                        break;
                    }
                    case 1: {
                        WebElement tagStatus = row.get(i).findElement(By.className(TAG_STATUS));
                        String statusToggleText = tagStatus.getAttribute("data-original-title");
                        boolean accessible = statusToggleText.equals(AVAILABLE_TAG_TEXT);
                        semiResult.setAccesible(accessible);
                        break;
                    }
                    case 2: {
                        WebElement editButton = row.get(i).findElement(By.tagName("a"));
                        semiResult.setEditButton(editButton);
                        break;
                    }

                }

            }
            if(row.size()>0){
                result.add(semiResult);
            }

        }
        return result;
    }

    @FindBy(id = TEAM_ROLE_TABLE)
    private List<WebElement> teamRoleTable;

    public List<TagTableRow> getTeamRoleTagTable(){
        WebElement tableEl = getElement(teamRoleTable, TEAM_ROLE_TABLE);
        List<List<WebElement>> tableContent = Table.getTableContent(tableEl);
        List<TagTableRow> result = new ArrayList<>();
        for (List<WebElement> row : tableContent) {

            if(row.size() != 3) continue;

            TagTableRow semiResult = new TagTableRow();
            for (int i = 0; i < row.size(); i++) {
                switch (i) {
                    case 0: {
                        String tagText = row.get(i).getText().strip();
                        semiResult.setTagText(tagText);
                        String text = row.get(i).findElement(By.tagName("span")).getAttribute("data-colorvalue");
                        semiResult.setTagColor(text.split("-")[1]);
                        break;
                    }
                    case 1: {
                        WebElement tagStatus = row.get(i).findElement(By.className(TAG_STATUS));
                        String statusToggleText = tagStatus.getAttribute("data-original-title");
                        boolean accessible = statusToggleText.equals(AVAILABLE_TAG_TEXT);
                        semiResult.setAccesible(accessible);
                        break;
                    }
                    case 2: {
                        WebElement editButton = row.get(i).findElement(By.tagName("a"));
                        semiResult.setEditButton(editButton);
                        break;
                    }

                }

            }
            if(row.size()>0){
                result.add(semiResult);
            }

        }
        return result;
    }

    @FindBy(id = ADD_TEAM_ROLE_BTN)
    private List<WebElement> addTeamRoleBTN;

    public Team_Role_Tag_Create_Modal clickOnAddTeamRoleBTN(){
        WebElement element = getElement(addTeamRoleBTN, ADD_TEAM_ROLE_BTN);
        Click.clickAndWaitId(element, Team_Role_Tag_Create_Modal.PAGE_ID);
        return new Team_Role_Tag_Create_Modal();
    }

    @FindBy(id = ADD_TEAM_PROFILE_BTN)
    private List<WebElement> addTeamProfile;

    public Team_Profile_Tag_Create_Modal clickOnAddTeamProfileBTN(){
        WebElement element = getElement(addTeamProfile, ADD_TEAM_PROFILE_BTN);
        Click.clickAndWaitId(element, Team_Profile_Tag_Create_Modal.PAGE_ID);
        return new Team_Profile_Tag_Create_Modal();
    }

}
