package pstsp.support.pageobjects.tagsmanagement;

import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.ui.Select;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.pageobjects.assignmentmanagement.Assignment_Management_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.Utils;

import java.util.HashSet;
import java.util.List;
import java.util.Set;
/**
 * Team role tag form page, using when editing and creating
 * Garant
 * @author David Kuta
 */
public class Team_Role_Tag_Form_Page extends PageObject {
    public static final String NAME_T = "frm-teamRoleAddForm-label";
    public static final String COLOR_S = "frm-teamRoleAddForm-roleColor";
    public static final String CAN_USE_CHCK = "frm-teamRoleAddForm-canUse";
    public static final String SUBMIT_BTN = "frm-teamRoleAddForm-submit";
    public static final String CANCEL_BTN = "frm-teamRoleAddForm-cancel";

    @FindBy(id = NAME_T)
    private List<WebElement> nameT;

    @FindBy(id = COLOR_S)
    public List<WebElement> colorS;

    @FindBy(id = CAN_USE_CHCK)
    public List<WebElement> canUseChck;

    @FindBy(id = CANCEL_BTN)
    private List<WebElement> cancelBTN;

    @FindBy(id = SUBMIT_BTN)
    private List<WebElement> submitBTN;

    public void setName(String name) {
        WebElement element = getElement(nameT, NAME_T);
        element.clear();
        element.sendKeys(name);
    }

    public String getName() {
        WebElement element = getElement(nameT, NAME_T);
        return element.getAttribute("value");
    }

    public void setColor(String color) {
        WebElement element = getElement(colorS, COLOR_S);
        Select select = new Select(element);
        select.selectByVisibleText(color);
    }

    public String getColor() {
        WebElement element = getElement(colorS, COLOR_S);
        Select select = new Select(element);
        Set<String> selectedOptions = new HashSet<>();
        return select.getAllSelectedOptions().get(0).getText().strip();
    }

    public Set<String> getAllColors() {
        WebElement element = getElement(colorS, COLOR_S);
        Select select = new Select(element);
        Set<String> allOptions = new HashSet<>();
        select.getOptions().forEach(option -> allOptions.add(option.getText().strip()));
        return allOptions;
    }

    public void setCanUSe(boolean set) {
        WebElement element = getElement(canUseChck, CAN_USE_CHCK);
        Utils.setCheckBox(element,set);
    }

    public boolean getCanUSe() {
        WebElement element = getElement(canUseChck, CAN_USE_CHCK);
        return element.isSelected();
    }


    public void clickOnSubmitBTN(){
        WebElement button = getElement(submitBTN, SUBMIT_BTN);
        Click.clickAndWaitId(button, Const.BASE_TITLE_ID);
    }

    public void clickOnBackBTN(){
        WebElement button = getElement(cancelBTN, CANCEL_BTN);
        Click.clickAndWaitId(button, TagsManagement_Page.PAGE_ID);
    }
}
