package pstsp.support.pageobjects.team;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.ui.Select;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;
import pstsp.support.tools.Drivers;

import java.util.HashSet;
import java.util.List;
import java.util.Set;
/**
 * Team page - Edit team roles page
 * Leader
 * @author David Kuta
 */
public class Edit_Team_Roles_Page extends PageObject {

    public static final String PAGE_ID = "teamPage-editTeamPosition-title";
    public static final String ROLES_PREFIX_SELECT = "frm-studentAdvancesForm-members";
    public static final String SUBMIT_BTN = "frm-studentAdvancesForm-submit";
    public static final String BACK_BTN = "frm-studentAdvancesForm-cancel";
    private final int teamMembersCount;

    public Edit_Team_Roles_Page(int teamMembersCount) {
        super();
        this.teamMembersCount = teamMembersCount;
    }

    public String getStudentLabelText(int order) {
        checkOrder(order);

        String selectId = ROLES_PREFIX_SELECT + order;
        WebElement label = Drivers.getDriver().findElement(By.xpath("//label[@for='" + selectId + "']"));
        return label.getText().strip();
    }

    private Select getSelect(int order) {
        checkOrder(order);
        String selectId = ROLES_PREFIX_SELECT + order;
        List<WebElement> elementList = Drivers.getDriver().findElements(By.id(selectId));
        WebElement st = getElement(elementList, selectId);
        return new Select(st);
    }

    private void checkOrder(int order){
        if (order >= teamMembersCount || order < 0) {
            throw new IllegalArgumentException("Order: " + order +" is out of range <0,"+teamMembersCount+">" );
        }
    }

    public void selectValuesByVisibleText(int order, Set<String> options) {
        Select select = getSelect(order);
        select.deselectAll();
        options.forEach(select::selectByVisibleText);
    }

    public Set<String> getSelectedProfiles(int order) {
        Select select = getSelect(order);
        Set<String> selectedOptions = new HashSet<>();
        select.getAllSelectedOptions().forEach(option -> selectedOptions.add(option.getText().strip()));
        return selectedOptions;
    }

    public Set<String> getAllAvailableOptions(int order){
        List<WebElement> options = getSelect(order).getOptions();
        Set<String> result = new HashSet<>();
        options.forEach(a -> result.add(a.getText().strip()));
        return result;
    }

    @FindBy(id = SUBMIT_BTN)
    private List<WebElement> submitButton;

    @FindBy(id = BACK_BTN)
    private List<WebElement> backButton;


    public void clickOnSubmitBTN(){
        WebElement button = getElement(submitButton, SUBMIT_BTN);
        Click.clickAndWaitId(button, Const.BASE_TITLE_ID);
    }

    public void clickOnBackBTN(){
        WebElement button = getElement(backButton, BACK_BTN);
        Click.clickAndWaitId(button,Team_Page.PAGE_ID);
    }


}
