package pstsp.support.pageobjects.team;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.ui.Select;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;
import pstsp.support.tools.Drivers;

import java.util.HashSet;
import java.util.List;
import java.util.Set;
/**
 * Team page - edit team form page
 * used at garant and leader
 * @author David Kuta
 */
public class Team_Edit_Form_Page_Object extends PageObject {

    public static final String TEAM_NAME_T = "frm-teamEditForm-name";
    public static final String TEAM_LEADER_NAME_T = "frm-teamEditForm-teamLeaderName";
    public static final String TEAM_MEMBERS_S = "frm-teamEditForm-members";
    public static final String TEAM_COMPLETE_S = "frm-teamEditForm-complete";
    public static final String SUBMIT_BTN = "frm-teamEditForm-submit";
    public static final String BACK_BTN = "frm-teamEditForm-cancel";
    public static final String TEAM_COMPLETE_TEXT = "Ano";
    public static final String TEAM_INCOMPLETE_TEXT = "Ne";


    @FindBy(id = TEAM_NAME_T)
    private List<WebElement> teamName;

    @FindBy(id = TEAM_LEADER_NAME_T)
    private List<WebElement> teamLeaderName;

    @FindBy(id = TEAM_MEMBERS_S)
    private List<WebElement> teamMembersSelect;

    @FindBy(id = TEAM_COMPLETE_S)
    private List<WebElement> teamComplete_Select;

    @FindBy(id = SUBMIT_BTN)
    private List<WebElement> submitButton;

    @FindBy(id = BACK_BTN)
    private List<WebElement> backButton;

    public String getTeamName() {
        WebElement teamNameTextBox = getElement(teamName, TEAM_NAME_T);
        return teamNameTextBox.getAttribute("value").strip();
    }

    public void setTeamName(String teamName) {
        WebElement element = getElement(this.teamName, TEAM_NAME_T);
        element.clear();
        element.sendKeys(teamName);
    }

    public String getTeamLeaderInfo() {
        WebElement element = getElement(teamLeaderName, TEAM_LEADER_NAME_T);
        return element.getAttribute("value").strip();
    }

    public boolean isTeamLeaderNameReadOnly() {
        WebElement element = getElement(teamLeaderName, TEAM_LEADER_NAME_T);
        String attribute = element.getAttribute("readonly");
        return attribute.equals("true");
    }

    public void setTeamMembers(Set<String> options) {
        WebElement select = getElement(teamMembersSelect, TEAM_MEMBERS_S);
        selectValuesByVisibleText(select, options);
    }

    public Set<String> getTeamMembers() {
        WebElement select = getElement(teamMembersSelect, TEAM_MEMBERS_S);
        return getSelectedValues(select);
    }

    public Set<String> getAllAvailableStudents() {
        WebElement select = getElement(teamMembersSelect, TEAM_MEMBERS_S);
        Select sel = new Select(select);
        Set<String> result = new HashSet<>();
        sel.getOptions().forEach(a -> result.add(a.getText().strip()));
        return result;
    }

    public void setTeamComplete() {
        WebElement element = getElement(teamComplete_Select, TEAM_COMPLETE_S);
        Select select = new Select(element);
        select.selectByVisibleText(TEAM_COMPLETE_TEXT);
    }

    public void setTeamInComplete() {
        WebElement element = getElement(teamComplete_Select, TEAM_COMPLETE_S);
        Select select = new Select(element);
        select.selectByVisibleText(TEAM_INCOMPLETE_TEXT);
    }

    public boolean isTeamComplete() {
        WebElement select = getElement(teamComplete_Select, TEAM_COMPLETE_S);
        boolean state = getSelectedValues(select).contains(TEAM_COMPLETE_TEXT);
        return state;
    }

    public void clickOnSubmitBTN(){
        WebElement button = getElement(submitButton, SUBMIT_BTN);
        Click.clickAndWaitId(button, Const.BASE_TITLE_ID);
    }

    public void clickOnBackBTN(){
        WebElement button = getElement(backButton, BACK_BTN);
        Click.clickAndWaitId(button,Team_Page.PAGE_ID);
    }

    private void selectValuesByVisibleText(WebElement selectInput, Set<String> options) {
        WebElement st1 = selectInput;
        Select select = new Select(st1);
        select.deselectAll();
        options.forEach(select::selectByVisibleText);
    }

    private Set<String> getSelectedValues(WebElement element) {
        WebElement st = element;
        Select select = new Select(st);
        Set<String> selectedOptions = new HashSet<>();
        select.getAllSelectedOptions().forEach(option -> selectedOptions.add(option.getText().strip()));
        return selectedOptions;
    }


}
