package pstsp.support.pageobjects.team;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.Table;
import pstsp.support.services.entities.LeaderTopicInterrest;
import pstsp.support.services.entities.Meeting;
import pstsp.support.services.entities.Student;
import pstsp.support.services.entities.storage.StudentStorage;
import pstsp.support.test_utils.Fail;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * Team page
 * Leader
 * @author David Kuta
 */
public class Team_Page extends PageObject {


    public static final String PAGE_ID = "teamPage-showTeam-title";
    public static final String TEAM_MEMBERS_TABLE = "teamPage-teamMemberTableCard-table";
    //public static final String TEAM_MEMBERS_CARD = "teamPage-teamMemberTableCard";
    public static final String TEAM_ASSIGNMENT_NAME = "teamPage-projectCard-project-caption";
    public static final String TEAM_EDIT_BUTTON = "teamPage-teamMemberTableCard-editTeam";
    public static final String TEAM_PROFILE_EDIT_BUTTON = "teamPage-teamProfileCard-edit";
    public static final String TEAM_PROFILES = "teamPage-teamProfileCard-body";
    public static final String MEETING_TABLE = "teamPage-meetingCard-table";
    public static final String COMPLETE_TEAM_STATE = "teamPage-completeTeamState";
    public static final String ADD_MEETING_BTN = "teamPage-meetingCard-addMeetingButton";
    public static final String TOPIC_INTERREST_TABLE = "teamPage-teamInterestsCard-table";
    public static final String EDIT_TEAM_ROLES = "teamPage-teamMemberTableCard-editTeamProfiles";
    public static final String NO_ASSIGNMENT_STRING = "Projekt dosud nemá přiřazené téma";

    public static final String COMPLETE_STRING = "Kompletní tým";
    public static final String INCOMPLETE_STRING = "Tým hledá členy";
    @FindBy(id = Const.BASE_TITLE_ID)
    private List<WebElement> teamName;

    public String getTeamName(){
        WebElement caption = getElement(teamName, Const.BASE_TITLE_ID);
        String text = caption.getText();
        String parts[] = text.split("-");
        if(parts.length != 2){
            return "";
        }
        return parts[1].strip();
    }


    @FindBy(id = TEAM_ASSIGNMENT_NAME)
    private List<WebElement> teamAssignment;

    public String getAssignmentName(){
        WebElement caption = getElement(teamAssignment, TEAM_ASSIGNMENT_NAME);
        String text = caption.getText();
        return text.strip();
    }

    @FindBy(id = COMPLETE_TEAM_STATE)
    private List<WebElement> completeTeamState;

    public String getTeamCompletionState() {
       WebElement element = getElement(completeTeamState,COMPLETE_TEAM_STATE);
       return element.getText();
    }

    public boolean hasAssignment(){
        String assignmentName = this.getAssignmentName();

        return !assignmentName.equals(NO_ASSIGNMENT_STRING);
    }

    @FindBy(id = TEAM_PROFILE_EDIT_BUTTON)
    private List<WebElement> teamProfilesEditButton;

    public Edit_Team_Profile_Page clickOnTeamProfileEditButton(){
        WebElement button = getElement(teamProfilesEditButton, TEAM_PROFILE_EDIT_BUTTON);
        Click.clickAndWaitId(button, Edit_Team_Profile_Page.PAGE_ID);
        return new Edit_Team_Profile_Page();
    }

    @FindBy(id = TEAM_EDIT_BUTTON)
    private List<WebElement> teamEditButton;


    public Edit_Team_Page clickOnTeamEditButton(){
        WebElement button = getElement(teamEditButton, TEAM_EDIT_BUTTON);
        Click.clickAndWaitId(button, Edit_Team_Page.PAGE_ID);
        return new Edit_Team_Page();
    }

    @FindBy(id = TEAM_MEMBERS_TABLE)
    private List<WebElement> teamMembersTable;

    public StudentStorage getTeamMembers() {
        WebElement table = getElement(teamMembersTable, TEAM_MEMBERS_TABLE);
        List<List<WebElement>> a = Table.getTableContent(table);
        List<Student> students = new ArrayList<>();
        for(List<WebElement> row : a){
            if(row.size() != 4) continue;
            Student student = new Student();
            for(int i = 1; i < row.size(); i++){
                switch (i) {
                    case 1: {
                        student.setNameAndPersonalId(row.get(i).getText().strip());
                        break;
                    }
                    case 2: {
                        student.setEmail(row.get(i).getText().strip());
                        break;
                    }
                    case 3: {
                        student.setRolesFromString(row.get(i).getText().strip());
                        break;
                    }
                }
            }
            if(row.size() > 0) {
                students.add(student);
            }
        }

        return new StudentStorage(students);
    }

    @FindBy(id = TEAM_PROFILES)
    private List<WebElement> teamProfiles;
    /**
     *
     * @return set of profile, related to whole team
     */
    public Set<String> getTeamProfile(){
        Set<String> profiles = new HashSet<>();
        WebElement element = getElement(teamProfiles,TEAM_PROFILES);
        List<WebElement> badges = element.findElements(By.tagName("span"));
        for (WebElement badge: badges) {
            profiles.add(badge.getText());
        }
        return profiles;
    }

    @FindBy(id = MEETING_TABLE)
    private List<WebElement> meetingTable;

    public List<Meeting> getAllMeetings()
    {
        WebElement table = getElement(meetingTable,MEETING_TABLE);
        Click.scrollToElement(table);
        List<List<WebElement>> a = Table.getTableContent(table);
        List<Meeting> meetings = new ArrayList<>();
        for(List<WebElement> row : a){
            if(row.size() != 4) continue;
            Meeting meeting = new Meeting();
            for(int i = 0; i < row.size(); i++){
                switch (i){
                    case 0: {
                        try {
                            meeting.setDatetime(row.get(i).getText().strip());
                        }
                        catch (Exception e){
                            Fail.failTestDueToMissingTextInTable(MEETING_TABLE,"Missing datetime in correct format");
                        }
                        break;
                    }
                    case 1: {
                        meeting.setRoom(row.get(i).getText().strip());
                        break;
                    }
                    case 2: {
                        meeting.setTopic(row.get(i).findElement(By.tagName("a")));
                        break;
                    }
                    case 3:{
                        meeting.setWith(row.get(i).getText().strip());
                        break;
                    }
                }
            }
            if(row.size() > 0) {
                meetings.add(meeting);
            }
        }
        return meetings;
    }


    @FindBy(id = ADD_MEETING_BTN)
    private List<WebElement> addMeetingBTN;

    public Team_Page_Meeting_Modal openMeetingModal() {

        WebElement button = getElement(addMeetingBTN, ADD_MEETING_BTN);

        Click.clickAndWaitId(button,Team_Page_Meeting_Modal.ID);
        return new Team_Page_Meeting_Modal();
    }

    @FindBy(id = TOPIC_INTERREST_TABLE)
    private List<WebElement> topicInterrestTable;

    /**
     * Only for leader, that dont have assigned topic for his project
     * @return list of assignment interrests
     */
    public List<LeaderTopicInterrest> getTopicInterrestTableContent() {

        WebElement elemet = getElement(topicInterrestTable, TOPIC_INTERREST_TABLE);

        List<List<WebElement>> tableContent = Table.getTableContent(elemet);
        List<LeaderTopicInterrest> result = new ArrayList<>();
        for (List<WebElement> row: tableContent) {
            if(row.size() != 7) continue;
            LeaderTopicInterrest inter = new LeaderTopicInterrest();
            for(int i = 0; i < row.size(); i++){
                switch (i){
                    case 0:{
                        inter.setTopic(row.get(i));
                        break;
                    }
                    case 1:{
                        inter.setMentor(row.get(i).getText());
                        break;
                    }
                    case 2:{
                        inter.setDate(row.get(i).getText());
                        break;
                    }
                    case 3:{
                        inter.setPriority(row.get(i).findElement(By.tagName("i")).getAttribute("data-original-title"));
                        break;
                    }
                    case 4:{
                        inter.setTopicSuitability(row.get(i).getText());
                        inter.setTopicSuitabilityColor(row.get(i).findElement(By.tagName("span")).getAttribute("data-testcolor").strip());
                        break;
                    }
                    case 5:{
                        inter.setStatus(row.get(i).getText());
                        break;
                    }
                    case 6:{
                        inter.setDeleteButton(row.get(i).findElement(By.className("btn")));
                        break;
                    }
                }
            }
            if(row.size() > 0) {
                result.add(inter);
            }

        }

        return result;
    }

    @FindBy(id = EDIT_TEAM_ROLES)
    private List<WebElement> editTeamRolesBtn;

    public Edit_Team_Roles_Page clickOnEditTeamRoles(){
        WebElement button = getElement(editTeamRolesBtn, EDIT_TEAM_ROLES);
        int cnt = this.getTeamMembers().getStudentCount();
        Click.clickAndWaitId(button, Edit_Team_Roles_Page.PAGE_ID);
        return new Edit_Team_Roles_Page(cnt);
    }

    public boolean isTeamComplete(){
        String compl = getTeamCompletionState().strip();
        return compl.equals(COMPLETE_STRING);
    }
}
