package pstsp.support.pageobjects.teammanagement;

import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.ui.Select;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.test_utils.Fail;

import java.util.List;
/**
 * Edit defence page
 * Garant
 * @author David Kuta
 */
public class Team_Manag_Edit_Defence_Modal_Page extends PageObject {
    public static final String PAGE_ID = "modal-add-defence";
    public static final String TERM_NUMBER = "frm-defenceAddForm-termNumber";
    public static final String DEFENCE_DATE = "frm-defenceAddForm-termDate";

    public static final String RESULT_SELECT = "frm-defenceAddForm-termResult";
    public static final String RESULT_YES = "Splněno";
    public static final String RESULT_NO = "Nesplněno";
    public static final String RESULT_NA = "Nespecifikováno";

    public static final String CLOSE_BUTTON = "frm-addMeetingForm-cancel";
    public static final String SUBMIT_BUTTON = "frm-addMeetingForm-submit";

    @FindBy(id = TERM_NUMBER)
    private List<WebElement> termNumber;

    @FindBy(id = DEFENCE_DATE)
    private List<WebElement> defenceDate;

    @FindBy(id = RESULT_SELECT)
    private List<WebElement> resultSelect;

    @FindBy(id = CLOSE_BUTTON)
    private List<WebElement> closeButton;

    @FindBy(id = SUBMIT_BUTTON)
    private List<WebElement> submitButton;

    public void clickOnCancelBTN() {
        WebElement element = getElement(closeButton, CLOSE_BUTTON);
        Click.clickButtonAndWaitHideModal(element);
    }

    public void clickOnSubmitBTN() {
        WebElement element = getElement(submitButton, SUBMIT_BUTTON);
        //Click.clickButtonAndWaitHideModal(element);
        Click.clickAndWaitId(element, Const.BASE_TITLE_ID);
    }

    public void setDefenceNumber(String number) {
        WebElement element = getElement(termNumber, TERM_NUMBER);
        element.clear();
        element.sendKeys(number);
    }

    /**
     * Sets datetime
     *
     * @param date date in format DDMMRRRR
     */
    public void setDefenceDate(String date) {
        WebElement element = getElement(defenceDate, DEFENCE_DATE);
        element.sendKeys(date);
    }

    public void setDefenceResultSuccess() {
        WebElement element = getElement(resultSelect, RESULT_SELECT);
        Select select = new Select(element);
        select.selectByVisibleText(RESULT_YES);
    }

    public void setDefenceResultUnSuccess() {
        WebElement element = getElement(resultSelect, RESULT_SELECT);
        Select select = new Select(element);
        select.selectByVisibleText(RESULT_NO);
    }

    public void setDefenceResultUnspecified() {
        WebElement element = getElement(resultSelect, RESULT_SELECT);
        Select select = new Select(element);
        select.selectByVisibleText(RESULT_NA);
    }

    public void setDefenceResult(String resultText){
        WebElement element = getElement(resultSelect, RESULT_SELECT);
        if(!resultText.equals(RESULT_YES) && !resultText.equals(RESULT_NO) && !resultText.equals(RESULT_NA))
            Fail.failTestDueToWrongValue(RESULT_SELECT,"Wrong selected value " + resultText);


        Select select = new Select(element);
        select.selectByVisibleText(resultText);
    }




}
