package pstsp.support.pageobjects.teammanagement;

import org.openqa.selenium.By;
import org.openqa.selenium.Keys;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.ui.Select;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.pageobjects.team.Team_Edit_Form_Page_Object;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.entities.DefenceInfo;
import pstsp.support.tools.Drivers;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
/**
 * Team edit page from garant view
 * Garant
 * @author David Kuta
 */
public class Team_Manag_Edit_Page extends PageObject {
    public static final String PAGE_ID = "teamManagementPage-edit-title";

    //team edit form
    public static final String TEAM_NAME_T = "frm-teamEditForm-name";
    public static final String TEAM_LEADER_NAME_T = "frm-teamEditForm-teamLeaderName";
    public static final String TEAM_MEMBERS_S = "frm-teamEditForm-members";
    public static final String TEAM_COMPLETE_S = "frm-teamEditForm-complete";
    public static final String TEAM_SUBMIT_BTN = "frm-teamEditForm-submit";
    public static final String TEAM_COMPLETE_TEXT = "Ano";
    public static final String TEAM_INCOMPLETE_TEXT = "Ne";

    public static final String CREDIT_TSP1_DATE = "frm-teamCreditForm-creditTsp1";
    public static final String CREDIT_TSP2_DATE = "frm-teamCreditForm-creditTsp2";
    public static final String CREDIT_SUBMIT = "frm-creditEditForm-submit";

    public static final String OPEN_MODAL_BTN = "teamManagementPage-addDefenceBTN";
    public static final String DEFENCE_CARD = "teamManagementPage-defenceCard";
    public static final String DEFENCE_ATTEMPT_PREF = "projectPage-projectInfo-card-defence-attempt-";
    public static final String DEFENCE_DATE_PREF = "projectPage-projectInfo-card-defence-date-";
    public static final String DEFENCE_RESULT_PREF = "projectPage-projectInfo-card-defence-result-";

    private Team_Edit_Form_Page_Object form = new Team_Edit_Form_Page_Object();

    public String getTeamName() {
        return form.getTeamName();
    }

    public void setTeamName(String teamName) {
        form.setTeamName(teamName);
    }

    public String getTeamLeaderInfo() {
        return form.getTeamLeaderInfo();
    }

    public boolean isTeamLeaderNameReadOnly() {
        return form.isTeamLeaderNameReadOnly();
    }

    public void setTeamMembers(Set<String> options) {
        form.setTeamMembers(options);
    }

    public Set<String> getTeamMembers() {
        return form.getTeamMembers();
    }

    public Set<String> getAllAvailableStudents() {
        return form.getAllAvailableStudents();
    }

    public void setTeamComplete() {
        form.setTeamComplete();
    }

    public void setTeamInComplete() {
        form.setTeamInComplete();
    }

    public boolean isTeamComplete() {
        return form.isTeamComplete();
    }

    public void clickOnTeamEditSubmitBTN() {
        form.clickOnSubmitBTN();
    }


    ///
    @FindBy(id = CREDIT_TSP1_DATE)
    private List<WebElement> credit1Date;

    @FindBy(id = CREDIT_TSP2_DATE)
    private List<WebElement> credit2Date;

    @FindBy(id = CREDIT_SUBMIT)
    private List<WebElement> creditSubmit;

    /**
     * Sets datetime
     *
     * @param date date in format DDMMRRRR
     */
    public void setCredit1DT(String date) {
        WebElement dateDT = getElement(credit1Date, CREDIT_TSP1_DATE);
        //date = "28022022";
        dateDT.clear();
        dateDT.sendKeys(date);
    }

    /**
     * Sets datetime
     *
     * @param date date in format DDMMRRRR
     */
    public void setCredit2DT(String date) {
        WebElement dateDT = getElement(credit2Date, CREDIT_TSP2_DATE);
        dateDT.clear();
        dateDT.sendKeys(date);
    }

    public String getCredit1Date() {

        WebElement dateDT = getElement(credit1Date, CREDIT_TSP1_DATE);
        String date = dateDT.getAttribute("value");
        if (!date.equals("")) {
            String[] dateParts = date.split("-");

            return dateParts[2] + dateParts[1] + dateParts[0];
        } else
            return "";
    }

    public String getCredit2Date() {

        WebElement dateDT = getElement(credit2Date, CREDIT_TSP2_DATE);
        String date = dateDT.getAttribute("value");
        if (!date.equals("")) {
            String[] dateParts = date.split("-");

            return dateParts[2] + dateParts[1] + dateParts[0];
        } else
            return "";
    }


    public void clickOnCreditSubmitBTN() {
        WebElement button = getElement(creditSubmit, CREDIT_SUBMIT);
        Click.clickAndWaitId(button, Const.BASE_TITLE_ID);
    }

    @FindBy(id = OPEN_MODAL_BTN)
    private List<WebElement> openModalBTN;

    public Team_Manag_Edit_Defence_Modal_Page openAddDefenceModal() {
        WebElement element = getElement(openModalBTN, OPEN_MODAL_BTN);
        Click.clickAndWaitId(element, Team_Manag_Edit_Defence_Modal_Page.PAGE_ID);
        return new Team_Manag_Edit_Defence_Modal_Page();
    }

    @FindBy(id = DEFENCE_CARD)
    private List<WebElement> defenceCard;


    public List<DefenceInfo> getAllDefences() {
        List<DefenceInfo> result = new ArrayList<>();
        if (defenceCard.size() > 0) {
            WebElement elementCard = getElement(defenceCard, DEFENCE_CARD);
            int defenceCount = Integer.parseInt(elementCard.getAttribute("data-defencecnt"));
            for (int i = 0; i < defenceCount; i++) {
                WebElement attempt = Drivers.getDriver().findElement(By.id(DEFENCE_ATTEMPT_PREF+i));
                int attemptNumber = Integer.parseInt(attempt.getText().strip());
                WebElement date = Drivers.getDriver().findElement(By.id(DEFENCE_DATE_PREF + i));
                WebElement defResult = Drivers.getDriver().findElement(By.id(DEFENCE_RESULT_PREF + i));
                result.add(new DefenceInfo(attemptNumber, date.getText(), defResult.getText()));

            }
        }

        return result;
    }

}
