package pstsp.support.pageobjects.teammanagement;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Table;
import pstsp.support.services.entities.TeamStateTableRow;

import java.util.ArrayList;
import java.util.List;
/**
 * Team management page
 * Garant
 * @author David Kuta
 */
public class Team_Management_Page extends PageObject {
    public static final String PAGE_ID = "teamManagementPage-base-title";
    public static final String TABLE = "teamManagementPage-table";

    @FindBy(id = TABLE)
    private List<WebElement> table;

    /**
     * In MentoredProjectsTableRow project has team name and goes to project page and team goes to edit team
     */
    public List<TeamStateTableRow> getTeamManagementTable() {

        WebElement element = getElement(table, TABLE);
        List<TeamStateTableRow> tableContent = new ArrayList<>();
        List<List<WebElement>> rawTable = Table.getTableContent(element);


        for (List<WebElement> elementList : rawTable) {

            //if (elementList.size() != 5 && elementList.size() != 3) continue;

            TeamStateTableRow row = new TeamStateTableRow();
            for (int i = 0; i < elementList.size(); i++) {
                if (elementList.size() == 5) {
                    switch (i) {
                        case 0: {
                            row.setProject(elementList.get(i).findElement(By.tagName("a")));
                            break;
                        }
                        case 1: {

                            WebElement progress = elementList.get(i).findElement(By.className("progress"));
                            int minCritGreen = Integer.parseInt(progress.findElement(By.className("bg-success")).getText());
                            int minCritOrange = Integer.parseInt(progress.findElement(By.className("bg-warning")).getText());
                            int minCritRed = Integer.parseInt(progress.findElement(By.className("bg-danger")).getText());
                            row.setMinCritGreen(minCritGreen);
                            row.setMinCritOrange(minCritOrange);
                            row.setMinCritRed(minCritRed);
                            break;
                        }
                        case 2: {
                            WebElement progress = elementList.get(i).findElement(By.className("progress"));
                            int prjStateGreen = Integer.parseInt(progress.findElement(By.className("bg-success")).getText());
                            int prjStateOrange = Integer.parseInt(progress.findElement(By.className("bg-warning")).getText());
                            int prjStateRed = Integer.parseInt(progress.findElement(By.className("bg-danger")).getText());
                            row.setPrjStateGreen(prjStateGreen);
                            row.setPrjStateOrange(prjStateOrange);
                            row.setPrjStateRed(prjStateRed);
                            break;
                        }
                        case 3: {
                            String date = elementList.get(i).getText();
                            row.setDate(date);
                            break;
                        }
                        case 4: {
                            row.setTeam(elementList.get(i).findElement(By.tagName("a")));
                        }
                    }
                }
                else if(elementList.size() == 3){
                    switch (i) {
                        case 0: {
                            row.setProject(elementList.get(i).findElement(By.tagName("a")));
                            break;
                        }
                        case 1: {

                            row.setOtherInfo(elementList.get(i).getText().strip());
                            break;
                        }
                        case 2: {
                            row.setTeam(elementList.get(i).findElement(By.tagName("a")));
                            break;
                        }
                    }
                }

            }

            if (elementList.size() > 0) {
                tableContent.add(row);

            }
        }
        return tableContent;
    }
}
