package pstsp.support.pageobjects.usermanagement;

import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import pstsp.support.pageobjects.PageObject;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.Table;
import pstsp.support.services.entities.UserManagementLeaderTableRow;
import pstsp.support.services.entities.UserManagementMentorTableRow;


import java.util.ArrayList;
import java.util.List;
/**
 * User management page
 * Garant
 * @author David Kuta
 */
public class User_Management_Page extends PageObject {
    public static final String PAGE_ID = "userManagementPage-default-title";
    public static final String MENTOR_TABLE = "userManagementPage-mentorTable";
    public static final String LEADER_TABLE = "userManagementPage-leaderTable";
    public static final String ADD_MENTOR_BTN = "userManagementPage-mentorAddBTN";

    @FindBy(id = MENTOR_TABLE)
    private List<WebElement> mentorTable;

    public List<UserManagementMentorTableRow> getMentorTable() {
        WebElement table = getElement(mentorTable, MENTOR_TABLE);

        List<List<WebElement>> a = Table.getTableContent(table);
        List<UserManagementMentorTableRow> mentorInfoList = new ArrayList<>();
        for (List<WebElement> row : a) {
            if (row.size() != 5) continue;
            UserManagementMentorTableRow mentorInfo = new UserManagementMentorTableRow();
            for (int i = 0; i < row.size(); i++) {
                switch (i) {
                    case 0: {
                        String firstName = row.get(i).getText().strip();
                        mentorInfo.setFirstname(firstName);
                        break;
                    }
                    case 1: {
                        String surname = row.get(i).getText().strip();
                        mentorInfo.setLastname(surname);

                        break;
                    }
                    case 2: {
                        String email = row.get(i).getText().strip();
                        mentorInfo.setEmail(email);
                        break;
                    }
                    case 3: {
                        String createdAt = row.get(i).getText().strip();
                        mentorInfo.setCreatedAt(createdAt);
                        break;
                    }
                    case 4: {
                        WebElement button = row.get(i).findElement(By.tagName("a"));
                        mentorInfo.setDeleteButton(button);
                        break;
                    }
                }
            }
            if (row.size() > 0) {
                mentorInfoList.add(mentorInfo);
            }
        }
        return mentorInfoList;
    }

    @FindBy(id = LEADER_TABLE)
    private List<WebElement> leaderTable;

    public List<UserManagementLeaderTableRow> getLeaderTable() {
        WebElement table = getElement(leaderTable, LEADER_TABLE);

        List<List<WebElement>> a = Table.getTableContent(table);
        List<UserManagementLeaderTableRow> leaderTableRows = new ArrayList<>();
        for (List<WebElement> row : a) {

            if (row.size() != 6) continue;

            UserManagementLeaderTableRow leaderInfo = new UserManagementLeaderTableRow();
            for (int i = 0; i < row.size(); i++) {
                switch (i) {
                    case 0: {
                        String firstName = row.get(i).getText().strip();
                        leaderInfo.setFirstname(firstName);
                        break;
                    }
                    case 1: {
                        String surname = row.get(i).getText().strip();
                        leaderInfo.setLastname(surname);
                        leaderInfo.setPersonalId(row.get(i).getAttribute("data-personalNumber").strip());

                        break;
                    }
                    case 2: {
                        String email = row.get(i).getText().strip();
                        leaderInfo.setEmail(email);
                        break;
                    }
                    case 3: {
                        WebElement button = row.get(i).findElement(By.tagName("a"));
                        leaderInfo.setTeamButton(button);

                        break;
                    }
                    case 4: {
                        String createdAt = row.get(i).getText().strip();
                        leaderInfo.setCreatedAt(createdAt);
                        break;
                    }
                    case 5: {
                        WebElement button = row.get(i).findElement(By.tagName("a"));
                        leaderInfo.setDeleteButton(button);

                        break;
                    }
                }
            }
            if (row.size() > 0) {
                leaderTableRows.add(leaderInfo);
            }
        }
        return leaderTableRows;
    }

    @FindBy(id = ADD_MENTOR_BTN)
    private List<WebElement> addMentorBTN;

    public User_Management_Page_Add_Mentor_Modal openAddMentorModal() {
        WebElement element = getElement(addMentorBTN,ADD_MENTOR_BTN);
        Click.clickAndWaitId(element,User_Management_Page_Add_Mentor_Modal.PAGE_ID);
        return new User_Management_Page_Add_Mentor_Modal();
    }

}
