package pstsp.support.selenium_utils;

import org.openqa.selenium.Alert;
import org.openqa.selenium.By;
import org.openqa.selenium.NoSuchElementException;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;
import pstsp.support.pageobjects.commonparts.HeaderBar_Page;
import pstsp.support.test_utils.Fail;
import pstsp.support.tools.Drivers;

import java.time.Duration;
import java.util.List;

/**
 * Representing a toast alert in PSTSP
 * @author David Kuta
 */
public class MyAlert {

    public static final String MY_ALERT_ID = "toastsContainerTopRight";
    public static final String SUCCES_HEADER = "Úspěch";
    public static final String WARNING_HEADER = "Varování";
    public static final String FAIL_HEADER = "Neúspěch";
    // header of alert
    private final WebElement header;
    // body of alert
    private final WebElement body;
    // closing button
    private final WebElement button;
    private boolean visible;

    /**
     * Private constructor, for forcing user to use factory method
     * @param header header element
     * @param body body element
     * @param button button element
     */
    private MyAlert(WebElement header, WebElement body, WebElement button) {
        this.header = header;
        this.body = body;
        this.button = button;
        this.visible = true;
    }

    @FindBy(id = MyAlert.MY_ALERT_ID)
    private List<WebElement> toast;

    /**
     * Static factory method for scan MyAlert from web
     * @return Alert instance or null
     */
    public static MyAlert getAlert() {
        WebElement alert;
        try {
            Click.wait.
                    until(ExpectedConditions.visibilityOfAllElementsLocatedBy(
                            By.id(MY_ALERT_ID)));
             alert = Drivers.getDriver().findElement(By.id(MY_ALERT_ID));
        }
        catch (NoSuchElementException e){
            Fail.failTestDueToMissingElement("toastsContainerTopRight");
            return null;
        }
        WebElement header = alert.findElement(By.className("toast-header"));
        WebElement body = alert.findElement(By.className("toast-body"));
        WebElement button = alert.findElement(By.tagName("button"));
        return new MyAlert(header,body,button);
    }

    public boolean getVisibility() {
        return visible;
    }
    public void closeAlert(){
    // NO ABLE TO REALLY CLOSE AN ALERT
        this.button.click();
        this.visible = false;
    }

    public String getHeaderText() {
        return header.getText().split("\n")[0].strip();
    }

    public String getBodyText() {
        return body.getText().strip();
    }
}
