package pstsp.support.services.assignment;

import pstsp.support.pageobjects.assignment.Assignment_Page;
import pstsp.support.pageobjects.assignment.Assignment_Page_Leader_Interrest_Modal;
import pstsp.support.pageobjects.assignment.Assignment_Page_Mentor_Assign_Modal;
import pstsp.support.pageobjects.assignmentlist.Assignment_List_Page;
import pstsp.support.pageobjects.assignmentswithouthmentor.Assignments_Without_Mentor_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarLeader_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarMentor_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.entities.Assignment;
import pstsp.support.services.entities.AssignmentInfo;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.Fail;
import pstsp.support.tools.ProjectLogger;

import java.util.HashMap;
import java.util.List;
/**
 * Actions related to assignment
 * Leader, Mentor
 * @author David Kuta
 */
public class Assignment_Actions {

    public static void makeLeaderInterestOnAssignmentSuccess(String assignmentName, String interestLevel, String mentorName, String leaderName){
        Login_Actions.loginIfNecessary(leaderName);
        SideNavBarLeader_Page snl = new SideNavBarLeader_Page();
        HashMap<String, Assignment> map = snl.clickAssignmentListPageLink().getAssignments();
        Assignment assignment = map.get(assignmentName);
        Check.checkCorrectness(assignment != null, Assignment_List_Page.ASSIGNMENT_SECTION,"Assignment with name: " + assignmentName + " is not on assignment list site");
        Click.clickAndWaitId(assignment.getDetailsButton(), Assignment_Page.PAGE_ID);
        Assignment_Page assignment_page = new Assignment_Page();

        Check.checkText("Volné", assignment_page.getState(),Assignment_Page.AS_STATE);

        Assignment_Page_Leader_Interrest_Modal alim = assignment_page.clickOnInterestButton();
        List<String> availableOptions = alim.getOptionsToSelect();
        if(!availableOptions.contains(interestLevel)){
            Fail.failTestDueToMissingTextInForm(Assignment_Page_Leader_Interrest_Modal.PAGE_ID,interestLevel);
        }
        alim.selectWeightByVisibleText(interestLevel);
        alim.clickOnSubmit();
        Check.checkAndCloseAlert(true);
        Assignment_Check.checkLeaderInterestSuccess(assignmentName, interestLevel, mentorName);
    }

    public static void assignAssignmentToMentor(String assignmentName, String assignmentOwner, String assignmentOwnerMail,
                                                String mentorName, String mentorFullname, String mentorEmail ){
        Login_Actions.loginIfNecessary(mentorName);
        SideNavBarMentor_Page snm = new SideNavBarMentor_Page();
        Assignments_Without_Mentor_Page awm = snm.clickOnAssignmentsWithoutMentor();
        //get all unmentored assignments
        AssignmentInfo found = null;
        List<AssignmentInfo> assignmentInfoList = awm.getUnmentoredAssignments();
        for (AssignmentInfo ai: assignmentInfoList) {
            if(ai.getNameText().equals(assignmentName) && ai.getOwner().equals(assignmentOwner)) {
                found = ai;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Page.TABLE_BODY_ID,"Assignment: " + assignmentName + " owner: " + assignmentOwner);
            return;
        }

        Click.clickAndWaitId(found.getNameLink(),Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkText(assignmentOwner,ap.getOwnerName(),Assignment_Page.AS_CREATOR_NAME);
        Check.checkText(assignmentOwnerMail,ap.getOwnerEmail(),Assignment_Page.AS_CREATOR_EMAIL);

        Assignment_Page_Mentor_Assign_Modal apm = ap.clickOnMentorAssignButton();
        apm.clickOnSubmit();
        Check.checkPage(Assignment_Page.PAGE_ID);
        Check.checkAndCloseAlert(true);
        Assignment_Check.checkMentorAssignmentAssign(assignmentName, assignmentOwner, mentorName, mentorFullname, mentorEmail);
    }

}
