package pstsp.support.services.assignment;

import com.beust.ah.A;
import pstsp.support.basic.Const;
import pstsp.support.pageobjects.assignment.Assignment_Page;
import pstsp.support.pageobjects.assignmentswithmentor.Assignments_With_Mentor_Page;
import pstsp.support.pageobjects.assignmentswithouthmentor.Assignments_Without_Mentor_Page;
import pstsp.support.pageobjects.assignmentswithoutmentormanagement.Assignments_Without_Mentor_Management;
import pstsp.support.pageobjects.assignmentswithoutteam.Assignments_Without_Team_Page;
import pstsp.support.pageobjects.assignmenttoteammanagement.Assignment_To_Team_Management_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarLeader_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarMentor_Page;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.JavaScript;
import pstsp.support.services.entities.AsToTeamManagTeamInterrest;
import pstsp.support.services.entities.AssignmentInfo;
import pstsp.support.services.entities.AssignmentToTeamManagementTableRow;
import pstsp.support.services.entities.LeaderTopicInterrest;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;

import java.util.List;
/**
 * Check on actions related to assignment
 * @author David Kuta
 */
public class Assignment_Check {
    public static void checkLeaderInterestSuccess(String assignmentName, String interestLevel, String mentorName) {
        Check.checkPage(Assignment_Page.PAGE_ID);
        //check of changed state of assignment
        Assignment_Page ap = new Assignment_Page();
        Check.checkText("Projevený zájem", ap.getState(), Assignment_Page.AS_STATE);

        //check if assignment interest is in leader table
        Team_Page teamPage = new SideNavBarLeader_Page().clickOnTeamPageLink();
        String teamName = teamPage.getTeamName();
        List<LeaderTopicInterrest> listInterrest = teamPage.getTopicInterrestTableContent();
        boolean found = false;
        for(LeaderTopicInterrest li : listInterrest){
            if(li.getTopicName().equals(assignmentName) && li.getPriority().strip().equals(interestLevel)){
             found = true;
            }
        }
        Check.checkCorrectness(found,Team_Page.TOPIC_INTERREST_TABLE,"Interest for topic " + assignmentName + " was not found");
        if(mentorName.equals("")) {
            return;
        }
        //check if assignment interest is not in mentor table of topics, with no interrest
        Login_Actions.loginIfNecessary(mentorName);
        SideNavBarMentor_Page snmp = new SideNavBarMentor_Page();
        Assignments_Without_Team_Page awtp = snmp.clickOnAssignmentsWithoutTeam();
       boolean foundInTopicsWithoutInterest =
               awtp.getAllNotInterrestedAssignments().stream().anyMatch(a -> a.getNameLink().getText().strip().equals(assignmentName));
       Check.checkCorrectness(!foundInTopicsWithoutInterest,Assignments_Without_Team_Page.NOT_INTERRESTED_ASSIGNMENTS_TABLE,
               "interested assignment: " + assignmentName + "is in table for not interested topics");
       //check if assignment is in interested assignments
       boolean foundInTopicsWithInterrest = awtp.getAllTopicInterrests().containsInterrest(assignmentName,teamName,interestLevel);
       Check.checkCorrectness(foundInTopicsWithInterrest,Assignments_Without_Team_Page.ASSIGNMENTS_WITH_INTERREST_TABLE,
               "interested assignment: " + assignmentName + "is not table for interested topics");
        //check at garant
        Login_Actions.loginIfNecessary(Const.ROLE_GARANT);
        Assignment_To_Team_Management_Page attm = new SideNavBarGarant_Page().clickAssignmentToTeamManagementPageLink();
        List<AssignmentToTeamManagementTableRow> table = attm.getManagementTable();
        found = false;
        for (AssignmentToTeamManagementTableRow row : table) {
            if (row.getAssignmentName().getText().strip().equals(assignmentName)) {
                for (AsToTeamManagTeamInterrest interrest : row.getListOfInterrests()) {
                    if(interrest.getTeamName().getText().strip().equals(teamName)) {
                        Check.checkText(interestLevel,interrest.getPriority(),Assignment_To_Team_Management_Page.TABLE_INTER_TEAM_PRIORITY);
                        found = true;
                        break;
                    }
                }
                break;
            }
        }
        Check.checkCorrectness(found,Assignment_To_Team_Management_Page.MANAGEMENT_TABLE,"Assignment interrest not found");
       
    }

    public static void checkMentorAssignmentAssign(String assignmentName, String assignmentOwner, String mentorName, String mentorFullname, String mentorEmail) {
        Check.checkPage(Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        String actualName = ap.getMentorName();
        String actualEmail = ap.getMentorEmail();

        Check.checkText(mentorFullname, actualName,Assignment_Page.AS_MENTOR_NAME);
        Check.checkText(mentorEmail,actualEmail,Assignment_Page.AS_MENTOR_EMAIL);
        Assignments_Without_Team_Page awtp = new SideNavBarMentor_Page().clickOnAssignmentsWithoutTeam();
        List<AssignmentInfo> assignmentInfoList = awtp.getAllNotInterrestedAssignments();
        AssignmentInfo expected = new AssignmentInfo();
        expected.setNameText(assignmentName);
        expected.setOwner(assignmentOwner);
        boolean found = false;
        for (AssignmentInfo ai: assignmentInfoList) {
            if (ai.equals(expected)) {
                found = true;
                expected = ai;
                break;
            }
        }

        Check.checkCorrectness(found,Assignments_Without_Team_Page.NOT_INTERRESTED_ASSIGNMENTS_TABLE,"Assignment " + expected + "is not found in table");
        Click.clickAndWaitId(expected.getNameLink(), Assignment_Page.PAGE_ID);
        Assignment_Page nap = new Assignment_Page();
        Check.checkText(assignmentName,nap.getName(),Assignment_Page.AS_NAME);
        Check.checkText(assignmentOwner, nap.getOwnerName(), Assignment_Page.AS_CREATOR_NAME);
        Check.checkText(mentorFullname, nap.getMentorName(),Assignment_Page.AS_MENTOR_NAME);

        //check at garant
        Login_Actions.loginIfNecessary(Const.ROLE_GARANT);
        boolean containsNotMentored = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink()
                .getAssignmentsWithoutMentor().contains(new AssignmentInfo(assignmentName,assignmentOwner));
        Check.checkCorrectness(!containsNotMentored, Assignments_Without_Mentor_Management.TABLE,"Assignment is found, but has to be hidden");

        String actualMentor = new SideNavBarGarant_Page().clickOnAssignmentsWithMentorPageLink().getAssignments().get(assignmentName).getMentor();
        Check.checkText(mentorFullname,actualMentor,Assignments_With_Mentor_Page.MENTOR_NAME_CLS);

    }
}
