package pstsp.support.services.assignmentmanagement;

import pstsp.support.pageobjects.assignmentmanagement.Assignment_Create_Page;
import pstsp.support.pageobjects.assignmentmanagement.Assignment_Edit_Page;
import pstsp.support.pageobjects.assignmentmanagement.Assignment_Form_Page_Object;
import pstsp.support.pageobjects.assignmentmanagement.Assignment_Management_Page;
import pstsp.support.pageobjects.assignmentswithoutmentormanagement.Assignments_Without_Mentor_Management;
import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.assignmentswithoutmentormanagement.Assign_Without_Mentor_Management_Check;
import pstsp.support.services.entities.AssignmentInfo;
import pstsp.support.services.entities.AssignmentManagementTableRow;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.Fail;

import java.util.List;
import java.util.Set;
/**
 * Actions related to assignment management
 * Garant
 * @author David Kuta
 */
public class Assignment_Management_Actions {


    public static void addAssignmentSuccess(String assignmentName, String assignmentDesc, String ownerFirsName, String ownerLastName,
                                            String ownerEmail, String ownerPhone, String ownerOtherInfo, String timeNeeded,
                                            String teamSize, Set<String> expTeamProfile, String mentor, String period, String visibility, String currUser, String assignmentMentorLogin) {

        Login_Actions.loginIfNecessary(currUser);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        Assignment_Create_Page acp = amp.clickOnAddAssignment();
        Assignment_Form_Page_Object form = acp.form;
        form.setAssignmentName(assignmentName);
        form.setAssignmentDesc(assignmentDesc);
        form.setOwnerFirstname(ownerFirsName);
        form.setOwnerLastname(ownerLastName);
        form.setOwnerEmail(ownerEmail);
        form.setOwnerPhone(ownerPhone);
        form.setOwnerOtherInfo(ownerOtherInfo);
        form.setTimeNeeded(timeNeeded);
        form.setTeamSize(teamSize);
        form.setAssignmentProfile(expTeamProfile);
        if(mentor.equals("")) {
            mentor = "Dosud nepřidělen";
        }
        form.setMentor(mentor);
        form.setPeriod(period);
        form.setVisibility(visibility);
        form.clickOnSubmitBTN();
        Check.checkPage(Assignment_Management_Page.PAGE_ID);
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkAddAssignmentSuccess(assignmentName, assignmentDesc,ownerFirsName, ownerLastName, ownerEmail, ownerPhone, ownerOtherInfo, timeNeeded,teamSize, expTeamProfile, mentor, period, visibility, assignmentMentorLogin,currUser);
    }

    public static void editAssignmentNameSuccess(String expectedName, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setAssignmentName(expectedName);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentNameSuccess(expectedName, ownerName);
    }

    public static void editAssignmentDescriptionSuccess(String expectedDesc, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setAssignmentDesc(expectedDesc);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentDescSuccess(expectedDesc,assignmentName, ownerName);
    }

    public static void editAssignmentOwnerNameSuccess(String ownerFirstName, String ownerLastName, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setOwnerFirstname(ownerFirstName);
        aep.form.setOwnerLastname(ownerLastName);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentOwnerNameSuccess(ownerFirstName, ownerLastName,assignmentName);
    }

    public static void editAssignmentOwnerMailSuccess(String ownerMail, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setOwnerEmail(ownerMail);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentOwnerEmailSuccess(ownerMail,assignmentName,ownerName);
    }

    public static void editAssignmentOwnerPhoneSuccess(String ownerPhone, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setOwnerPhone(ownerPhone);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentOwnerPhoneSuccess(ownerPhone,assignmentName,ownerName);
    }

    public static void editAssignmentOwnerOtherInfoSuccess(String ownerOtherInfo, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setOwnerOtherInfo(ownerOtherInfo);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentOwnerOtherInfoSuccess(ownerOtherInfo,assignmentName,ownerName);
    }

    public static void editAssignmentTimeNeededSuccess(String timeNeeded, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setTimeNeeded(timeNeeded);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentTimeNeededSuccess(timeNeeded,assignmentName,ownerName);
    }

    public static void editAssignmentExpTeamSizeSuccess(String expTeamSize, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setTeamSize(expTeamSize);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentExpTeamSizeSuccess(expTeamSize,assignmentName,ownerName);
    }

    public static void editAssignmentExpTeamProfileSuccess(Set<String> expTeamProfile, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setAssignmentProfile(expTeamProfile);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentExpTeamProfileSuccess(expTeamProfile,assignmentName,ownerName);
    }

    public static void editAssignmentMentorSuccess(String mentorName, String mentorLogin, String assignmentName, String ownerName, String user ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        if(mentorName.equals("")) {
            mentorName = "Dosud nepřidělen";
        }
        aep.form.setMentor(mentorName);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentMentorSuccess(mentorName,mentorLogin,assignmentName,ownerName);
    }

    public static void editAssignmentPeriodSuccess(String period, String mentorLogin, String assignmentName, String ownerName, String user ){
        //TODO
    }

    public static void editAssignmentVisibilitySuccess(String visibility, String assignmentName, String ownerName, String user, boolean withMentor ){
        Login_Actions.loginIfNecessary(user);
        Assignment_Management_Page awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        AssignmentManagementTableRow found = null;
        for (AssignmentManagementTableRow row : table) {
            if(row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)){
                found = row;
                break;
            }
        }
        if(found == null){
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.PAGE_ID,"Assignment: "+assignmentName+" " +ownerName);
            return;
        }

        Click.clickAndWaitId(found.getEditAction(), Assignment_Edit_Page.PAGE_ID);
        Assignment_Edit_Page aep = new Assignment_Edit_Page();
        aep.form.setVisibility(visibility);
        aep.form.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Assignment_Management_Check.checkEditAssignmentVisibilitySuccess(visibility,assignmentName,ownerName, withMentor);
    }

}
