package pstsp.support.services.assignmentmanagement;

import pstsp.support.pageobjects.assignment.Assignment_Page;
import pstsp.support.pageobjects.assignmentlist.Assignment_List_Page;
import pstsp.support.pageobjects.assignmentmanagement.Assignment_Edit_Page;
import pstsp.support.pageobjects.assignmentmanagement.Assignment_Management_Page;
import pstsp.support.pageobjects.assignmentswithmentor.Assignments_With_Mentor_Page;
import pstsp.support.pageobjects.assignmentswithouthmentor.Assignments_Without_Mentor_Page;
import pstsp.support.pageobjects.assignmentswithoutmentormanagement.Assignments_Without_Mentor_Management;
import pstsp.support.pageobjects.assignmentswithoutteam.Assignments_Without_Team_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarMentor_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarUnlogged_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.entities.Assignment;
import pstsp.support.services.entities.AssignmentInfo;
import pstsp.support.services.entities.AssignmentManagementTableRow;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.Fail;

import java.util.HashMap;
import java.util.List;
import java.util.Set;
/**
 * Check on actions related to assignment management
 * Garant
 * @author David Kuta
 */
public class Assignment_Management_Check {
    public static void checkAddAssignmentSuccess(String assignmentName, String desc, String ownerFirsName, String ownerLastName,
                                                 String ownerEmail, String ownerPhone, String ownerOtherInfo, String timeNeeded,
                                                 String teamSize, Set<String> expTeamProfile, String mentor, String period, String visibility, String assignmentMentorLogin, String currUser) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);
        Assignment_Management_Page amp = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = amp.getAllAssignmnets();
        String ownerFullName = ownerFirsName + " " + ownerLastName;
        mentor = mentor.equals("Dosud nepřidělen") ? "Mentor nepřiřazen" : mentor;
        String inTableOwner = ownerFullName.equals(" ") ? "" : ownerFullName;
        ownerFullName = ownerFullName.equals(" ") ? "Zadavatel nespecifikován" : ownerFullName;
        boolean found = false;

        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(inTableOwner) && row.getState().equals(visibility)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();
                Check.checkText(assignmentName, ap.getName(), Assignment_Page.AS_NAME);
                Check.checkText(desc, ap.getDescription(), Assignment_Page.AS_DESCRIPTION);
                Check.checkText(ownerFullName, ap.getOwnerName(), Assignment_Page.AS_CREATOR_NAME);
                Check.checkText(ownerEmail, ap.getOwnerEmail(), Assignment_Page.AS_CREATOR_EMAIL);
                Check.checkText(ownerPhone, ap.getOwnerPhone(), Assignment_Page.AS_CREATOR_PHONE);
                Check.checkText(ownerOtherInfo, ap.getOwnerOtherInfo(), Assignment_Page.AS_CREATOR_INFO);
                Check.checkText(timeNeeded, ap.getExpectedTime(), Assignment_Page.AS_EXP_TIME);
                Check.checkText(teamSize, ap.getPrefTeamSize(), Assignment_Page.AS_PREF_TEAM_SIZE);
                Check.checkContentsOfTwoSets(ap.getAssignmentTags(), expTeamProfile, "Assignment profile is not the same");
                Check.checkText(mentor, ap.getMentorName(), Assignment_Page.AS_MENTOR_NAME);
                //todo period check
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        Assignments_Without_Mentor_Management awmp = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        String finalOwnerFullName = ownerFullName.equals("Zadavatel nespecifikován") ? "" : ownerFullName;
        boolean foundAWMP = awmp.getAssignmentsWithoutMentor().stream().
                anyMatch(a -> (a.getNameText().equals(assignmentName) && a.getOwner().equals(finalOwnerFullName)));

        if (mentor.equals("Mentor nepřiřazen") && visibility.equals("Publikováno pro všechny") || mentor.equals("Mentor nepřiřazen") && visibility.equals("Viditelné pouze pro mentory")) {
            Check.checkCorrectness(foundAWMP, Assignments_Without_Mentor_Management.TABLE, "Assignment not found");
        } else {
            Check.checkCorrectness(!foundAWMP, Assignments_Without_Mentor_Management.TABLE, "Assignment found but has to be hidden");
        }


        Assignments_With_Mentor_Page awmpS = new SideNavBarGarant_Page().clickOnAssignmentsWithMentorPageLink();
        HashMap<String, Assignment> hashMap = awmpS.getAssignments();

        boolean containsAssignment = hashMap.containsKey(assignmentName);
        if (mentor.equals("Mentor nepřiřazen")) {
            Check.checkCorrectness(!containsAssignment, Assignments_With_Mentor_Page.ASSIGNMENT_DIV_CLS, "Assignment not found");
        } else {
            Check.checkCorrectness(containsAssignment, Assignments_With_Mentor_Page.ASSIGNMENT_DIV_CLS, "Assignment not found");
            if (containsAssignment) {
                Assignment ap = hashMap.get(assignmentName);
                Check.checkText(assignmentName, ap.getName(), Assignments_With_Mentor_Page.NAME_CLS);
                Check.checkText(mentor, ap.getMentor(), Assignments_With_Mentor_Page.MENTOR_NAME_CLS);
                Check.checkText(timeNeeded, ap.getTimeNeeded(), Assignments_With_Mentor_Page.TIME_NEEDED_CLS);
                Check.checkText(teamSize, ap.getTeamSize(), Assignments_With_Mentor_Page.TEAM_SIZE_CLS);
                Check.checkContentsOfTwoSets(ap.getTags(), expTeamProfile, "Assignment profile is not the same");
                Check.checkText(ownerFullName, ap.getOwner(), Assignments_With_Mentor_Page.ASSIGNMENT_OWNER_CLS);
            }
            Login_Actions.loginIfNecessary(assignmentMentorLogin);
            Assignments_Without_Team_Page awtp = new SideNavBarMentor_Page().clickOnAssignmentsWithoutTeam();
            boolean contains = awtp.getAllNotInterrestedAssignments().contains(new AssignmentInfo(assignmentName, ownerFullName));
            Check.checkCorrectness(contains, Assignments_Without_Team_Page.NOT_INTERRESTED_ASSIGNMENTS_TABLE, "Assignment not found");
        }

        Login_Actions.logoutIfPossible();
        Assignment_List_Page alp = new SideNavBarUnlogged_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> hashMap1 = alp.getAssignments();
        boolean containsAssignment1 = hashMap1.containsKey(assignmentName);
        if (visibility.equals("Publikováno pro všechny")) {
            Check.checkCorrectness(containsAssignment1, Assignment_List_Page.ASSIGNMENT_SECTION, "Assignment not found");
            if (containsAssignment1) {
                Assignment ap = hashMap1.get(assignmentName);
                Check.checkText(assignmentName, ap.getName(), Assignment_List_Page.NAME_CLS);
                mentor = mentor.equals("Mentor nepřiřazen") ? "Mentor dosud nepřiřazen" : mentor;
                Check.checkText(mentor, ap.getMentor(), Assignment_List_Page.MENTOR_NAME_CLS);
                Check.checkText(timeNeeded, ap.getTimeNeeded(), Assignment_List_Page.TIME_NEEDED_CLS);
                Check.checkText(teamSize, ap.getTeamSize(), Assignment_List_Page.TEAM_SIZE_CLS);
                Check.checkContentsOfTwoSets(ap.getTags(), expTeamProfile, "Assignment profile is not the same");
                ownerFullName = ownerFullName.equals("Zadavatel nespecifikován") ?  "Zadavatel dosud nespecifikován" : ownerFullName;
                Check.checkText(ownerFullName, ap.getOwner(), Assignment_List_Page.ASSIGNMENT_OWNER_CLS);
            }
        } else {
            Check.checkCorrectness(!containsAssignment1, Assignment_List_Page.ASSIGNMENT_SECTION, "Assignment found");
        }

    }

    public static void checkEditAssignmentNameSuccess(String expectedName, String ownerName) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);
        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(expectedName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();
                Check.checkText(expectedName, ap.getName(), Assignment_Page.AS_NAME);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(expectedName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(expectedName, aep.form.getAssignmentName(), Assignment_Edit_Page.PAGE_ID);
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment name not as expected");
    }

    public static void checkEditAssignmentDescSuccess(String expectedDesc, String assignmentName, String ownerName) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);
        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();
                Check.checkText(expectedDesc, ap.getDescription(), Assignment_Page.AS_DESCRIPTION);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(expectedDesc, aep.form.getAssignmentDesc(), Assignment_Edit_Page.PAGE_ID);
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment not found");
    }

    public static void checkEditAssignmentOwnerNameSuccess(String ownerFirstName, String ownerLastName, String assignmentName) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);
        String ownerFullName = ownerFirstName + " " + ownerLastName;
        if (ownerFirstName.isBlank() || ownerLastName.isBlank()) {
            ownerFullName = ownerFullName.strip();
        }
        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerFullName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();

                Check.checkText(ownerFullName, ap.getOwnerName(), Assignment_Page.AS_CREATOR_NAME);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerFullName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                String actualOwnerFullName = aep.form.getOwnerFirstname() + " " + aep.form.getOwnerLastname();
                if (aep.form.getOwnerFirstname().isBlank() || aep.form.getOwnerLastname().isBlank()) {
                    actualOwnerFullName = actualOwnerFullName.strip();
                }
                Check.checkText(ownerFullName, actualOwnerFullName, Assignment_Edit_Page.PAGE_ID);
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment not found");
    }

    public static void checkEditAssignmentOwnerEmailSuccess(String ownerMail, String assignmentName, String ownerName) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);

        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();

                Check.checkText(ownerMail, ap.getOwnerEmail(), Assignment_Page.AS_CREATOR_EMAIL);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(ownerMail, aep.form.getOwnerEmail(), Assignment_Edit_Page.PAGE_ID);
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment not found");
    }

    public static void checkEditAssignmentOwnerPhoneSuccess(String ownerPhone, String assignmentName, String ownerName) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);

        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();

                Check.checkText(ownerPhone, ap.getOwnerPhone(), Assignment_Page.AS_CREATOR_PHONE);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(ownerPhone, aep.form.getOwnerPhone(), Assignment_Edit_Page.PAGE_ID);
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment not found");
    }

    public static void checkEditAssignmentOwnerOtherInfoSuccess(String ownerOtherInfo, String assignmentName, String ownerName) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);

        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();

                Check.checkText(ownerOtherInfo, ap.getOwnerOtherInfo(), Assignment_Page.AS_CREATOR_INFO);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(ownerOtherInfo, aep.form.getOwnerOtherInfo(), Assignment_Edit_Page.PAGE_ID);
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment not found");
    }

    public static void checkEditAssignmentTimeNeededSuccess(String timeNeeded, String assignmentName, String ownerName) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);

        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();

                Check.checkText(timeNeeded, ap.getExpectedTime(), Assignment_Page.AS_EXP_TIME);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(timeNeeded, aep.form.getTimeNeeded(), Assignment_Edit_Page.PAGE_ID);
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment not found");
    }

    public static void checkEditAssignmentExpTeamSizeSuccess(String expTeamSize, String assignmentName, String ownerName) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);

        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();

                Check.checkText(expTeamSize, ap.getPrefTeamSize(), Assignment_Page.AS_PREF_TEAM_SIZE);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(expTeamSize, aep.form.getTeamSize(), Assignment_Edit_Page.PAGE_ID);
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment not found");
    }

    public static void checkEditAssignmentExpTeamProfileSuccess(Set<String> expTeamProfile, String assignmentName, String ownerName) {

        Check.checkPage(Assignment_Management_Page.PAGE_ID);

        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();
                Check.checkContentsOfTwoSets(ap.getAssignmentTags(), expTeamProfile, "Assignment profile is not as expected");
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkContentsOfTwoSets(aep.form.getAssignmentProfile(), expTeamProfile, "Assignment profile is not as expected");
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment not found");
    }

    public static void checkEditAssignmentMentorSuccess(String mentorName, String mentorLogin, String assignmentName, String ownerName) {

        Check.checkPage(Assignment_Management_Page.PAGE_ID);

        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page ap = new Assignment_Page();
                if (mentorName.equals("Dosud nepřidělen")) {
                    mentorName = "Mentor nepřiřazen";
                }
                Check.checkText(mentorName, ap.getMentorName(), Assignment_Page.AS_PREF_TEAM_SIZE);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        awmm = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        List<AssignmentManagementTableRow> nextTable = awmm.getAllAssignmnets();
        boolean found1 = false;
        for (AssignmentManagementTableRow row : nextTable) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getEditAction(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                if (mentorName.equals("Mentor nepřiřazen")) {
                    mentorName = "Dosud nepřidělen";
                }
                Check.checkText(mentorName, aep.form.getCurrentMentor(), Assignment_Edit_Page.PAGE_ID);
                found1 = true;
                break;
            }
        }
        Check.checkCorrectness(found1, Assignment_Edit_Page.PAGE_ID, "Assignment not found");

        if (!mentorName.equals("Dosud nepřidělen")) {
            Assignments_With_Mentor_Page awmp = new SideNavBarGarant_Page().clickOnAssignmentsWithMentorPageLink();
            boolean foundMentoredTopics = awmp.getAssignments().containsKey(assignmentName);
            Check.checkCorrectness(foundMentoredTopics, Assignments_With_Mentor_Page.ASSIGNMENT_DIV_CLS, "Assignment not found");

            Login_Actions.loginIfNecessary(mentorLogin);
            Assignments_Without_Team_Page awtp = new SideNavBarMentor_Page().clickOnAssignmentsWithoutTeam();
            boolean foundAtMentor = awtp.getAllNotInterrestedAssignments().contains(new AssignmentInfo(assignmentName, ownerName));
            Check.checkCorrectness(foundAtMentor, Assignments_Without_Team_Page.NOT_INTERRESTED_ASSIGNMENTS_TABLE, "Assignment not found");
        }
    }

    public static void checkEditAssignmentVisibilitySuccess(String visibility, String assignmentName, String ownerName, boolean withMentor) {
        Check.checkPage(Assignment_Management_Page.PAGE_ID);

        Assignment_Management_Page awmm = new Assignment_Management_Page();
        List<AssignmentManagementTableRow> table = awmm.getAllAssignmnets();
        boolean found = false;
        for (AssignmentManagementTableRow row : table) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {

                Check.checkText(visibility, row.getState(), Assignment_Management_Page.TABLE);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Assignment_Management_Page.TABLE, "Assignment not found");

        Assignments_Without_Mentor_Management awmp = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        boolean foundAWMP = awmp.getAssignmentsWithoutMentor().stream().
                anyMatch(a -> (a.getNameText().equals(assignmentName) && a.getOwner().equals(ownerName)));

        if (withMentor == false && visibility.equals("Publikováno pro všechny") || withMentor == false && visibility.equals("Viditelné pouze pro mentory")) {
            Check.checkCorrectness(foundAWMP, Assignments_Without_Mentor_Management.TABLE, "Assignment not found");
        } else {
            Check.checkCorrectness(!foundAWMP, Assignments_Without_Mentor_Management.TABLE, "Assignment found but has to be hidden");
        }


        Assignments_With_Mentor_Page awmpS = new SideNavBarGarant_Page().clickOnAssignmentsWithMentorPageLink();
        HashMap<String, Assignment> hashMap = awmpS.getAssignments();

        boolean containsAssignment = hashMap.containsKey(assignmentName);
        if (withMentor == false) {
            Check.checkCorrectness(!containsAssignment, Assignments_With_Mentor_Page.ASSIGNMENT_DIV_CLS, "Assignment not found");
        } else {
            Check.checkCorrectness(containsAssignment, Assignments_With_Mentor_Page.ASSIGNMENT_DIV_CLS, "Assignment not found");
            if (containsAssignment) {
                Assignment ap = hashMap.get(assignmentName);
                Check.checkText(assignmentName, ap.getName(), Assignments_With_Mentor_Page.NAME_CLS);
                Check.checkText(ownerName, ap.getOwner(), Assignments_With_Mentor_Page.ASSIGNMENT_OWNER_CLS);
            }
        }

        Login_Actions.logoutIfPossible();
        Assignment_List_Page alp = new SideNavBarUnlogged_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> hashMap1 = alp.getAssignments();
        boolean containsAssignment1 = hashMap1.containsKey(assignmentName);
        if (visibility.equals("Publikováno pro všechny")) {
            Check.checkCorrectness(containsAssignment1, Assignment_List_Page.ASSIGNMENT_SECTION, "Assignment not found");
            if (containsAssignment1) {
                Assignment ap = hashMap1.get(assignmentName);
                Check.checkText(assignmentName, ap.getName(), Assignment_List_Page.NAME_CLS);
                Check.checkText(ownerName, ap.getOwner(), Assignment_List_Page.ASSIGNMENT_OWNER_CLS);
            }
        } else {
            Check.checkCorrectness(!containsAssignment1, Assignment_List_Page.ASSIGNMENT_SECTION, "Assignment found");
        }
    }
}
