package pstsp.support.services.assignmentswithoutmentormanagement;

import com.beust.ah.A;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.devtools.v85.log.Log;
import pstsp.support.pageobjects.assignment.Assignment_Page;
import pstsp.support.pageobjects.assignmentlist.Assignment_List_Page;
import pstsp.support.pageobjects.assignmentmanagement.Assignment_Edit_Page;
import pstsp.support.pageobjects.assignmentmanagement.Assignment_Management_Page;
import pstsp.support.pageobjects.assignmentswithmentor.Assignments_With_Mentor_Page;
import pstsp.support.pageobjects.assignmentswithouthmentor.Assignments_Without_Mentor_Page;
import pstsp.support.pageobjects.assignmentswithoutmentormanagement.Assignments_Without_Mentor_Management;
import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarMentor_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.entities.Assignment;
import pstsp.support.services.entities.AssignmentInfo;
import pstsp.support.services.entities.AssignmentManagementTableRow;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.Fail;

import javax.swing.*;
import java.beans.Visibility;
import java.util.HashMap;
import java.util.List;
import java.util.Set;
/**
 * Check to actions related to assignment without mentor management
 * Garant
 * @author David Kuta
 */
public class Assign_Without_Mentor_Management_Check {

    public static void checkEditPublAssignmentNameSuccess(String expectedName, String ownerName) {
        Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
        List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
        boolean found = false;
        for (AssignmentInfo ai : aiList) {
            if (ai.getNameText().equals(expectedName) && ai.getOwner().equals(ownerName)) {
                found = true;
                break;
            }

        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + expectedName + " " + ownerName);
            return;
        }

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        found = asignMap.containsKey(expectedName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + expectedName + " " + ownerName);
            return;
        }
        WebElement button = asignMap.get(expectedName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkText(expectedName, ap.getName(), Assignment_Page.AS_NAME);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(expectedName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkText(expectedName, apn.getName(), Assignment_Page.AS_NAME);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + expectedName + " " + ownerName);
        }

    }


    public static void checkEditPublAssignmentDescSuccess(String expectedDesc, String assignmentName, String ownerName) {

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        boolean found = asignMap.containsKey(assignmentName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }
        WebElement button = asignMap.get(assignmentName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkText(expectedDesc, ap.getDescription(), Assignment_Page.AS_NAME);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkText(expectedDesc, apn.getDescription(), Assignment_Page.AS_NAME);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + ownerName);
        }
    }

    public static void checkEditPublAssignmentOwnerNameSuccess(String assignmentName, String expectedOwnerFullName) {
        Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
        List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
        boolean found = false;
        for (AssignmentInfo ai : aiList) {
            if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(expectedOwnerFullName)) {
                found = true;
                break;
            }

        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + expectedOwnerFullName);
            return;
        }

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        found = asignMap.containsKey(assignmentName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + expectedOwnerFullName);
            return;
        }
        String actualOwnerFullName = asignMap.get(assignmentName).getOwner();
        Check.checkText(expectedOwnerFullName, actualOwnerFullName, Assignment_List_Page.ASSIGNMENT_OWNER_CLS);

        WebElement button = asignMap.get(assignmentName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkText(expectedOwnerFullName, ap.getOwnerName(), Assignment_Page.AS_CREATOR_NAME);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(expectedOwnerFullName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkText(expectedOwnerFullName, apn.getOwnerName(), Assignment_Page.AS_CREATOR_NAME);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + expectedOwnerFullName);
        }
    }

    public static void checkEditPublAssignmentOwnerEmailSuccess(String expectedEmail, String assignmentName, String ownerName) {
        Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
        List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
        boolean found = false;
        for (AssignmentInfo ai : aiList) {
            if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(ai.getNameLink(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(expectedEmail, aep.form.getOwnerEmail(), Assignment_Edit_Page.PAGE_ID);
                found = true;
                break;
            }

        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        found = asignMap.containsKey(assignmentName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }


        WebElement button = asignMap.get(assignmentName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkText(expectedEmail, ap.getOwnerEmail(), Assignment_Page.AS_CREATOR_EMAIL);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkText(expectedEmail, apn.getOwnerEmail(), Assignment_Page.AS_CREATOR_EMAIL);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + ownerName);
        }

    }

    public static void checkEditPublAssignmentOwnerPhoneSuccess(String expectedPhone, String assignmentName, String ownerName) {
        Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
        List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
        boolean found = false;
        for (AssignmentInfo ai : aiList) {
            if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(ai.getNameLink(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(expectedPhone, aep.form.getOwnerPhone(), Assignment_Edit_Page.PAGE_ID);
                found = true;
                break;
            }

        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        found = asignMap.containsKey(assignmentName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }


        WebElement button = asignMap.get(assignmentName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkText(expectedPhone, ap.getOwnerPhone(), Assignment_Page.AS_CREATOR_PHONE);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkText(expectedPhone, apn.getOwnerPhone(), Assignment_Page.AS_CREATOR_PHONE);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + ownerName);
        }
    }

    public static void checkEditPublAssignmentOwnerOtherInfoSuccess(String expectedOtherInfo, String assignmentName, String ownerName) {
        Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
        List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
        boolean found = false;
        for (AssignmentInfo ai : aiList) {
            if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(ai.getNameLink(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(expectedOtherInfo, aep.form.getOwnerOtherInfo(), Assignment_Edit_Page.PAGE_ID);
                found = true;
                break;
            }

        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        found = asignMap.containsKey(assignmentName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }


        WebElement button = asignMap.get(assignmentName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkText(expectedOtherInfo, ap.getOwnerOtherInfo(), Assignment_Page.AS_CREATOR_INFO);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkText(expectedOtherInfo, apn.getOwnerOtherInfo(), Assignment_Page.AS_CREATOR_INFO);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + ownerName);
        }
    }

    public static void checkEditPublAssignmentTimeNeededSuccess(String expectedTime, String assignmentName, String ownerName) {
        Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
        List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
        boolean found = false;
        for (AssignmentInfo ai : aiList) {
            if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(ai.getNameLink(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(expectedTime, aep.form.getTimeNeeded(), Assignment_Edit_Page.PAGE_ID);
                found = true;
                break;
            }

        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        found = asignMap.containsKey(assignmentName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }

        Check.checkText(expectedTime, asignMap.get(assignmentName).getTimeNeeded(), Assignment_List_Page.TIME_NEEDED_CLS);
        WebElement button = asignMap.get(assignmentName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkText(expectedTime, ap.getExpectedTime(), Assignment_Page.AS_EXP_TIME);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkText(expectedTime, apn.getExpectedTime(), Assignment_Page.AS_EXP_TIME);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + ownerName);
        }
    }

    public static void checkEditPublAssignmentTeamSizeSuccess(String expectedTeamSize, String assignmentName, String ownerName) {
        Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
        List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
        boolean found = false;
        for (AssignmentInfo ai : aiList) {
            if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(ai.getNameLink(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkText(expectedTeamSize, aep.form.getTeamSize(), Assignment_Edit_Page.PAGE_ID);
                found = true;
                break;
            }

        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        found = asignMap.containsKey(assignmentName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }

        Check.checkText(expectedTeamSize, asignMap.get(assignmentName).getTeamSize(), Assignment_List_Page.TEAM_SIZE_CLS);
        WebElement button = asignMap.get(assignmentName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkText(expectedTeamSize, ap.getPrefTeamSize(), Assignment_Page.AS_PREF_TEAM_SIZE);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkText(expectedTeamSize, apn.getPrefTeamSize(), Assignment_Page.AS_PREF_TEAM_SIZE);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + ownerName);
        }
    }

    public static void checkEditPublAssignmentExpectedTeamProfileSuccess(Set<String> expectedTeamProfile, String assignmentName, String ownerName) {
        Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
        List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
        boolean found = false;
        for (AssignmentInfo ai : aiList) {
            if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(ai.getNameLink(), Assignment_Edit_Page.PAGE_ID);
                Assignment_Edit_Page aep = new Assignment_Edit_Page();
                Check.checkContentsOfTwoSets(aep.form.getAssignmentProfile(), expectedTeamProfile, Assignment_Edit_Page.PAGE_ID);
                found = true;
                break;
            }

        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        found = asignMap.containsKey(assignmentName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }

        Check.checkContentsOfTwoSets(asignMap.get(assignmentName).getTags(), expectedTeamProfile, Assignment_List_Page.TAGS_CLS);
        WebElement button = asignMap.get(assignmentName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        Check.checkContentsOfTwoSets(ap.getAssignmentTags(), expectedTeamProfile, Assignment_Page.AS_TAGS);
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkContentsOfTwoSets(apn.getAssignmentTags(), expectedTeamProfile, Assignment_Page.AS_TAGS);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + ownerName);
        }
    }

    public static void checkEditPublAssignmentCurrMentorSuccess(String expectedMentorName, String assignmentName, String ownerName) {
        Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
        Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
        List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
        boolean found = false;
        for (AssignmentInfo ai : aiList) {
            if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(ownerName)) {
                if (expectedMentorName.equals(Assign_Without_Mentor_Management_Actions.MENTOR_NOT_ASSIGNED)) {
                    Click.clickAndWaitId(ai.getNameLink(), Assignment_Edit_Page.PAGE_ID);
                    Assignment_Edit_Page aep = new Assignment_Edit_Page();
                    Check.checkText(expectedMentorName, aep.form.getCurrentMentor(), Assignment_Edit_Page.PAGE_ID);
                }
                found = true;
                break;
            }

        }

        if (expectedMentorName.equals(Assign_Without_Mentor_Management_Actions.MENTOR_NOT_ASSIGNED)) {
            if (!found) {
                Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
                return;
            }
        } else {
            if (found) {
                Fail.failTestDueToWrongValue(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
                return;
            }
        }

        Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
        HashMap<String, Assignment> asignMap = alp.getAssignments();

        found = asignMap.containsKey(assignmentName);
        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
            return;
        }
        if (expectedMentorName.equals(Assign_Without_Mentor_Management_Actions.MENTOR_NOT_ASSIGNED)) {
            Check.checkText("Mentor dosud nepřiřazen", asignMap.get(assignmentName).getMentor(), Assignment_List_Page.MENTOR_NAME_CLS);
        } else
            Check.checkText(expectedMentorName, asignMap.get(assignmentName).getMentor(), Assignment_List_Page.MENTOR_NAME_CLS);

        WebElement button = asignMap.get(assignmentName).getDetailsButton();
        Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        if (expectedMentorName.equals(Assign_Without_Mentor_Management_Actions.MENTOR_NOT_ASSIGNED)) {
            Check.checkText("Mentor nepřiřazen", ap.getMentorName(), Assignment_Page.AS_MENTOR_NAME);
        } else
            Check.checkText(expectedMentorName, ap.getMentorName(), Assignment_Page.AS_MENTOR_NAME);

        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                if (expectedMentorName.equals(Assign_Without_Mentor_Management_Actions.MENTOR_NOT_ASSIGNED)) {
                    Check.checkText("Mentor nepřiřazen", apn.getMentorName(), Assignment_Page.AS_MENTOR_NAME);
                } else
                    Check.checkText(expectedMentorName, apn.getMentorName(), Assignment_Page.AS_MENTOR_NAME);
                found = true;
                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + ownerName);
        }

        if(!expectedMentorName.equals(Assign_Without_Mentor_Management_Actions.MENTOR_NOT_ASSIGNED)){
            Assignments_With_Mentor_Page awmp = new SideNavBarGarant_Page().clickOnAssignmentsWithMentorPageLink();
            HashMap<String,Assignment> hm = awmp.getAssignments();
            found = hm.containsKey(assignmentName);
            if (!found) {
                Fail.failTestDueToWrongValue(Assignments_With_Mentor_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
                return;
            }

                    Check.checkText(expectedMentorName,hm.get(assignmentName).getMentor(),Assignments_With_Mentor_Page.MENTOR_NAME_CLS );
        }
    }

    public static void checkEditPublAssignmentVisibilitySuccess(String visibility, String assignmentName, String ownerName) {

        if (visibility.equals(Assign_Without_Mentor_Management_Actions.VISIBILITY_ALL)) {
            Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
            Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
            List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
            boolean found = false;
            for (AssignmentInfo ai : aiList) {
                if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(ownerName)) {
                    found = true;
                    break;
                }

            }

            if (!found) {
                Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
                return;
            }

            Assignment_List_Page alp = new SideNavBarGarant_Page().clickAssignmentListPageLink();
            HashMap<String, Assignment> asignMap = alp.getAssignments();

            found = asignMap.containsKey(assignmentName);
            if (!found) {
                Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
                return;
            }
            WebElement button = asignMap.get(assignmentName).getDetailsButton();
            Click.clickAndWaitId(button, Assignment_Page.PAGE_ID);
            Assignment_Page ap = new Assignment_Page();
            Check.checkText(assignmentName, ap.getName(), Assignment_Page.AS_NAME);

        }

        if(visibility.equals(Assign_Without_Mentor_Management_Actions.VISIBILITY_MENTOR)) {
            Assignments_Without_Mentor_Management awmm = new SideNavBarGarant_Page().clickOnAssignmentsWithoutMentorPageLink();
            Check.checkPage(Assignments_Without_Mentor_Management.PAGE_ID);
            List<AssignmentInfo> aiList = awmm.getAssignmentsWithoutMentor();
            boolean found = false;
            for (AssignmentInfo ai : aiList) {
                if (ai.getNameText().equals(assignmentName) && ai.getOwner().equals(ownerName)) {
                    found = true;
                    break;
                }

            }

            if (!found) {
                Fail.failTestDueToMissingTextInTable(Assignments_Without_Mentor_Management.TABLE, "Assignment: " + assignmentName + " " + ownerName);
                return;
            }

            Login_Actions.loginIfNecessary("mentor");
            Assignments_Without_Mentor_Page alp = new SideNavBarMentor_Page().clickOnAssignmentsWithoutMentor();
            List<AssignmentInfo> ainfoList = alp.getUnmentoredAssignments();

            AssignmentInfo ainfo = new AssignmentInfo();
            ainfo.setNameText(assignmentName);
            ainfo.setOwner(ownerName);
            found = ainfoList.contains(ainfo);

            if (!found) {
                Fail.failTestDueToMissingTextInTable(Assignment_List_Page.ASSIGNMENT_DIV_CLS, "Assignment: " + assignmentName + " " + ownerName);
                return;
            }
        }

        Login_Actions.loginIfNecessary("garant");
        Assignment_Management_Page amp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
        boolean found = false;
        for (AssignmentManagementTableRow row : amp.getAllAssignmnets()) {
            if (row.getName().getText().strip().equals(assignmentName) && row.getOwner().equals(ownerName)) {
                if(visibility.equals(Assign_Without_Mentor_Management_Actions.VISIBILITY_MENTOR)){
                    Check.checkText("Viditelné pouze pro mentory",row.getState(),Assignment_Management_Page.TABLE);
                }
                if(visibility.equals(Assign_Without_Mentor_Management_Actions.VISIBILITY_HIDDNEN)){
                    Check.checkText("Skryté",row.getState(),Assignment_Management_Page.TABLE);
                }
                Click.clickAndWaitId(row.getName(), Assignment_Page.PAGE_ID);
                Assignment_Page apn = new Assignment_Page();
                Check.checkText(assignmentName, apn.getName(), Assignment_Page.AS_NAME);
                found = true;


                break;
            }
        }

        if (!found) {
            Fail.failTestDueToMissingTextInTable(Assignment_Management_Page.TABLE, "Assignment: " + assignmentName + " " + ownerName);
        }



    }
}
