package pstsp.support.services.entities;

import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

/**
 * Class for data based on Team page, table of team members
 */
public class Student {
    private String name;
    private String personalID;
    private String email;
    private Set<String> roles;
    private boolean isLeader;


    public Student() {
        this.name = "";
        this.personalID = "";
        this.email = "";
        this.roles = new HashSet<>();
        this.isLeader = false;
    }

    public static String LEADER_ROLE = "Vedoucí";
    public static final String NO_ROLE = "Role nezvolena";

    public String getName() {
        return name;
    }

    public String getPersonalID() {
        return personalID;
    }

    public String getEmail() {
        return email;
    }

    public Set<String> getRoles() {
        return roles;
    }

    public void setName(String name) {
        this.name = name;
    }

    public void setIsLeader(boolean isLeader){
        this.isLeader = isLeader;
    }

    public boolean isLeader(){
        return isLeader;
    }
    public void setPersonalID(String personalID) {
        this.personalID = personalID;
    }

    /**
     * For setting name and faculty from single line
     * @param line line with format NAME\nFACULTY-PROGRAM
     */
    public void setNameAndPersonalId(String line){
        String parts[] = line.split("\n");

        if(parts.length != 2) {
            throw new IllegalArgumentException("Unsupported format for name and faculty");
        }
        this.name = parts[0];
        this.personalID = parts[1];
    }

    public void setRolesFromString(String line){
        if(line.strip().contains(NO_ROLE)){
            return;
        }
        String parts[] = line.split(" ");

        if(parts.length < 1) {
            throw new IllegalArgumentException("Unsupported format for role string");
        }

        for (String role: parts) {
            if(role.equals(LEADER_ROLE)){
                this.isLeader = true;
                continue;
            }
            this.roles.add(role);
        }
    }


    public void setEmail(String email) {
        this.email = email;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Student student = (Student) o;
        return name.equals(student.name) && personalID.equals(student.personalID) && email.equals(student.email) && roles.equals(student.roles);
    }

    @Override
    public int hashCode() {
        return Objects.hash(name, personalID, email, roles);
    }

    @Override
    public String toString() {
        return "Student{" +
                "name='" + name + '\'' +
                ", facultyProgram='" + personalID + '\'' +
                ", email='" + email + '\'' +
                ", roles=" + roles +
                '}';
    }
}
