package pstsp.support.services.entities.storage;

import org.openqa.selenium.By;
import org.openqa.selenium.InvalidArgumentException;
import org.openqa.selenium.WebElement;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.MyAlert;
import pstsp.support.services.entities.InterrestedTopicMentorTableRow;
import pstsp.support.tools.Drivers;

import java.util.List;
/**
 * Table from assignments without team - mentor table
 * @author David Kuta
 */
public class MentorInterrestTopicTable {
    public static final int MIN_OPTION = 0;
    public static final int MAX_OPTION = 2;

    // color options

    public static final String NOT_ASSIGNED = "secondary";
    public static final String NOT_GOOD = "danger";
    public static final String GOOD = "success";

    //optionPrefix
    public static final String OPTION_PREFIX = "assignmentsWithoutTeamPage-table-interAssign-option-";


    public final List<InterrestedTopicMentorTableRow> rowList;

    public MentorInterrestTopicTable(List<InterrestedTopicMentorTableRow> rowList) {
        this.rowList = rowList;
    }

    /**
     * sets value and waits for alert
     *
     * @param row    row in table
     * @param option option, number from 0 to 2
     */
    public void setStateValue(int row, int option) {
        if (row >= this.getRowCount()) {
            throw new InvalidArgumentException("Row " + row + " out of range from maximum value " + this.getRowCount());
        }

        if (option > MAX_OPTION) {
            throw new InvalidArgumentException("Option " + option + " out of range from maximum value " + MAX_OPTION);
        }
        Click.scrollToElement(this.rowList.get(row).getButtonToggle());
        //Click.clickAndWaitBy(this.rowList.get(row).getChangeButtonToggle(), By.id("projectPage-usedExp-leader-table-" + 3 + "-0"));
        String optionId = OPTION_PREFIX + row + "-" + option;
        Click.clickAndWaitBy(this.rowList.get(row).getButtonToggle(), By.id(optionId));
        WebElement optionToSelect = Drivers.getDriver().findElement(By.id(optionId));
        Click.clickAndWaitId(optionToSelect, MyAlert.MY_ALERT_ID);
    }

    public InterrestedTopicMentorTableRow getInterrestRow(String assignmentName, String teamName){
        int index = getIndexForAssignmentName(assignmentName,teamName);

        return this.rowList.get(index);
    }

    public int getIndexForAssignmentName(String assignmentName, String teamName) {

        for (int i = 0; i < rowList.size(); i++) {
            if (rowList.get(i).getAssignmentName().getText().strip().equals(assignmentName) &&
                    rowList.get(i).getTeamName().getText().strip().equals(teamName)) {
                return i;
            }
        }
        throw new IllegalArgumentException("No interrest from team " + teamName + " to assignment " + assignmentName);
    }

    public void setValueByNameAndAssign(String assignmentName, String teamName, int option){
        int row = getIndexForAssignmentName(assignmentName, teamName);
        setStateValue(row,option);
    }

    public String getActualButtonColor(int row) {
        return this.rowList.get(row).getButtonColor();
    }

    public boolean containsInterrest(String assignmentName, String teamName, String priority){
        for (InterrestedTopicMentorTableRow row: this.rowList) {
            if(row.getTeamName().getText().strip().equals(teamName) &&
                    row.getAssignmentName().getText().strip().equals(assignmentName) &&
                    row.getInterrestLevel().equals(priority)) {
                return true;
            }

        }
        return false;
    }

    public int getRowCount() {
        return rowList.size();
    }

    public String getColorForChoice(int choice) {
        switch (choice) {
            case 0: {
                return NOT_ASSIGNED;
            }
            case 1: {
                return NOT_GOOD;
            }
            case 2: {
                return GOOD;
            }
            default: {
                throw new IllegalArgumentException("Choice out of range. Correct is from <0;3>");
            }
        }
    }
}
