package pstsp.support.services.entities.storage;

import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.services.entities.Student;
import pstsp.support.test_utils.Fail;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
/**
 * Storage with students in team
 * @author David Kuta
 */
public class StudentStorage {
    private List<Student> storage;

    public StudentStorage(List<Student> storage) {
        this.storage = storage;
    }

    public Student getLeader() {
        for (Student stu : storage) {
            if (stu.isLeader()) {
                return stu;
            }
        }
        return null;
    }

    public boolean containsStudent(Student stu) {
        if (stu == null) {
            throw new IllegalArgumentException("Parameter is null");
        }

        return storage.contains(stu);
    }

    /**
     * Gets all roles from all members. Used to compare in incomplete team tests
     * @return list with all ocurences of roles
     */
    public List<String> getWholeTeamRoles(){
        List<String> roles = new ArrayList<>();
        for (Student stu: storage) {
            for (String role: stu.getRoles()) {
                roles.add(role);
            }
        }
        return roles;
    }
    /**
     * contains with student info special format
     *
     * @param studentInfo Firstname SURNAME (PERSONALID)
     * @return
     */
    public boolean containsStudent(String studentInfo) {
        String st[] = studentInfo.split(" ");
        String name = st[0] + " " + st[1];
        String personalId = st[2].replaceAll("[()]*", "");
        return storage.stream().anyMatch(student -> student.getName().equals(name) && student.getPersonalID().equals(personalId));
    }

    public void printStudents() {
        for (Student stu : storage) {
            System.out.println(stu.toString());
        }
    }

    /**
     * gets student info with format Firstname SURNAME (PERSONALID)
     *
     * @return set
     */
    public Set<String> getStudentInfoSet() {
        Set<String> set = new HashSet<>();
        storage.forEach(a -> set.add(a.getName() + " (" + a.getPersonalID() + ")"));
        return set;
    }

    /**
     * Gets student orde in table. Mostly used in edit team role testing
     * Fails test when the student is not found
     *
     * @param studentInfo Firstname SURNAME (PERSONALID)
     * @return index or -i if not found
     */
    public int getStudentOrder(String studentInfo) {
        String st[] = studentInfo.split(" ");
        String name = st[0] + " " + st[1];
        String personalId = st[2].replaceAll("[()]*", "");

        for (int i = 0; i < storage.size(); i++) {
            if (storage.get(i).getName().equals(name) && storage.get(i).getPersonalID().equals(personalId)) {
                return i;
            }
        }
        Fail.failTestDueToMissingTextInTable(Team_Page.TEAM_MEMBERS_TABLE, name + " " + personalId);
        return -1;
    }

    public Student getStudentByItsInfo(String studentInfo) {
        String st[] = studentInfo.split(" ");
        String name = st[0] + " " + st[1];
        String personalId = st[2].replaceAll("[()]*", "");

        for (Student stu : storage) {
            if (stu.getName().equals(name) && stu.getPersonalID().equals(personalId)) {
                return stu;
            }
        }
        Fail.failTestDueToMissingTextInTable(Team_Page.TEAM_MEMBERS_TABLE, name + " " + personalId);
        throw new IllegalStateException("Student is not in team");
    }

    public int getStudentCount() {
        return this.storage.size();
    }

    public List<Student> getData() {
        return storage;
    }

    /**
     * @return set of names in format First name Last name (schood id)
     */
    public Set<String> getTeamMemberNamesExceptLeader() {
        Set<String> result = new HashSet<>();
        for (Student student : storage) {
            if (student.isLeader()) {
                continue;
            }
            String str = student.getName();
            result.add(str);
        }
        return result;
    }
}
