package pstsp.support.services.login;

import pstsp.support.basic.Const;
import pstsp.support.basic.Url;
import pstsp.support.pageobjects.commonparts.HeaderBar_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarUnlogged_Page;
import pstsp.support.pageobjects.login.Login_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.Utils;
import pstsp.support.test_oracle.storage.UsersSet;
import pstsp.support.test_utils.Fail;
import pstsp.support.tools.Drivers;

/**
 * Actions on Login page
 *
 * @author Pavel Herout
 * @version 2022-01-25
 */

public class Login_Actions {

    /**
     * Login user
     * <p>
     * Check if specified user is already logged in
     * if not logout actual user and log in specified user
     *
     * @param userName user name from file 'users_list.txt'
     */
    public static void loginIfNecessary(String userName) {
        String currentUrl = Utils.getCurrentUrl();
            if (!new HeaderBar_Page().canClickOnLoginBTN()) {
                if (Url.isValidLoginPageURL(currentUrl) == false) {
                    HeaderBar_Page headerBarPage = new HeaderBar_Page();
                    String loggedFullname = headerBarPage.getLoggedUserFullName();
                    String userFullname = UsersSet.getInstance().getUserByUsername(userName).getFullName();
                    if (loggedFullname.equals(userFullname) == true) {
                        // user is already logged in
                        new SideNavBarUnlogged_Page().clickHomePageLink();
                        return;
                    } else {
                        // another user is logged in
                        logoutIfPossible();
                    }
                }
            }
        // real logging activity
        Click.openUrlAndWait(Url.URL_LOGIN);
        Login_Page loginPage = new Login_Page();
        loginPage.setUsername(userName)
                .setPassword(Const.CORRECT_PASSWORD)
                .clickOnLoginButton();
    }

    /**
     * Logout user
     * <p>
     * Check if any user is already logged in
     * if yes logout this user
     */
    public static void logoutIfPossible() {
        String currentUrl = Utils.getCurrentUrl();
        if (!new HeaderBar_Page().canClickOnLoginBTN()) {
            if (Url.isValidLoginPageURL(currentUrl) == false) {
                HeaderBar_Page headerBarPage = new HeaderBar_Page();
                headerBarPage.clickOnLogoutLink();
            }
        }
    }
}
