package pstsp.support.services.login;

/**
 * Checking on Login page
 *
 * @author Pavel Herout
 * @version 2022-01-25
 */

import pstsp.support.pageobjects.commonparts.HeaderBar_Page;
import pstsp.support.pageobjects.login.Login_Page;
import pstsp.support.selenium_utils.MyAlert;
import pstsp.support.test_oracle.storage.UsersSet;
import pstsp.support.test_utils.Check;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class Login_Check {

  /**
   * Check Login success
   *
   * There is any alert present
   * Success means displaying user full name in the header
   *
   * @param userName specified user
   */
  public static void checkLoginSuccess(String userName) {
    HeaderBar_Page hbp = new HeaderBar_Page();
    String expectedFullname = UsersSet.getInstance().getUserByUsername(userName).getFullName();
    String actualFullname = hbp.getLoggedUserFullName();
    Check.checkText(expectedFullname, actualFullname, HeaderBar_Page.LOGOUT);
  }

  /**
   * Check Login error alert text
   */
  public static void checkLoginErrorAlert() {
//    Login_Page loginPage = new Login_Page();
//    String actual = loginPage.getErrorLoginAlertText();
//    String expected = loginPage.TXT_LOGIN_ALERT_ERROR;
//    Check.checkText(expected, actual, loginPage.LOGIN_ALERT_ERROR);
  }

  public static void checkLoginProcess(String expectedName, String expectedRole){
    HeaderBar_Page hbp = new HeaderBar_Page();
    String actualName = hbp.getLoggedUserFullName();
    String actualRole = hbp.getLoggedUserRole();
    Check.checkText(expectedName,actualName,HeaderBar_Page.USER_NAME);
    Check.checkText(expectedRole,actualRole,HeaderBar_Page.USER_NAME);
  }
  /**
   * Check Logout success alert text
   **/
  public static void checkLogoutSuccessAlert() {
    String alertHeader = MyAlert.getAlert().getHeaderText();
    Check.checkText(MyAlert.SUCCES_HEADER, alertHeader, MyAlert.MY_ALERT_ID);
    MyAlert.getAlert().closeAlert();
  }

  /**
   * Check Logout error alert text
   *
   * POZOR: Tento alert se bezne nevyskytuje, proto nema v LoginPage
   * ani ID ani TEXT (nastaveno na "???")
   */
  public static void checkLogoutErrorAlert() {
//    Login_Page loginPage = new Login_Page();
//    String actual = loginPage.getErrorLogoutAlertText();
//    String expected = loginPage.TXT_LOGOUT_ALERT_ERROR;
//    Check.checkText(expected, actual, loginPage.LOGOUT_ALERT_ERROR);
  }

}
