package pstsp.support.services.project;

import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.mentoredprojects.Mentored_Projects_Page;
import pstsp.support.pageobjects.mentormanagement.Mentor_Management_Page;
import pstsp.support.pageobjects.project.Mentor_View_On_Project_Page;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.pageobjects.teammanagement.Team_Manag_Edit_Page;
import pstsp.support.pageobjects.teammanagement.Team_Management_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.entities.MentorInfo;
import pstsp.support.services.entities.TeamStateTableRow;
import pstsp.support.services.entities.storage.ProjectTable;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.mentoredprojects.Mentored_Projects_Actions;
import pstsp.support.test_utils.Check;

import java.util.List;
/**
 * Actions on project page from garant view
 * Garant
 * @author David Kuta
 */
public class Project_Garant_Actions {

    public static void editMinimalCriteriaTableFromTeamManagementSuccess(String stepName, int choice, String teamName, String currentUser){
        Login_Actions.loginIfNecessary(currentUser);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if (row.getProject().getText().strip().equals(teamName)) {
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        Mentor_View_On_Project_Page mvp = new Mentor_View_On_Project_Page();

        ProjectTable before = mvp.getMinimalCriteriaMentorTable();
        //row
        int row = before.getIndexForStepName(stepName);
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row, choice);
        Check.checkAndCloseAlert(true);
        Project_Garant_Check.checkEditMinimalCriteriaTableFromTeamManagementSuccess(
                stepName, expectedColor, teamName);
    }

    public static void editProjectStateTableFromTeamManagementSuccess(String stepName, int choice, String teamName, String currentUser){
        Login_Actions.loginIfNecessary(currentUser);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if (row.getProject().getText().strip().equals(teamName)) {
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        Mentor_View_On_Project_Page mvp = new Mentor_View_On_Project_Page();

        ProjectTable before = mvp.getProjectStateMentorTable();
        //row
        int row = before.getIndexForStepName(stepName);
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row, choice);
        Check.checkAndCloseAlert(true);
        Project_Garant_Check.checkEditProjectStateTableFromTeamManagementSuccess(
                stepName, expectedColor, teamName);
    }

    public static void editUsedExpTableFromTeamManagementSuccess(String stepName, String otherInfo, int choice, String teamName, String currentUser){
        Login_Actions.loginIfNecessary(currentUser);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if (row.getProject().getText().strip().equals(teamName)) {
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        Mentor_View_On_Project_Page mvp = new Mentor_View_On_Project_Page();

        ProjectTable before = mvp.getUsedExpMentorTable();
        //row
        int row = before.getIndexForStepNameAndTextInfo(stepName, otherInfo);
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row, choice);
        Check.checkAndCloseAlert(true);
        Project_Garant_Check.checkEditUsedExpTableFromTeamManagementSuccess(
                stepName, otherInfo, expectedColor);
    }

    public static void editMinimalCriteriaTableFromMentorManagementSuccess(String stepName, int choice, String teamName, String assignmentName, String mentorFullName,  String currentUser){
        Login_Actions.loginIfNecessary(currentUser);
        Mentor_Management_Page tmp = new SideNavBarGarant_Page().clickOnMentorManagementPageLink();
        List<MentorInfo> table = tmp.getTableWithMentorInfo();
        boolean found = false;
        for (MentorInfo row : table) {
            if (row.getName().getText().strip().equals(mentorFullName) && row.getTeamName().equals(teamName) && row.getProjectName().equals(assignmentName)) {
                Click.clickAndWaitId(row.getName(), Mentored_Projects_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        found = false;
        Mentored_Projects_Page mpp = new Mentored_Projects_Page();
        for(TeamStateTableRow row : mpp.getMentoredProjectsTable()) {
            if(row.getProject().getText().strip().equals(assignmentName) && row.getTeam().getText().strip().equals(teamName)){
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Mentored_Projects_Page.MENTORER_PROJECTS_TBL, "Assignment and team: " + assignmentName + " " + teamName + "not found");
        Mentor_View_On_Project_Page mvp = new Mentor_View_On_Project_Page();

        ProjectTable before = mvp.getMinimalCriteriaMentorTable();
        //row
        int row = before.getIndexForStepName(stepName);
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row, choice);
        Check.checkAndCloseAlert(true);
        Project_Garant_Check.checkEditMinimalCriteriaTableFromMentorManagementSuccess(
                stepName, expectedColor, teamName, assignmentName, mentorFullName);
    }

    public static void editProjStateTableFromMentorManagementSuccess(String stepName, int choice, String teamName, String assignmentName, String mentorFullName,  String currentUser){
        Login_Actions.loginIfNecessary(currentUser);
        Mentor_Management_Page tmp = new SideNavBarGarant_Page().clickOnMentorManagementPageLink();
        List<MentorInfo> table = tmp.getTableWithMentorInfo();
        boolean found = false;
        for (MentorInfo row : table) {
            if (row.getName().getText().strip().equals(mentorFullName) && row.getTeamName().equals(teamName) && row.getProjectName().equals(assignmentName)) {
                Click.clickAndWaitId(row.getName(), Mentored_Projects_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        found = false;
        Mentored_Projects_Page mpp = new Mentored_Projects_Page();
        for(TeamStateTableRow row : mpp.getMentoredProjectsTable()) {
            if(row.getProject().getText().strip().equals(assignmentName) && row.getTeam().getText().strip().equals(teamName)){
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Mentored_Projects_Page.MENTORER_PROJECTS_TBL, "Assignment and team: " + assignmentName + " " + teamName + "not found");
        Mentor_View_On_Project_Page mvp = new Mentor_View_On_Project_Page();

        ProjectTable before = mvp.getProjectStateMentorTable();
        //row
        int row = before.getIndexForStepName(stepName);
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row, choice);
        Check.checkAndCloseAlert(true);
        Project_Garant_Check.checkEditProjectStateTableFromMentorManagementSuccess(
                stepName, expectedColor, teamName, assignmentName, mentorFullName);
    }

    public static void editUsedExpTableFromMentorManagementSuccess(String stepName, String otherInfo, int choice, String teamName, String assignmentName, String mentorFullName,  String currentUser){
        Login_Actions.loginIfNecessary(currentUser);
        Mentor_Management_Page tmp = new SideNavBarGarant_Page().clickOnMentorManagementPageLink();
        List<MentorInfo> table = tmp.getTableWithMentorInfo();
        boolean found = false;
        for (MentorInfo row : table) {
            if (row.getName().getText().strip().equals(mentorFullName) && row.getTeamName().equals(teamName) && row.getProjectName().equals(assignmentName)) {
                Click.clickAndWaitId(row.getName(), Mentored_Projects_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        found = false;
        Mentored_Projects_Page mpp = new Mentored_Projects_Page();
        for(TeamStateTableRow row : mpp.getMentoredProjectsTable()) {
            if(row.getProject().getText().strip().equals(assignmentName) && row.getTeam().getText().strip().equals(teamName)){
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Mentored_Projects_Page.MENTORER_PROJECTS_TBL, "Assignment and team: " + assignmentName + " " + teamName + "not found");
        Mentor_View_On_Project_Page mvp = new Mentor_View_On_Project_Page();

        ProjectTable before = mvp.getUsedExpMentorTable();
        //row
        int row = before.getIndexForStepNameAndTextInfo(stepName, otherInfo);
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row, choice);
        Check.checkAndCloseAlert(true);
        Project_Garant_Check.checkEditUsedExpTableFromMentorManagementSuccess(
                stepName,otherInfo, expectedColor, teamName, assignmentName, mentorFullName);
    }
}
