package pstsp.support.services.project;

import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.mentoredprojects.Mentored_Projects_Page;
import pstsp.support.pageobjects.mentormanagement.Mentor_Management_Page;
import pstsp.support.pageobjects.project.Mentor_View_On_Project_Page;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.pageobjects.teammanagement.Team_Management_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.entities.MentorInfo;
import pstsp.support.services.entities.TeamStateTableRow;
import pstsp.support.services.entities.storage.ProjectTable;
import pstsp.support.test_utils.Check;

import java.util.List;
/**
 * Check on actions on project page from garant view
 * Garant
 * @author David Kuta
 */
public class Project_Garant_Check {

    public static void checkEditMinimalCriteriaTableFromTeamManagementSuccess(String stepName, String expectedColor, String teamName) {
        Check.checkPage(Mentor_View_On_Project_Page.PAGE_ID);
        Mentor_View_On_Project_Page page = new Mentor_View_On_Project_Page();
        ProjectTable after = page.getMinimalCriteriaMentorTable();
        int row = after.getIndexForStepName(stepName);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");

        //checkAtGarantSite site -> counts
        int expDanger = after.getDangerCount();
        int expWarning = after.getWarningCount();
        int expSuccess = after.getSuccessCount();

        List<TeamStateTableRow> table = new SideNavBarGarant_Page().clickOnTeamManagementPageLink().getTeamManagementTable();
        for (TeamStateTableRow garantRow: table) {
            if(garantRow.getProject().getText().equals(teamName)) {
                int actualDanger = garantRow.getMinCritRed();
                int actualWarning = garantRow.getMinCritOrange();
                int actualSuccess = garantRow.getMinCritGreen();
                if(expDanger != actualDanger || expWarning != actualWarning || actualSuccess != expSuccess){
                    Check.checkCorrectness(false, Team_Management_Page.TABLE, "wrong count of steps\n"+
                            "expected " + expDanger + " " + expWarning + " " + expSuccess + " but was " + actualDanger + " " + actualWarning + " " + actualSuccess);
                }
                break;
            }
        }
    }

    public static void checkEditProjectStateTableFromTeamManagementSuccess(String stepName, String expectedColor, String teamName) {
        Check.checkPage(Mentor_View_On_Project_Page.PAGE_ID);
        Mentor_View_On_Project_Page page = new Mentor_View_On_Project_Page();
        ProjectTable after = page.getProjectStateMentorTable();
        int row = after.getIndexForStepName(stepName);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");

        //checkAtGarantSite site -> counts
        int expDanger = after.getDangerCount();
        int expWarning = after.getWarningCount();
        int expSuccess = after.getSuccessCount();

        List<TeamStateTableRow> table = new SideNavBarGarant_Page().clickOnTeamManagementPageLink().getTeamManagementTable();
        for (TeamStateTableRow garantRow: table) {
            if(garantRow.getProject().getText().equals(teamName)) {
                int actualDanger = garantRow.getPrjStateRed();
                int actualWarning = garantRow.getPrjStateOrange();
                int actualSuccess = garantRow.getPrjStateGreen();
                if(expDanger != actualDanger || expWarning != actualWarning || actualSuccess != expSuccess){
                    Check.checkCorrectness(false, Team_Management_Page.TABLE, "wrong count of steps\n"+
                            "expected " + expDanger + " " + expWarning + " " + expSuccess + " but was " + actualDanger + " " + actualWarning + " " + actualSuccess);
                }
                break;
            }
        }
    }

    public static void checkEditUsedExpTableFromTeamManagementSuccess(String stepName,  String otherInfo, String expectedColor) {
        Check.checkPage(Mentor_View_On_Project_Page.PAGE_ID);
        Mentor_View_On_Project_Page page = new Mentor_View_On_Project_Page();
        ProjectTable after = page.getUsedExpMentorTable();
        int row = after.getIndexForStepNameAndTextInfo(stepName, otherInfo);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");
    }

    public static void checkEditMinimalCriteriaTableFromMentorManagementSuccess(String stepName, String expectedColor, String teamName, String assignmentName, String mentorFullName) {
        Check.checkPage(Mentor_View_On_Project_Page.PAGE_ID);
        Mentor_View_On_Project_Page page = new Mentor_View_On_Project_Page();
        ProjectTable after = page.getMinimalCriteriaMentorTable();
        int row = after.getIndexForStepName(stepName);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");

        //checkAtGarantSite site -> counts
        int expDanger = after.getDangerCount();
        int expWarning = after.getWarningCount();
        int expSuccess = after.getSuccessCount();
        Mentor_Management_Page tmp = new SideNavBarGarant_Page().clickOnMentorManagementPageLink();
        List<MentorInfo> table = tmp.getTableWithMentorInfo();
        boolean found = false;
        for (MentorInfo mentInfoRow : table) {
            if (mentInfoRow.getName().getText().strip().equals(mentorFullName) && mentInfoRow.getTeamName().equals(teamName) && mentInfoRow.getProjectName().equals(assignmentName)) {
                Click.clickAndWaitId(mentInfoRow.getName(), Mentored_Projects_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        found = false;
        Mentored_Projects_Page mpp = new Mentored_Projects_Page();
        for(TeamStateTableRow mentProjRow : mpp.getMentoredProjectsTable()) {
            if(mentProjRow.getProject().getText().strip().equals(assignmentName) && mentProjRow.getTeam().getText().strip().equals(teamName)){
                int actualDanger = mentProjRow.getMinCritRed();
                int actualWarning = mentProjRow.getMinCritOrange();
                int actualSuccess = mentProjRow.getMinCritGreen();
                if(expDanger != actualDanger || expWarning != actualWarning || actualSuccess != expSuccess){
                    Check.checkCorrectness(false, Team_Management_Page.TABLE, "wrong count of steps\n"+
                            "expected " + expDanger + " " + expWarning + " " + expSuccess + " but was " + actualDanger + " " + actualWarning + " " + actualSuccess);
                }
                found = true;
                break;

            }
        }
        Check.checkCorrectness(found, Mentored_Projects_Page.MENTORER_PROJECTS_TBL, "Assignment and team: " + assignmentName + " " + teamName + "not found");
    }

    public static void checkEditProjectStateTableFromMentorManagementSuccess(String stepName, String expectedColor, String teamName, String assignmentName, String mentorFullName) {
        Check.checkPage(Mentor_View_On_Project_Page.PAGE_ID);
        Mentor_View_On_Project_Page page = new Mentor_View_On_Project_Page();
        ProjectTable after = page.getProjectStateMentorTable();
        int row = after.getIndexForStepName(stepName);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");

        //checkAtGarantSite site -> counts
        int expDanger = after.getDangerCount();
        int expWarning = after.getWarningCount();
        int expSuccess = after.getSuccessCount();
        Mentor_Management_Page tmp = new SideNavBarGarant_Page().clickOnMentorManagementPageLink();
        List<MentorInfo> table = tmp.getTableWithMentorInfo();
        boolean found = false;
        for (MentorInfo mentInfoRow : table) {
            if (mentInfoRow.getName().getText().strip().equals(mentorFullName) && mentInfoRow.getTeamName().equals(teamName) && mentInfoRow.getProjectName().equals(assignmentName)) {
                Click.clickAndWaitId(mentInfoRow.getName(), Mentored_Projects_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        found = false;
        Mentored_Projects_Page mpp = new Mentored_Projects_Page();
        for(TeamStateTableRow mentProjRow : mpp.getMentoredProjectsTable()) {
            if(mentProjRow.getProject().getText().strip().equals(assignmentName) && mentProjRow.getTeam().getText().strip().equals(teamName)){
                int actualDanger = mentProjRow.getPrjStateRed();
                int actualWarning = mentProjRow.getPrjStateOrange();
                int actualSuccess = mentProjRow.getPrjStateGreen();
                if(expDanger != actualDanger || expWarning != actualWarning || actualSuccess != expSuccess){
                    Check.checkCorrectness(false, Team_Management_Page.TABLE, "wrong count of steps\n"+
                            "expected " + expDanger + " " + expWarning + " " + expSuccess + " but was " + actualDanger + " " + actualWarning + " " + actualSuccess);
                }
                found = true;
                break;

            }
        }
        Check.checkCorrectness(found, Mentored_Projects_Page.MENTORER_PROJECTS_TBL, "Assignment and team: " + assignmentName + " " + teamName + "not found");
    }

    public static void checkEditUsedExpTableFromMentorManagementSuccess(String stepName, String otherInfo, String expectedColor, String teamName, String assignmentName, String mentorFullName) {
        Check.checkPage(Mentor_View_On_Project_Page.PAGE_ID);
        Mentor_View_On_Project_Page page = new Mentor_View_On_Project_Page();
        ProjectTable after = page.getUsedExpMentorTable();
        int row = after.getIndexForStepNameAndTextInfo(stepName, otherInfo);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");
    }
}
