package pstsp.support.services.project;

import pstsp.support.pageobjects.commonparts.SideNavBarLeader_Page;
import pstsp.support.pageobjects.project.Edit_Links_Page;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.pageobjects.project.Project_Page_Add_Exp_Modal;
import pstsp.support.selenium_utils.MyAlert;
import pstsp.support.services.entities.storage.ProjectTable;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;

import java.util.List;
/**
 * Actions on project page from leader view
 * Leader
 * @author David Kuta
 */
public class Project_Leader_Actions {

    public static Project_Page goToProjectPageAsLeader(String userName){
        Login_Actions.loginIfNecessary(userName);
        SideNavBarLeader_Page snl = new SideNavBarLeader_Page();
        Project_Page ppage = snl.clickOnProjectPageLink();
        Check.checkPage(Project_Page.PAGE_ID);
        return ppage;
    }

    public static void editMinCritTblSuccess(String stepName, int choice, String leaderName, String mentorName) {
        Project_Page page = goToProjectPageAsLeader(leaderName);
        String teamName = page.getTeamName();
        String assignmentName = page.getAssignmentName();
        ProjectTable before = page.getMinimalCriteriaLeaderTable();
        //row
        int row = before.getIndexForStepName(stepName);
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row,choice);
        Check.checkAndCloseAlert(true);
        Project_Leader_Check.checkMinCritTblLeaderSuccessEdit(stepName, expectedColor, teamName, assignmentName, mentorName);
    }

    public static void editUsedExpTblSuccess(String subjectName, String subjNextInfo, int choice, String leaderName, String mentorName) {
        Project_Page page = goToProjectPageAsLeader(leaderName);
        String teamName = page.getTeamName();
        String assignmentName = page.getAssignmentName();
        ProjectTable before = page.getUsedExpLeaderTable();
        //row
        int row = before.getIndexForStepNameAndTextInfo(subjectName, subjNextInfo);
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row,choice);
        Check.checkAndCloseAlert(true);
        Project_Leader_Check.checkUsedExpTblLeaderSuccessEdit(subjectName, subjNextInfo, expectedColor, teamName, assignmentName, mentorName);
    }

    public static void addUsedExpSuccess(String subjectName, String subjectInfo, String leaderName){
        Project_Page page = goToProjectPageAsLeader(leaderName);
        Project_Page_Add_Exp_Modal modal = page.openAddExpModal();
        modal.setSubject(subjectName);
        modal.setSubjectInfo(subjectInfo);
        modal.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Project_Leader_Check.checkUsedExpRow(subjectName, subjectInfo);
    }

    public static void editProjStateTblSuccess(String stepName, int choice, String leaderName, String mentorName) {
        Project_Page page = goToProjectPageAsLeader(leaderName);
        String teamName = page.getTeamName();
        String assignmentName = page.getAssignmentName();
        ProjectTable before = page.getProjectStateLeaderTable();
        //row
        int row = before.getIndexForStepName(stepName);
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row,choice);
        Check.checkAndCloseAlert(true);
        Project_Leader_Check.checkProjStateTblLeaderSuccessEdit(stepName, expectedColor, teamName, assignmentName, mentorName);
    }

    public static void setProjectUrls(String storage, String management, String production, List<String> otherUrls, String leaderName) {
        Project_Page page = goToProjectPageAsLeader(leaderName);
        Edit_Links_Page links = page.clickOnEditLinksBtn();
        links.setStorage(storage);
        links.setManagement(management);
        links.setProduction(production);
        links.setOther(otherUrls);
        links.clickOnSubmitButton();
        Check.checkAndCloseAlert(true);
        Check.checkPage(Project_Page.PAGE_ID);
        Project_Leader_Check.checkProjectLinks(storage,management,production,otherUrls);

    }
}
