package pstsp.support.services.project;

import pstsp.support.pageobjects.project.Mentor_View_On_Project_Page;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.services.entities.ProjectLink;
import pstsp.support.services.entities.storage.ProjectTable;
import pstsp.support.services.mentoredprojects.Mentored_Projects_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.Fail;

import java.util.ArrayList;
import java.util.List;
/**
 * Check on actions on project page from leader view
 * Leader
 * @author David Kuta
 */
public class Project_Leader_Check {

    public static void checkMinCritTblLeaderSuccessEdit(String stepName, String expectedColor, String teamName,
                                                        String assignmentName, String mentorName) {
        Check.checkPage(Project_Page.PAGE_ID);
        Project_Page page = new Project_Page();
        ProjectTable after = page.getMinimalCriteriaLeaderTable();
        int row = after.getIndexForStepName(stepName);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");


        Mentor_View_On_Project_Page mvop = Mentored_Projects_Actions.goToProjectPage(teamName,assignmentName,mentorName);
        ProjectTable mentorTable = mvop.getMinimalCriteriaMentorTable();
        String mentorActualColor = mentorTable.getActualValueDisabled(row);
        Check.checkText(expectedColor, mentorActualColor,"Colors does not match");
    }

    public static void checkUsedExpTblLeaderSuccessEdit(String subjectName, String subjNextInfo, String expectedColor,
                                                        String teamName, String assignmentName, String mentorName) {
        Check.checkPage(Project_Page.PAGE_ID);
        Project_Page page = new Project_Page();
        ProjectTable after = page.getUsedExpLeaderTable();
        int row = after.getIndexForStepNameAndTextInfo(subjectName,subjNextInfo);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");



        Mentor_View_On_Project_Page mvop = Mentored_Projects_Actions.goToProjectPage(teamName,assignmentName,mentorName);
        ProjectTable mentorTable = mvop.getUsedExpMentorTable();
        String mentorActualColor = mentorTable.getActualValueDisabled(row);
        Check.checkText(expectedColor, mentorActualColor,"Colors does not match");
    }

    public static void checkUsedExpRow(String subjectName, String subjectInfo) {
        Check.checkPage(Project_Page.PAGE_ID);
        Project_Page page = new Project_Page();
        ProjectTable usedExp = page.getUsedExpLeaderTable();
        try {
            usedExp.getIndexForStepNameAndTextInfo(subjectName, subjectInfo);
        }
        catch (IllegalStateException e){
            Fail.failTestDueToMissingTextInTable(Project_Page.PROJECT_USED_EXP_TABLE,"missing subject " + subjectName + "with info: " + subjectInfo);
        }
    }

    public static void checkProjStateTblLeaderSuccessEdit(String stepName, String expectedColor, String teamName,
                                                          String assignmentName, String mentorName) {
        Check.checkPage(Project_Page.PAGE_ID);
        Project_Page page = new Project_Page();
        ProjectTable after = page.getProjectStateLeaderTable();
        int row = after.getIndexForStepName(stepName);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");

        Mentor_View_On_Project_Page mvop = Mentored_Projects_Actions.goToProjectPage(teamName,assignmentName,mentorName);;
        ProjectTable mentorTable = mvop.getProjectStateMentorTable();
        String mentorActualColor = mentorTable.getActualValueDisabled(row);
        Check.checkText(expectedColor, mentorActualColor,"Colors does not match");
    }

    public static void checkProjectLinks(String storage, String management, String production, List<String> otherUrls) {
        Check.checkPage(Project_Page.PAGE_ID);
        Project_Page page = new Project_Page();
        List<ProjectLink> reqLinks = page.getRequiredLinks();
        List<ProjectLink> optLinks = page.getOptionalLinks();

        Check.checkText(storage, reqLinks.get(0).getUrl(),Project_Page.REQ_URL_LIST);
        Check.checkText(management, reqLinks.get(1).getUrl(),Project_Page.REQ_URL_LIST);
        Check.checkText(production, reqLinks.get(2).getUrl(),Project_Page.REQ_URL_LIST);
        List<String> actualOptLinks = new ArrayList<>();
        optLinks.forEach(a -> actualOptLinks.add(a.getName()+";"+a.getUrl()));
        Check.checkContentsOfTwoLists(actualOptLinks, otherUrls, "Content of urls is not as expected");

    }
}
