package pstsp.support.services.project;

import pstsp.support.basic.Const;
import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarMentor_Page;
import pstsp.support.pageobjects.mentoredprojects.Mentored_Projects_Page;
import pstsp.support.pageobjects.project.Mentor_View_On_Project_Page;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.pageobjects.teammanagement.Team_Management_Page;
import pstsp.support.services.entities.TeamStateTableRow;
import pstsp.support.services.entities.storage.ProjectTable;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;

import java.util.List;
/**
 * Actions on project page from mentor view
 * Mentor
 * @author David Kuta
 */
public class Project_Mentor_Check {
    public static void checkMinCritTblSuccessEdit(String stepName, String expectedColor, String teamName, String assignmentName, String leaderName) {
        Check.checkPage(Project_Page.PAGE_ID);
        Mentor_View_On_Project_Page page = new Mentor_View_On_Project_Page();
        ProjectTable after = page.getMinimalCriteriaMentorTable();
        int row = after.getIndexForStepName(stepName);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");

        //checkAtMenthoredProjects site -> counts
        int expDanger = after.getDangerCount();
        int expWarning = after.getWarningCount();
        int expSuccess = after.getSuccessCount();

        Mentored_Projects_Page mentPage = new SideNavBarMentor_Page().clickOnMentoredProjects();
        List<TeamStateTableRow> tableContent = mentPage.getMentoredProjectsTable();
        for (TeamStateTableRow projRow: tableContent) {
            if(projRow.getTeam().getText().strip().equals(teamName) && projRow.getProject().getText().strip().equals(assignmentName)){
                int actualDanger = projRow.getMinCritRed();
                int actualWarning = projRow.getMinCritOrange();
                int actualSuccess = projRow.getMinCritGreen();
                if(expDanger != actualDanger || expWarning != actualWarning || actualSuccess != expSuccess){
                    Check.checkCorrectness(false,Mentored_Projects_Page.MENTORER_PROJECTS_TBL, "wrong count of steps\n"+
                            "expected " + expDanger + " " + expWarning + " " + expSuccess + " but was " + actualDanger + " " + actualWarning + " " + actualSuccess);
                }
            }

        }
        //check at leader site
        Project_Page leaderProj = Project_Leader_Actions.goToProjectPageAsLeader(leaderName);
        ProjectTable leaderTable = leaderProj.getMinimalCriteriaLeaderTable();
        String mentorActualColor = leaderTable.getActualValueDisabled(row);
        Check.checkText(expectedColor, mentorActualColor,"Colors does not match");

        //check at garant
        Login_Actions.loginIfNecessary(Const.ROLE_GARANT);
        List<TeamStateTableRow> table = new SideNavBarGarant_Page().clickOnTeamManagementPageLink().getTeamManagementTable();
        for (TeamStateTableRow garantRow: table) {
            if(garantRow.getProject().getText().equals(teamName)) {
                int actualDanger = garantRow.getMinCritRed();
                int actualWarning = garantRow.getMinCritOrange();
                int actualSuccess = garantRow.getMinCritGreen();
                if(expDanger != actualDanger || expWarning != actualWarning || actualSuccess != expSuccess){
                    Check.checkCorrectness(false, Team_Management_Page.TABLE, "wrong count of steps\n"+
                            "expected " + expDanger + " " + expWarning + " " + expSuccess + " but was " + actualDanger + " " + actualWarning + " " + actualSuccess);
                }
                break;
            }
        }

    }

    public static void checkUsedExpTblSuccessEdit(String subjName, String subjInfo, String expectedColor, String leaderName) {
        Check.checkPage(Project_Page.PAGE_ID);
        Mentor_View_On_Project_Page page = new Mentor_View_On_Project_Page();
        ProjectTable after = page.getUsedExpMentorTable();
        int row = after.getIndexForStepNameAndTextInfo(subjName, subjInfo);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");

        //check at leader site
        Project_Page leaderProj = Project_Leader_Actions.goToProjectPageAsLeader(leaderName);
        ProjectTable leaderTable = leaderProj.getUsedExpLeaderTable();
        String mentorActualColor = leaderTable.getActualValueDisabled(row);
        Check.checkText(expectedColor, mentorActualColor,"Colors does not match");
    }

    public static void checkProjStateTblSuccessEdit(String stepName, String expectedColor, String teamName, String assignmentName, String leaderName) {
        Check.checkPage(Project_Page.PAGE_ID);
        Mentor_View_On_Project_Page page = new Mentor_View_On_Project_Page();
        ProjectTable after = page.getProjectStateMentorTable();
        int row = after.getIndexForStepName(stepName);
        //color check
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"Colors does not match");


        //checkAtMenthoredProjects site -> counts
        int expDanger = after.getDangerCount();
        int expWarning = after.getWarningCount();
        int expSuccess = after.getSuccessCount();

        Mentored_Projects_Page mentPage = new SideNavBarMentor_Page().clickOnMentoredProjects();
        List<TeamStateTableRow> tableContent = mentPage.getMentoredProjectsTable();
        for (TeamStateTableRow projRow: tableContent) {
            if(projRow.getTeam().getText().strip().equals(teamName) && projRow.getProject().getText().strip().equals(assignmentName)){
                int actualDanger = projRow.getPrjStateRed();
                int actualWarning = projRow.getPrjStateOrange();
                int actualSuccess = projRow.getPrjStateGreen();
                if(expDanger != actualDanger || expWarning != actualWarning || actualSuccess != expSuccess){
                    Check.checkCorrectness(false,Mentored_Projects_Page.MENTORER_PROJECTS_TBL, "wrong count of steps\n"+
                            "expected " + expDanger + " " + expWarning + " " + expSuccess + " but was " + actualDanger + " " + actualWarning + " " + actualSuccess);
                }
            }

        }

        //check at leader site
        Project_Page leaderProj = Project_Leader_Actions.goToProjectPageAsLeader(leaderName);
        ProjectTable leaderTable = leaderProj.getProjectStateLeaderTable();
        String mentorActualColor = leaderTable.getActualValueDisabled(row);
        Check.checkText(expectedColor, mentorActualColor,"Colors does not match");

        //check at garant
        Login_Actions.loginIfNecessary(Const.ROLE_GARANT);
        List<TeamStateTableRow> table = new SideNavBarGarant_Page().clickOnTeamManagementPageLink().getTeamManagementTable();
        for (TeamStateTableRow garantRow: table) {
            if(garantRow.getProject().getText().equals(teamName)) {
                int actualDanger = garantRow.getPrjStateRed();
                int actualWarning = garantRow.getPrjStateOrange();
                int actualSuccess = garantRow.getPrjStateGreen();
                if(expDanger != actualDanger || expWarning != actualWarning || actualSuccess != expSuccess){
                    Check.checkCorrectness(false, Team_Management_Page.TABLE, "wrong count of steps\n"+
                            "expected " + expDanger + " " + expWarning + " " + expSuccess + " but was " + actualDanger + " " + actualWarning + " " + actualSuccess);
                }
                break;
            }
        }
    }
}
