package pstsp.support.services.scenario;

import pstsp.support.pageobjects.assignment.Assignment_Page;
import pstsp.support.pageobjects.assignment.Assignment_Page_Leader_Interrest_Modal;
import pstsp.support.pageobjects.assignmentlist.Assignment_List_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarLeader_Page;
import pstsp.support.pageobjects.team.Edit_Team_Page;
import pstsp.support.pageobjects.team.Edit_Team_Profile_Page;
import pstsp.support.pageobjects.team.Edit_Team_Roles_Page;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.assignment.Assignment_Check;
import pstsp.support.services.entities.storage.StudentStorage;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.services.team.Team_Check;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.Fail;

import java.util.Map;
import java.util.Set;
/**
 * Scenario leader actions - experiment
 * Leader
 * @author David Kuta
 */
public class Scenario_Leader_Actions {
    /**
     * Leader must be right after garant creation
     * Leader sets team name, members, completeness, team profile and make interrest on assignment
     *
     * @param expectedTeamName            team name to set
     * @param expectedTeamMembers         team members to set
     * @param isTeamComplete              if team is complete to set
     * @param rolesForTeamMembers         roles every team member
     * @param teamProfile                 team profile roles
     * @param interrestAssignmentName     assignment name to make interrest
     * @param interrestAssignmentPriority priorito for interrested assignment
     * @param currentUser                 user for login
     */
    public static void leaderStartFlow(String expectedTeamName, Set<String> expectedTeamMembers, boolean isTeamComplete, Map<String, Set<String>> rolesForTeamMembers, Set<String> teamProfile, String interrestAssignmentName, String interrestAssignmentPriority, String currentUser, String interrestedAssignmentMentorLogin) {
        Login_Actions.loginIfNecessary(currentUser);
        SideNavBarLeader_Page snl = new SideNavBarLeader_Page();
        Team_Page tp = snl.clickOnTeamPageLink();
        Edit_Team_Page etp = tp.clickOnTeamEditButton();
        String leader = etp.getTeamLeaderInfo();
        etp.setTeamName(expectedTeamName);
        etp.setTeamMembers(expectedTeamMembers);
        if (isTeamComplete) etp.setTeamComplete();
        else etp.setTeamInComplete();
        etp.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Check.checkTeamName(expectedTeamName);
        expectedTeamMembers.add(leader);
        Team_Check.checkTeamMembers(expectedTeamMembers);
        Team_Check.checkTeamComplete(isTeamComplete);
        tp = new SideNavBarLeader_Page().clickOnTeamPageLink();
        StudentStorage studStor = tp.getTeamMembers();
        Edit_Team_Roles_Page etrp = tp.clickOnEditTeamRoles();
        for (String member : expectedTeamMembers) {
            int index = studStor.getStudentOrder(member);
            etrp.selectValuesByVisibleText(index, rolesForTeamMembers.get(member));
        }
        etrp.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        tp = snl.clickOnTeamPageLink();
        for (String member : expectedTeamMembers) {
            tp = snl.clickOnTeamPageLink();
            Team_Check.checkTeamMemberRole(member, rolesForTeamMembers.get(member), isTeamComplete);
        }

        tp = snl.clickOnTeamPageLink();
        Edit_Team_Profile_Page etpp = tp.clickOnTeamProfileEditButton();
        etpp.selectValuesByVisibleText(teamProfile);
        etpp.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Check.checkTeamProfile(teamProfile);

        Assignment_List_Page alp = snl.clickAssignmentListPageLink();
        Click.clickAndWaitId(alp.getAssignments().get(interrestAssignmentName).getDetailsButton(), Assignment_Page.PAGE_ID);
        Assignment_Page ap = new Assignment_Page();
        if(!ap.getState().equals("Volné")){
            Fail.failTestDueToWrongValue(Assignment_Page.AS_STATE, "Assignment is not in state: Volné");
        }
        Assignment_Page_Leader_Interrest_Modal apli = ap.clickOnInterestButton();
        apli.selectWeightByVisibleText(interrestAssignmentPriority);
        apli.clickOnSubmit();
        Check.checkAndCloseAlert(true);
        Assignment_Check.checkLeaderInterestSuccess(interrestAssignmentName, interrestAssignmentPriority, interrestedAssignmentMentorLogin);
    }





}
