package pstsp.support.services.studentmanagement;

import org.openqa.selenium.WebElement;
import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.studentmanagement.Add_Student_Modal_Page;
import pstsp.support.pageobjects.studentmanagement.Add_Team_With_Leader_Page;
import pstsp.support.pageobjects.studentmanagement.Student_Management_Page;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.JavaScript;
import pstsp.support.selenium_utils.MyAlert;
import pstsp.support.services.entities.StudentManagementTableRow;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;

import javax.swing.event.CaretListener;
import java.util.List;
/**
 * Actions on student management page
 * Garant
 * @author David Kuta
 */
public class Student_Management_Actions {

    public static void addStudent(String login, String firstName, String lastName, String email, String personalID,
                                  String periodTSP, String fieldOfStudy, String faculty, String currentUser, String leader) {

        Login_Actions.loginIfNecessary(currentUser);
        Student_Management_Page smp = new SideNavBarGarant_Page().clickOnStudentManagementPageLink();
        Add_Student_Modal_Page asmp = smp.openAddStudentModal();
        asmp.setLoginT(login);
        asmp.setFirstnameT(firstName);
        asmp.setLastnameT(lastName);
        asmp.setEmailT(email);
        asmp.setPersonalidT(personalID);
        asmp.setPeriodS(periodTSP);
        asmp.setFieldOfStudyT(fieldOfStudy);
        asmp.setFacultyT(faculty);
        asmp.clickOnSubmitBTN();
        Check.checkPage(Student_Management_Page.PAGE_ID);
        Check.checkAndCloseAlert(true);
        Student_Management_Check.checkAddStudent(firstName, lastName, personalID,email,leader);
    }

    public static void makeStudentLeader(String firstName, String lastName, String email, String personalID,
                                  String expectedTeamName, String currentUser) {

        Login_Actions.loginIfNecessary(currentUser);
        Student_Management_Page smp = new SideNavBarGarant_Page().clickOnStudentManagementPageLink();
        List<StudentManagementTableRow> tbl = smp.getStudentTable();
        boolean found = false;

        for (StudentManagementTableRow row: tbl) {
            if(row.getFirstname().equals(firstName) && row.getLastname().equals(lastName) && row.getPersonalID().equals(personalID) && row.getEmail().equals(email)) {
                found = true;
                Check.checkText("Bez týmu",row.getState(),Student_Management_Page.TABLE);
                Click.clickAndWaitId(row.getMakeLeaderButton(), Add_Team_With_Leader_Page.PAGE_ID);
                break;
            }
        }
        Check.checkCorrectness(found,Student_Management_Page.TABLE,"Student not found");
        Check.checkPage(Add_Team_With_Leader_Page.PAGE_ID);
        Add_Team_With_Leader_Page atwl = new Add_Team_With_Leader_Page();

        atwl.setTeamName(expectedTeamName);
        atwl.clickOnSubmitBTN();
        Check.checkPage(Team_Page.PAGE_ID);
        Check.checkAndCloseAlert(true);
        Student_Management_Check.checkMakeStudentLeaderSuccess(firstName,lastName,email,personalID,expectedTeamName);
    }

    public static void removeStudent(String firstName, String lastName, String email, String personalID,String currentUser, String leader){
        Login_Actions.loginIfNecessary(currentUser);
        Student_Management_Page smp = new SideNavBarGarant_Page().clickOnStudentManagementPageLink();
        List<StudentManagementTableRow> tbl = smp.getStudentTable();
        boolean found = false;

        for (StudentManagementTableRow row: tbl) {
            if(row.getFirstname().equals(firstName) && row.getLastname().equals(lastName) && row.getPersonalID().equals(personalID) && row.getEmail().equals(email)) {
                found = true;
                Check.checkText("Bez týmu",row.getState(),Student_Management_Page.TABLE);
                row.getRemoveStudentButton().click();
                JavaScript.confirm_JS_Alert();
                break;
            }
        }
        Check.checkCorrectness(found,Student_Management_Page.TABLE,"Student not found");
        Check.checkPage(Student_Management_Page.PAGE_ID);
        Check.checkAndCloseAlert(true);
        Student_Management_Check.checkRemoveStudent(firstName,lastName,email,personalID, leader);
    }
}
