package pstsp.support.services.studentmanagement;

import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarLeader_Page;
import pstsp.support.pageobjects.studentmanagement.Student_Management_Page;
import pstsp.support.pageobjects.team.Edit_Team_Page;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.pageobjects.teammanagement.Team_Management_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.entities.Student;
import pstsp.support.services.entities.StudentManagementTableRow;
import pstsp.support.services.entities.TeamStateTableRow;
import pstsp.support.services.entities.storage.StudentStorage;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;

import java.util.List;
/**
 * Check on actions on student management page
 * Garant
 * @author David Kuta
 */
public class Student_Management_Check {
    public static void checkAddStudent(String firstName, String lastName, String personalID, String email, String leader) {
        Check.checkPage(Student_Management_Page.PAGE_ID);
        Student_Management_Page smp = new Student_Management_Page();
        List<StudentManagementTableRow> tbl = smp.getStudentTable();
        boolean found = false;
        for (StudentManagementTableRow row: tbl) {
            if(row.getFirstname().equals(firstName) && row.getLastname().equals(lastName) && row.getPersonalID().equals(personalID) && row.getEmail().equals(email)) {
                found = true;
                Check.checkText("Bez týmu",row.getState(),Student_Management_Page.TABLE);
                break;
            }
        }

        Check.checkCorrectness(found,Student_Management_Page.TABLE,"Student not found");

        Login_Actions.loginIfNecessary(leader);
        Team_Page tp = new SideNavBarLeader_Page().clickOnTeamPageLink();
        String studentInfo = firstName + " " + lastName + " ("+personalID+")";
        boolean contains = tp.clickOnTeamEditButton().getAllAvailableStudents().contains(studentInfo);
        Check.checkCorrectness(contains, Edit_Team_Page.TEAM_MEMBERS_S,"Student not found.");

    }

    public static void checkMakeStudentLeaderSuccess(String firstName, String lastName, String email, String personalID, String expectedTeamName) {
        Check.checkPage(Team_Page.PAGE_ID);
        Team_Page tp = new Team_Page();
        Check.checkText(expectedTeamName, tp.getTeamName(), Team_Page.PAGE_ID);
        Check.checkText("Tým hledá členy",tp.getTeamCompletionState(),Team_Page.COMPLETE_TEAM_STATE);
        Check.checkText("Projekt dosud nemá přiřazené téma",tp.getAssignmentName(),Team_Page.TEAM_ASSIGNMENT_NAME);

        StudentStorage studStor = tp.getTeamMembers();
        Student stu = new Student();
        stu.setName(firstName + " " + lastName);
        stu.setEmail(email);
        stu.setPersonalID(personalID);
        stu.setIsLeader(true);
        Check.checkCorrectness(studStor.containsStudent(stu),Team_Page.TEAM_MEMBERS_TABLE,"Student is not in table");
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> teamsTable = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row: teamsTable) {
            if(row.getProject().getText().strip().equals(expectedTeamName) && row.getOtherInfo().equals("Tým dosud nemá přiřazené téma")) {
                found = true;
                Click.clickAndWaitId(row.getProject(), Team_Page.PAGE_ID);
                Team_Page tp1 = new Team_Page();
                Check.checkText(expectedTeamName, tp1.getTeamName(), Team_Page.PAGE_ID);
                break;
            }
        }
        Check.checkCorrectness(found,Team_Management_Page.TABLE,"Team not found");
        Student_Management_Page smp = new SideNavBarGarant_Page().clickOnStudentManagementPageLink();
        List<StudentManagementTableRow> tbl = smp.getStudentTable();
        found = false;
        for (StudentManagementTableRow row: tbl) {
            if(row.getFirstname().equals(firstName) && row.getLastname().equals(lastName) && row.getPersonalID().equals(personalID) && row.getEmail().equals(email)) {
                found = true;
                Check.checkText("Vedoucí",row.getState(),Student_Management_Page.TABLE);
                break;
            }
        }

        Check.checkCorrectness(found,Student_Management_Page.TABLE,"Student not found");
    }

    public static void checkRemoveStudent(String firstName, String lastName, String email, String personalID, String leader) {
        Check.checkPage(Student_Management_Page.PAGE_ID);
        Student_Management_Page smp = new Student_Management_Page();
        List<StudentManagementTableRow> tbl = smp.getStudentTable();
        boolean notFound = true;
        for (StudentManagementTableRow row: tbl) {
            if(row.getFirstname().equals(firstName) && row.getLastname().equals(lastName) && row.getPersonalID().equals(personalID) && row.getEmail().equals(email)) {
                notFound = false;
                break;
            }
        }
        Check.checkCorrectness(notFound,Student_Management_Page.TABLE,"Student is found afted deleting.");

        Login_Actions.loginIfNecessary(leader);
        Team_Page tp = new SideNavBarLeader_Page().clickOnTeamPageLink();
        String studentInfo = firstName + " " + lastName + " ("+personalID+")";
        boolean contains = tp.clickOnTeamEditButton().getAllAvailableStudents().contains(studentInfo);
        Check.checkCorrectness(!contains, Edit_Team_Page.TEAM_MEMBERS_S,"Student found after deleting.");
    }
}
