package pstsp.support.services.tagmanagement;

import pstsp.support.basic.Const;
import pstsp.support.pageobjects.assignmentmanagement.Assignment_Create_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarLeader_Page;
import pstsp.support.pageobjects.tagsmanagement.TagsManagement_Page;
import pstsp.support.pageobjects.team.Edit_Team_Roles_Page;
import pstsp.support.services.entities.TagTableRow;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;

import java.util.List;
/**
 * Check on actions on tag management page
 * Garant
 * @author David Kuta
 */
public class Tag_Management_Check {

    public static String colorConvertToCssClass(String colorByName){
        switch (colorByName) {
            case "Modrá": {
                return "primary";
            }
            case "Žlutá": {
                return "warning";
            }
            case "Tyrkysová": {
                return "info";
            }
            case "Zelená": {
                return "success";
            }
            case "Šedá": {
                return "secondary";
            }
            case "Červená": {
                return "danger";
            }
            case "Černá": {
                return "gray";
            }
            case "Fialová": {
                return "purple";
            }
            case "Limetková": {
                return "lime";
            }
            case "Oranžová": {
                return "orange";
            }
            case "Růžová": {
                return "pink";
            }
        }

        return "";
    }

    public static void checkTeamProfileSuccess(String expectedName, boolean enabled) {
        Check.checkPage(TagsManagement_Page.PAGE_ID);
        List<TagTableRow> table = new TagsManagement_Page().getTeamProfileTagTable();
        boolean contains = false;
        for(TagTableRow ttr : table){
            if (ttr.getTagText().equals(expectedName) && (ttr.isAccesible() == enabled)) {
                contains = true;
                break;
            }
        }
        Check.checkCorrectness(contains,TagsManagement_Page.TEAM_PROFLIE_TABLE, "Tag with name: " + expectedName
                + " and usability" + enabled + "is not in table");
        Assignment_Create_Page acp = new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink().clickOnAddAssignment();
        contains = acp.form.getAllAvailableProfiles().contains(expectedName);

        Check.checkCorrectness(enabled ? contains : !contains,Assignment_Create_Page.PAGE_ID, "Tag with name: " + expectedName + "is in select");
    }

    public static void checkTeamRoleSuccess(String expectedName, String color, boolean enabled) {
        Check.checkPage(TagsManagement_Page.PAGE_ID);
        List<TagTableRow> table = new TagsManagement_Page().getTeamRoleTagTable();
        boolean contains = false;
        for(TagTableRow ttr : table){
            if (ttr.getTagText().equals(expectedName) && (ttr.isAccesible() == enabled) && ttr.getTagColor().equals(colorConvertToCssClass(color))) {
                contains = true;
                break;
            }
        }

        Check.checkCorrectness(contains,TagsManagement_Page.TEAM_ROLE_TABLE, "Tag with name: " + expectedName
                + " and usability" + enabled +"and color" + color + "is not in table");

        Login_Actions.loginIfNecessary(Const.ROLE_LEADER);
        Edit_Team_Roles_Page etrp = new SideNavBarLeader_Page().clickOnTeamPageLink().clickOnEditTeamRoles();
        contains = etrp.getAllAvailableOptions(0).contains(expectedName);
        Check.checkCorrectness(enabled ? contains : !contains,Edit_Team_Roles_Page.PAGE_ID, "Tag with name: " + expectedName
                + " is not in select");
    }
}
