package pstsp.support.services.team;

import org.openqa.selenium.WebElement;
import pstsp.support.pageobjects.mentoredprojects.Mentored_Projects_Page;
import pstsp.support.pageobjects.team.*;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.MyAlert;
import pstsp.support.services.entities.LeaderTopicInterrest;
import pstsp.support.services.entities.Meeting;
import pstsp.support.services.entities.TeamStateTableRow;
import pstsp.support.services.entities.storage.StudentStorage;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.Fail;

import java.text.ParseException;
import java.util.List;
import java.util.Set;

/**
 * Actions on team Page
 * @author David Kuta
 */
public class Team_Actions {

    public static Team_Page goToTeamPageAsLeader(String userName) {
        Login_Actions.loginIfNecessary(userName);
        Check.checkPage(Team_Page.PAGE_ID);
        return new Team_Page();
    }

    public static Team_Page goToTeamPageAsMentor(String teamName, String mentorName) {
        Login_Actions.loginIfNecessary(mentorName);
        Check.checkPage(Mentored_Projects_Page.PAGE_ID);
        List<TeamStateTableRow> list = new Mentored_Projects_Page().getMentoredProjectsTable();
        boolean found = false;
        for (TeamStateTableRow row: list) {
            if(row.getTeam().getText().strip().equals(teamName)){
                found = true;
                Click.clickAndWaitId(row.getTeam(),Team_Page.PAGE_ID);
                break;
            }
        }

        Check.checkCorrectness(found,Mentored_Projects_Page.MENTORER_PROJECTS_TBL, "Missing team " + teamName);
        return new Team_Page();

    }

    public static void editTeamNameAsLeaderSuccess(String expectedTeamName, String userName) {
        Team_Page tp = goToTeamPageAsLeader(userName);
        Edit_Team_Page etp = tp.clickOnTeamEditButton();
        etp.setTeamName(expectedTeamName);
        etp.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Check.checkTeamName(expectedTeamName);
    }

    public static void setTeamCompleteAsLeaderSuccess(String userName) {
        Team_Page tp = goToTeamPageAsLeader(userName);
        Edit_Team_Page etp = tp.clickOnTeamEditButton();
        etp.setTeamComplete();
        etp.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Check.checkTeamComplete(true);
    }

    public static void setTeamInCompleteAsLeaderSuccess(String userName) {
        Team_Page tp = goToTeamPageAsLeader(userName);
        Edit_Team_Page etp = tp.clickOnTeamEditButton();
        etp.setTeamInComplete();
        etp.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Check.checkTeamComplete(false);
    }

    public static void setTeamMemberRoleAsLeaderSuccess(String studentInfo, Set<String> expectedRoles, String userName) {
        Team_Page tp = goToTeamPageAsLeader(userName);
        StudentStorage st = tp.getTeamMembers();
        boolean isComplete = tp.isTeamComplete();
        int index = st.getStudentOrder(studentInfo);
        Edit_Team_Roles_Page etr = tp.clickOnEditTeamRoles();
        etr.selectValuesByVisibleText(index,expectedRoles);
        etr.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Check.checkTeamMemberRole(studentInfo, expectedRoles, isComplete);
    }

    public static void setTeamProfileAsLeaderSuccess(Set<String> expectedProfiles, String userName) {
        Team_Page tp = goToTeamPageAsLeader(userName);
        Edit_Team_Profile_Page etp = tp.clickOnTeamProfileEditButton();
        etp.selectValuesByVisibleText(expectedProfiles);
        etp.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Check.checkTeamProfile(expectedProfiles);
    }

    /**
     *
     * @param dateTime with format "d.M.y H:m
     * @param room
     * @param topic
     * @param with
     * @param userName
     */
    public static void addMeetingAsLeaderSuccess(String dateTime, String room, String topic, String with, String userName, String mentorName) {
        Team_Page tp = goToTeamPageAsLeader(userName);
        Team_Page_Meeting_Modal tmm = tp.openMeetingModal();
        String[] dt = dateTime.replace(".","").split(" ");
        tmm.setDateTimeDT(dt[0],dt[1]);
        tmm.setRoom(room);
        tmm.setTopic(topic);
        tmm.setWhoByVisibleText(with);
        tmm.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Meeting expected = new Meeting();
        try {
            expected.setDatetime(dateTime);
        }
        catch (Exception e){
            Fail.failTestDueToWrongValue("Wrong meeting format", dateTime);
        }
        expected.setRoom(room);
        expected.setTopicText(topic);
        expected.setWith(with);
        Team_Check.checkMeeting(expected, mentorName);

    }

    public static void deleteTopicInterrestAsLeaderSuccess(String topicName, String priority, String leaderName, String mentorName){
        Team_Page tp = goToTeamPageAsLeader(leaderName);
        String teamName = tp.getTeamName().strip();
        //String interrest = "";
        List<LeaderTopicInterrest> ltList = tp.getTopicInterrestTableContent();
        for (LeaderTopicInterrest lt: ltList) {
            if(lt.getTopicName().equals(topicName) && lt.getPriority().equals(priority)){
                WebElement btn = lt.getDeleteButton();
                Click.clickAndWaitId(btn, MyAlert.MY_ALERT_ID);
                break;
            }
        }
        Check.checkAndCloseAlert(true);
        Team_Check.checkDeletedTopicInterrest(topicName, teamName,priority, mentorName);
    }

    /**
     *
     * @param expectedMembers in format "fistName" "SURNAME" (PERSONAL ID)
     * @param userName for user
     */
    public static void editTeamMembersAsLeaderSuccess(Set<String> expectedMembers, String userName){
        Team_Page tp = Team_Actions.goToTeamPageAsLeader(userName);
        Edit_Team_Page et = tp.clickOnTeamEditButton();
        String leader = et.getTeamLeaderInfo();
        et.setTeamMembers(expectedMembers);
        et.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        expectedMembers.add(leader);
        Team_Check.checkTeamMembers(expectedMembers);
    }

    /**
     *
     * @param expectedDate with format d.M.y H:m
     * @param expectedDesc
     * @param userName
     */
    public static void editMeetingTopicDescriptionAsLeaderSuccess(String expectedDate, String expectedDesc, String userName){
        Team_Page tp = Team_Actions.goToTeamPageAsLeader(userName);
        List<Meeting> mtngs = tp.getAllMeetings();
        WebElement btn = null;
        for (Meeting mt:mtngs) {
            try{
                if(mt.getDatetime().equals(Meeting.getDateTimeFromString(expectedDate))){
                    btn = mt.getTopic();
                    break;
                }
            }
            catch (ParseException e){
                Fail.failTestDueToMissingElementText("Wrong datetime format " + expectedDate);
                return;
            }
        }
        if(btn == null){
            Fail.failTestDueToMissingElementText("No meeting with datetime " + expectedDate);
            return;
        }

        Click.clickAndWaitId(btn,Add_Meeting_Topic_Page.PAGE_ID);
        Add_Meeting_Topic_Page amp = new Add_Meeting_Topic_Page();
        amp.setDescription(expectedDesc);
        amp.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Check.checkMeetingTopicDescriptionAsLeader(expectedDate, expectedDesc);
    }

    /**
     *
     * @param dateTime with format "d.M.y H:m
     */
    public static void addMeetingAsMentorSuccess(String dateTime, String room, String topic, String with, String teamName, String mentorName) {

        Team_Page tp = goToTeamPageAsMentor(teamName, mentorName);
        Team_Page_Meeting_Modal tmm = tp.openMeetingModal();
        String[] dt = dateTime.replace(".","").split(" ");
        tmm.setDateTimeDT(dt[0],dt[1]);
        tmm.setRoom(room);
        tmm.setTopic(topic);
        tmm.setWhoByVisibleText(with);
        tmm.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Meeting expected = new Meeting();
        try {
            expected.setDatetime(dateTime);
        }
        catch (Exception e){
            Fail.failTestDueToWrongValue("Wrong meeting format", dateTime);
        }
        expected.setRoom(room);
        expected.setTopicText(topic);
        expected.setWith(with);
        Team_Check.checkMeeting(expected, mentorName);
    }

    /**
     *
     * @param expectedDate with format d.M.y H:m
     */
    public static void editMeetingTopicDescriptionAsMentorSuccess(String expectedDate, String expectedDesc, String teamName, String mentorName){
        Team_Page tp = goToTeamPageAsMentor(teamName, mentorName);
        List<Meeting> mtngs = tp.getAllMeetings();
        WebElement btn = null;
        for (Meeting mt:mtngs) {
            try{
                if(mt.getDatetime().equals(Meeting.getDateTimeFromString(expectedDate))){
                    btn = mt.getTopic();
                    break;
                }
            }
            catch (ParseException e){
                Fail.failTestDueToMissingElementText("Wrong datetime format " + expectedDate);
                return;
            }
        }
        if(btn == null){
            Fail.failTestDueToMissingElementText("No meeting with datetime " + expectedDate);
            return;
        }

        Click.clickAndWaitId(btn,Add_Meeting_Topic_Page.PAGE_ID);
        Add_Meeting_Topic_Page amp = new Add_Meeting_Topic_Page();
        amp.setDescription(expectedDesc);
        amp.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Check.checkMeetingTopicDescriptionAsMentor(expectedDate, expectedDesc, teamName);
    }


}
