package pstsp.support.services.team;

import org.openqa.selenium.WebElement;
import pstsp.support.basic.Const;
import pstsp.support.basic.Url;
import pstsp.support.pageobjects.assignment.Assignment_Page;
import pstsp.support.pageobjects.assignment.Assignment_Page_Leader_Interrest_Modal;
import pstsp.support.pageobjects.assignmentlist.Assignment_List_Page;
import pstsp.support.pageobjects.assignmentswithoutteam.Assignments_Without_Team_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarMentor_Page;
import pstsp.support.pageobjects.incompleteTeam.Incomplete_Team_Page;
import pstsp.support.pageobjects.mentoredprojects.Mentored_Projects_Page;
import pstsp.support.pageobjects.team.Add_Meeting_Topic_Page;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.entities.*;
import pstsp.support.services.entities.storage.MentorInterrestTopicTable;
import pstsp.support.services.entities.storage.StudentStorage;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.Fail;

import java.text.ParseException;
import java.util.*;

/**
 * Check on team actions
 * @author David Kuta
 */
public class Team_Check {

    public static void checkTeamName(String expectedTeamName){
        Check.checkPage(Team_Page.PAGE_ID);
        Team_Page tp = new Team_Page();
        String actual = tp.getTeamName();
        Check.checkText(expectedTeamName,actual, Const.BASE_TITLE_ID);
    }

    /**
     * check team members with a leader
     * @param expectedMembers in format Firstname SURNAME (PERSONALID)
     */
    public static void checkTeamMembers(Set<String> expectedMembers) {
        Check.checkPage(Team_Page.PAGE_ID);
        Team_Page tp = new Team_Page();
        StudentStorage st = tp.getTeamMembers();
        Check.checkContentsOfTwoSets(expectedMembers, st.getStudentInfoSet(),"Team members are not as expected");

    }

    public static void checkTeamComplete(boolean complete) {
        Check.checkPage(Team_Page.PAGE_ID);
        Team_Page tp = new Team_Page();
        boolean actual = tp.isTeamComplete();
        String teamName = tp.getTeamName();
        Check.checkBoolean(complete, actual, Team_Page.COMPLETE_TEAM_STATE);
        Click.openUrlAndWait(Url.URL_INCOMPLETE_TEAM);
        Incomplete_Team_Page it = new Incomplete_Team_Page();
        HashMap<String, IncompleteTeam> itm = it.getIncompleteTeams();
        boolean teamIsPresent = itm.keySet().contains(teamName);
        Check.checkBoolean(!complete,teamIsPresent,"ICOMPLETE TEAM BUT COMPLETE");
    }

    public static void checkTeamMemberRole(String studentInfo, Set<String> expectedRoles, boolean teamComplete){
        Check.checkPage(Team_Page.PAGE_ID);
        Team_Page tp = new Team_Page();
        String teamName = tp.getTeamName();
        StudentStorage st = tp.getTeamMembers();
        Student stu = st.getStudentByItsInfo(studentInfo);
        Check.checkContentsOfTwoSets(stu.getRoles(),expectedRoles,"Student " + studentInfo + " does not have correct roles");

        if(!teamComplete){
            List<String> teamRolesFromTeamPage = st.getWholeTeamRoles();
            Click.openUrlAndWait(Url.URL_INCOMPLETE_TEAM);
            Incomplete_Team_Page it = new Incomplete_Team_Page();
            HashMap<String, IncompleteTeam> itm = it.getIncompleteTeams();
            List<String> teamRolesFromIncompleteTeamPage = itm.get(teamName).getMemberRoles();
            Collections.sort(teamRolesFromTeamPage);
            Collections.sort(teamRolesFromIncompleteTeamPage);
            Check.checkContentsOfTwoLists(teamRolesFromIncompleteTeamPage,teamRolesFromTeamPage,"Student roles are not as expected");
        }
    }

    public static void checkTeamProfile(Set<String> expectedProfiles) {
        Check.checkPage(Team_Page.PAGE_ID);
        Team_Page tp = new Team_Page();
        Set<String> actualProfile = tp.getTeamProfile();
        Check.checkContentsOfTwoSets(actualProfile,expectedProfiles,"Team profile does not match");
    }

    public static void checkMeeting(Meeting expected, String mentorName) {
        Check.checkPage(Team_Page.PAGE_ID);
        Team_Page tp = new Team_Page();
        boolean result = tp.getAllMeetings().contains(expected);
        if(!result){
            Fail.failTestDueToMissingElementText(expected.toString());
        }
        boolean isInFuture = expected.getDatetime().after(new Date());
        if(isInFuture && expected.getWith().equals("Mentor")){
            Login_Actions.loginIfNecessary(mentorName);
            Check.checkPage(Mentored_Projects_Page.PAGE_ID);
            Mentored_Projects_Page mp = new Mentored_Projects_Page();
            List<MentUpcomingMeeting> lmp = mp.getAllUpcomingMeetings();
            boolean found = false;
            for (MentUpcomingMeeting upMeet:lmp) {
                if(expected.getDatetime().equals(upMeet.getDatetime()) && expected.getTopicText().equals(upMeet.getTopic()) && expected.getRoom().equals(upMeet.getRoom())){
                    found = true;
                    break;
                }
            }
            if(!found){
                Fail.failTestDueToMissingTextInTable(Mentored_Projects_Page.UPCOMING_MEETINGS_TBL,expected.toString());
            }
        }
    }

    public static void checkDeletedTopicInterrest(String topicName, String teamName, String priority, String mentorName) {
        Check.checkPage(Team_Page.PAGE_ID);
        Team_Page tp = new Team_Page();
        boolean result = tp.getTopicInterrestTableContent().stream().anyMatch(ti -> ti.getTopicName().equals(topicName) && ti.getPriority().equals(priority));
        if(result){
            Fail.failTestDueToWrongValue(Team_Page.TOPIC_INTERREST_TABLE,topicName);
        }
        Click.openUrlAndWait(Url.URL_ASSIGNMENT_LIST);
        Assignment_List_Page al = new Assignment_List_Page();
        Map<String,Assignment> assignmentMap = al.getAssignments();
        if(assignmentMap.containsKey(topicName)){
            WebElement btn = assignmentMap.get(topicName).getDetailsButton();
            Click.clickAndWaitId(btn, Assignment_Page.PAGE_ID);
            Assignment_Page ap = new Assignment_Page();
            String actual = ap.getState();
            Check.checkText("Volné",actual,Assignment_Page.AS_STATE);
            Assignment_Page_Leader_Interrest_Modal aplim = ap.clickOnInterestButton();
            if(!aplim.getOptionsToSelect().contains(priority)){
                Fail.failTestDueToMissingTextInForm(Assignment_Page_Leader_Interrest_Modal.WEIGHT_SELECT,priority);
            }
            aplim.closeModal();

            Login_Actions.loginIfNecessary(mentorName);
            SideNavBarMentor_Page snm = new SideNavBarMentor_Page();
            Assignments_Without_Team_Page awt = snm.clickOnAssignmentsWithoutTeam();
            MentorInterrestTopicTable table = awt.getAllTopicInterrests();
            boolean contains = table.containsInterrest(topicName, teamName,priority);
            Check.checkBoolean(false, contains, "Interest is not deleted in mentors view");
        }
        else {
            Fail.failTestDueToMissingElementText(topicName);
        }
    }

    private static void checkMeetingTopicDescription(String expectedDate, String expectedDesc) {
        Team_Page tp = new Team_Page();
        List<Meeting> mtngs = tp.getAllMeetings();
        WebElement btn = null;
        for (Meeting mt:mtngs) {
            try{
                if(mt.getDatetime().equals(Meeting.getDateTimeFromString(expectedDate))){
                    btn = mt.getTopic();
                    break;
                }
            }
            catch (ParseException e){
                Fail.failTestDueToMissingElementText("Wrong datetime format " + expectedDate);
                return;
            }
        }
        if(btn == null){
            Fail.failTestDueToMissingElementText("No meeting with datetime " + expectedDate);
            return;
        }

        Click.clickAndWaitId(btn, Add_Meeting_Topic_Page.PAGE_ID);
        Add_Meeting_Topic_Page amp = new Add_Meeting_Topic_Page();
        String actual = amp.getDescription();
        Check.checkText(expectedDesc, actual,Add_Meeting_Topic_Page.DESCRIPTION_TA );

    }

    public static void checkMeetingTopicDescriptionAsLeader(String expectedDate, String expectedDesc) {
        Check.checkPage(Team_Page.PAGE_ID);
        checkMeetingTopicDescription(expectedDate, expectedDesc);
    }

    public static void checkMeetingTopicDescriptionAsMentor(String expectedDate, String expectedDesc, String teamName) {
        Check.checkPage(Team_Page.PAGE_ID);
        //List<TeamStateTableRow> list = new Mentored_Projects_Page().getMentoredProjectsTable();
        //boolean found = false;
        //for (TeamStateTableRow row: list) {
        //    if(row.getTeam().getText().strip().equals(teamName)){
        //        found = true;
        //        Click.clickAndWaitId(row.getTeam(),Team_Page.PAGE_ID);
        //        break;
        //    }
        //}
//
        //Check.checkCorrectness(found,Mentored_Projects_Page.MENTORER_PROJECTS_TBL, "Missing team " + teamName);
        checkMeetingTopicDescription(expectedDate,expectedDesc);

    }
}
