package pstsp.support.services.teammanagement;

import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.teammanagement.Team_Manag_Edit_Defence_Modal_Page;
import pstsp.support.pageobjects.teammanagement.Team_Manag_Edit_Page;
import pstsp.support.pageobjects.teammanagement.Team_Management_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.entities.DefenceInfo;
import pstsp.support.services.entities.TeamStateTableRow;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;

import java.util.List;
import java.util.Set;
/**
 * Actions on team management page
 * Garant
 * @author David Kuta
 */
public class Team_Management_Actions {

    public static void setFirstCreditSuccess(String expectedDatetime, String teamName, String leaderLogin, String garantLogin) {
        Login_Actions.loginIfNecessary(garantLogin);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if (row.getProject().getText().strip().equals(teamName)) {
                Click.clickAndWaitId(row.getTeam(), Team_Manag_Edit_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        Team_Manag_Edit_Page tmep = new Team_Manag_Edit_Page();

        Check.checkText(teamName, tmep.getTeamName(), Team_Manag_Edit_Page.TEAM_NAME_T);

        tmep.setCredit1DT(expectedDatetime);
        tmep.clickOnCreditSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Management_Check.checkEditCredit1Success(expectedDatetime, teamName, leaderLogin);
    }

    public static void setSecondCreditSuccess(String expectedDatetime, String teamName, String leaderLogin, String garantLogin) {
        Login_Actions.loginIfNecessary(garantLogin);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if (row.getProject().getText().strip().equals(teamName)) {
                Click.clickAndWaitId(row.getTeam(), Team_Manag_Edit_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        Team_Manag_Edit_Page tmep = new Team_Manag_Edit_Page();

        Check.checkText(teamName, tmep.getTeamName(), Team_Manag_Edit_Page.TEAM_NAME_T);

        tmep.setCredit2DT(expectedDatetime);
        tmep.clickOnCreditSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Management_Check.checkEditCredit2Success(expectedDatetime, teamName, leaderLogin);
    }

    /**
     * datetime in format DD. MM. RRRR
     *
     * @param expectedDefence
     * @param teamName
     * @param leaderLogin
     * @param garantLogin
     */
    public static void addDefenceSuccess(DefenceInfo expectedDefence, String teamName, String leaderLogin, String garantLogin) {
        Login_Actions.loginIfNecessary(garantLogin);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if (row.getProject().getText().strip().equals(teamName)) {
                Click.clickAndWaitId(row.getTeam(), Team_Manag_Edit_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + teamName + "not found");
        Team_Manag_Edit_Page tmep = new Team_Manag_Edit_Page();

        Check.checkText(teamName, tmep.getTeamName(), Team_Manag_Edit_Page.TEAM_NAME_T);

        Team_Manag_Edit_Defence_Modal_Page modal = tmep.openAddDefenceModal();
        String[] dateParts = expectedDefence.getDate().split("\\. ");
        String dateText = dateParts[0] + dateParts[1] + dateParts[2];
        modal.setDefenceDate(dateText);
        modal.setDefenceNumber("" + expectedDefence.getAttempt());
        modal.setDefenceResult(expectedDefence.getResult());
        modal.clickOnSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Management_Check.checkAddDefenceSuccess(expectedDefence, teamName, leaderLogin);
    }

    public static void editTeamNameSuccess(String expectedTeamName, String destTeamName, String currentUser) {
        Login_Actions.loginIfNecessary(currentUser);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if (row.getProject().getText().strip().equals(destTeamName)) {
                Click.clickAndWaitId(row.getTeam(), Team_Manag_Edit_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + destTeamName + "not found");
        Team_Manag_Edit_Page tmep = new Team_Manag_Edit_Page();

        Check.checkText(destTeamName, tmep.getTeamName(), Team_Manag_Edit_Page.TEAM_NAME_T);
        tmep.setTeamName(expectedTeamName);
        tmep.clickOnTeamEditSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Management_Check.checkEditTeamNameSuccess(expectedTeamName);
    }

    public static void editTeamMembersSuccess(Set<String> expTeamMembers, String destTeamName, String currentUser) {
        Login_Actions.loginIfNecessary(currentUser);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if (row.getProject().getText().strip().equals(destTeamName)) {
                Click.clickAndWaitId(row.getTeam(), Team_Manag_Edit_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + destTeamName + "not found");
        Team_Manag_Edit_Page tmep = new Team_Manag_Edit_Page();
        String leader = tmep.getTeamLeaderInfo();
        Check.checkText(destTeamName, tmep.getTeamName(), Team_Manag_Edit_Page.TEAM_NAME_T);
        tmep.setTeamMembers(expTeamMembers);
        tmep.clickOnTeamEditSubmitBTN();
        expTeamMembers.add(leader);
        Check.checkAndCloseAlert(true);
        Team_Management_Check.checkEditTeamMembersSuccess(expTeamMembers, destTeamName);
    }

    public static void editTeamCompletnessSuccess(boolean complete, String destTeamName, String currentUser) {
        Login_Actions.loginIfNecessary(currentUser);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if (row.getProject().getText().strip().equals(destTeamName)) {
                Click.clickAndWaitId(row.getTeam(), Team_Manag_Edit_Page.PAGE_ID);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found, Team_Management_Page.TABLE, "Team " + destTeamName + "not found");
        Team_Manag_Edit_Page tmep = new Team_Manag_Edit_Page();
        String leader = tmep.getTeamLeaderInfo();
        Check.checkText(destTeamName, tmep.getTeamName(), Team_Manag_Edit_Page.TEAM_NAME_T);
        if(complete) {
            tmep.setTeamComplete();
        }
        else {
         tmep.setTeamInComplete();
        }
        tmep.clickOnTeamEditSubmitBTN();
        Check.checkAndCloseAlert(true);
        Team_Management_Check.checkEditTeamCompletnessSuccess(complete, destTeamName);
    }


}
