package pstsp.support.services.teammanagement;

import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.pageobjects.commonparts.SideNavBarLeader_Page;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.pageobjects.team.Team_Page;
import pstsp.support.pageobjects.teammanagement.Team_Manag_Edit_Page;
import pstsp.support.pageobjects.teammanagement.Team_Management_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.Utils;
import pstsp.support.services.entities.DefenceInfo;
import pstsp.support.services.entities.TeamStateTableRow;
import pstsp.support.services.entities.storage.StudentStorage;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;

import java.util.List;
import java.util.Set;
/**
 * Check on actions on team management page
 * Garant
 * @author David Kuta
 */
public class Team_Management_Check {
    public static void checkEditCredit1Success(String expectedDatetime, String teamName, String leaderLogin) {
        Check.checkPage(Team_Manag_Edit_Page.PAGE_ID);
        Team_Manag_Edit_Page tmep = new Team_Manag_Edit_Page();
        Check.checkText(expectedDatetime,tmep.getCredit1Date(),Team_Manag_Edit_Page.CREDIT_TSP1_DATE);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if(row.getProject().getText().strip().equals(teamName)){
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                Project_Page pp = new Project_Page();
                String actualDate = pp.getCredit1Date();
                Check.checkText(expectedDatetime,actualDate,Project_Page.CREDIT_TSP1_DATE);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found,Team_Management_Page.TABLE,"Team " + teamName + "not found");
        Login_Actions.loginIfNecessary(leaderLogin);
        Project_Page pp = new SideNavBarLeader_Page().clickOnProjectPageLink();
        String actualDate = pp.getCredit1Date();
        Check.checkText(expectedDatetime,actualDate,Project_Page.CREDIT_TSP1_DATE);

    }

    public static void checkEditCredit2Success(String expectedDatetime, String teamName, String leaderLogin) {
        Check.checkPage(Team_Manag_Edit_Page.PAGE_ID);
        Team_Manag_Edit_Page tmep = new Team_Manag_Edit_Page();
        Check.checkText(expectedDatetime,tmep.getCredit2Date(),Team_Manag_Edit_Page.CREDIT_TSP2_DATE);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if(row.getProject().getText().strip().equals(teamName)){
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                Project_Page pp = new Project_Page();
                String actualDate = pp.getCredit2Date();

                Check.checkText(expectedDatetime,actualDate,Project_Page.CREDIT_TSP2_DATE);
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found,Team_Management_Page.TABLE,"Team " + teamName + "not found");
        Login_Actions.loginIfNecessary(leaderLogin);
        Project_Page pp = new SideNavBarLeader_Page().clickOnProjectPageLink();
        String actualDate = pp.getCredit2Date();
        Check.checkText(expectedDatetime,actualDate,Project_Page.CREDIT_TSP2_DATE);
    }

    public static void checkAddDefenceSuccess(DefenceInfo expectedDefence, String teamName, String leaderLogin) {
        Check.checkPage(Team_Manag_Edit_Page.PAGE_ID);
        Team_Manag_Edit_Page tmep = new Team_Manag_Edit_Page();
        List<DefenceInfo> actualDefence = tmep.getAllDefences();
        Check.checkCorrectness(actualDefence.contains(expectedDefence),Team_Manag_Edit_Page.DEFENCE_CARD,"Defence is not on site.");
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        List<TeamStateTableRow> table = tmp.getTeamManagementTable();
        boolean found = false;
        for (TeamStateTableRow row : table) {
            if(row.getProject().getText().strip().equals(teamName)){
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                Project_Page pp = new Project_Page();
                actualDefence = pp.getAllDefences();
                Check.checkCorrectness(actualDefence.contains(expectedDefence),Project_Page.DEFENCE_CARD,"Defence is not on site.");
                found = true;
                break;
            }
        }
        Check.checkCorrectness(found,Team_Management_Page.TABLE,"Team " + teamName + "not found");
        Login_Actions.loginIfNecessary(leaderLogin);
        Project_Page pp = new SideNavBarLeader_Page().clickOnProjectPageLink();
        actualDefence = pp.getAllDefences();
        Check.checkCorrectness(actualDefence.contains(expectedDefence),Project_Page.DEFENCE_CARD,"Defence is not on site.");
    }

    public static void checkEditTeamNameSuccess(String expectedTeamName) {
        Check.checkPage(Team_Manag_Edit_Page.PAGE_ID);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        boolean found = false;
        for (TeamStateTableRow row: tmp.getTeamManagementTable()) {
            if(row.getProject().getText().strip().equals(expectedTeamName)){
                found = true;
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                Project_Page pp = new Project_Page();
                Check.checkText(expectedTeamName, pp.getTeamName(), Project_Page.TEAM_NAME);
                break;
            }
        }
        Check.checkCorrectness(found,Team_Management_Page.TABLE,"Missing team: " + expectedTeamName );
    }

    public static void checkEditTeamMembersSuccess(Set<String> expTeamMembers, String destTeamName) {
        Check.checkPage(Team_Manag_Edit_Page.PAGE_ID);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        boolean found = false;
        for (TeamStateTableRow row: tmp.getTeamManagementTable()) {
            if(row.getProject().getText().strip().equals(destTeamName)){
                found = true;
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                StudentStorage stor = new SideNavBarLeader_Page().clickOnTeamPageLink().getTeamMembers();
                Check.checkContentsOfTwoSets(expTeamMembers, stor.getStudentInfoSet(),"Team members are not as expected");
                break;
            }
        }
        Check.checkCorrectness(found,Team_Management_Page.TABLE,"Missing team: " + destTeamName );
    }

    public static void checkEditTeamCompletnessSuccess(boolean complete, String destTeamName) {
        Check.checkPage(Team_Manag_Edit_Page.PAGE_ID);
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        boolean found = false;
        for (TeamStateTableRow row: tmp.getTeamManagementTable()) {
            if(row.getProject().getText().strip().equals(destTeamName)){
                found = true;
                Click.clickAndWaitId(row.getProject(), Project_Page.PAGE_ID);
                boolean isCompleteActual = new SideNavBarLeader_Page().clickOnTeamPageLink().isTeamComplete();
                Check.checkBoolean(complete, isCompleteActual, Team_Page.COMPLETE_TEAM_STATE);
                break;
            }
        }
        Check.checkCorrectness(found,Team_Management_Page.TABLE,"Missing team: " + destTeamName );
    }
}
