package pstsp.support.test_oracle;

/**
 * class
 *
 * @author Pavel Herout
 * @version 2022-01-25
 */

import pstsp.support.test_oracle.storage.ProjectPageStepList;
import pstsp.support.test_oracle.storage.UsersSet;
import pstsp.support.tools.ProjectLogger;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

public class OracleInicialization {

    /**
     * file for initializing of internal data
     */
    public static final String USERS_FILE_NAME = "users_list.txt";
//  public static final String USERS_FILE_NAME = "users_list-error1.txt";
//  public static final String USERS_FILE_NAME = "users_list-error2.txt";
//  public static final String USERS_FILE_NAME = "users_list-error3.txt";
//  public static final String USERS_FILE_NAME = "users_list-error4.txt";
    public static final String MINIMAL_CRITERIA_STEPS_FILE_NAME = "minimal_criteria_steps.txt";
//  public static final String MINIMAL_CRITERIA_STEPS_FILE_NAME = "minimal_criteria_steps-error1.txt";
    public static final String PROJECT_STATE_STEPS_FILE_NAME = "project_state_steps.txt";
//  public static final String PROJECT_STATE_STEPS_FILE_NAME = "project_state_steps-error1.txt";

    /**
     * URI of list of full names
     */
    public static String USERS_FILE_URI;
    public static String MINIMAL_CRITERIA_STEPS_FILE_URI;
    public static String PROJECT_STATE_STEPS_FILE_URI;

    public static void setAllFilesUri(String configDir) {
        USERS_FILE_URI = configDir + USERS_FILE_NAME;
        MINIMAL_CRITERIA_STEPS_FILE_URI = configDir + MINIMAL_CRITERIA_STEPS_FILE_NAME;
        PROJECT_STATE_STEPS_FILE_URI = configDir + PROJECT_STATE_STEPS_FILE_NAME;
    }

    public static void restoreOracleStorage() {
        UsersSet.getInstance().restore();
        ProjectLogger.logger.debug("Users file:       " + USERS_FILE_URI);
        UsersSet.getInstance().readUsers();
        ProjectLogger.logger.debug("Users number:     " + UsersSet.getInstance().getAllUsers().size());
        ProjectPageStepList.getInstance().restore();
        ProjectLogger.logger.debug("Minimal criteria step file:       " + MINIMAL_CRITERIA_STEPS_FILE_URI);
        ProjectLogger.logger.debug("Project state step file:       " + PROJECT_STATE_STEPS_FILE_URI);
        ProjectPageStepList.getInstance().readMinimalCriteriaSteps();
        ProjectLogger.logger.debug("Minimal criteria step size:       " + ProjectPageStepList.getInstance().getAllMinimalCriteriaSteps().size());
        ProjectPageStepList.getInstance().readProjectStateSteps();
        ProjectLogger.logger.debug("Project state step size:       " + ProjectPageStepList.getInstance().getAllProjectStateSteps().size());
    }

    /**
     * Reads file and skips all empty or comment lines
     *
     * @param fileName name of config file
     * @return list of valuable lines
     */
    public static List<String> readValidLinesFile(String fileName) {
        List<String> validLines = new ArrayList<>();
        try {
            List<String> lines = Files.readAllLines(Paths.get(fileName));

            for (int i = 0; i < lines.size(); i++) {
                String line = lines.get(i).trim();
                if (isEmptyOrCommentLine(line) == true) {
                    continue;
                }
                validLines.add(line);
                ProjectLogger.logger.trace("File line:        " + line);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }

        return validLines;
    }

    /**
     * Check if a line is empty or comment line
     *
     * @param line checked line
     * @return true if line is empty or comment line, false otherwise
     */
    private static boolean isEmptyOrCommentLine(String line) {
        String tmpLine = line.trim();
        if (tmpLine.isEmpty() == true) {
            return true;
        }
        if (tmpLine.startsWith("#") == true) {
            return true;
        }

        return false;
    }
}
