package pstsp.support.test_oracle.storage;

import pstsp.support.test_oracle.OracleInicialization;
import pstsp.support.tools.ProjectLogger;

import java.util.LinkedList;
import java.util.List;

/**
 * Project page table step list
 * @author David Kuta
 */
public class ProjectPageStepList {

    /** Only one instance - Singleton design pattern */
    private static final ProjectPageStepList INSTANCE = new ProjectPageStepList();

    /** all steps */
    private List<String> minCritSteps;
    private List<String> projectStateSTeps;

    /** Private constructor - Singleton design pattern */
    private ProjectPageStepList() {
        minCritSteps = new LinkedList<>();
        projectStateSTeps = new LinkedList<>();
    }

    /**
     * Get only one instance
     *
     * @return only one instance
     */
    public static ProjectPageStepList getInstance() {
        return INSTANCE;
    }

    /**
     * Get all minimalCriteriaSteps
     *
     * @return all steps
     */
    public List<String> getAllMinimalCriteriaSteps() {
        return minCritSteps;
    }

    /**
     * Get all projectStateSteps
     *
     * @return all steps
     */
    public List<String> getAllProjectStateSteps() {
        return projectStateSTeps;
    }

    /**
     * Delete all users
     */
    public void restore() {
        minCritSteps.clear();
        projectStateSTeps.clear();
    }

    public void readMinimalCriteriaSteps() {
        List<String> lines = OracleInicialization.readValidLinesFile(
                OracleInicialization.MINIMAL_CRITERIA_STEPS_FILE_NAME);
        if (lines.isEmpty()) {
            ProjectLogger.logger.error("No valid minimal criteria step in the file");
            throw new IllegalArgumentException("No valid minimal criteria step in the file");
        }

        for (String line : lines) {
            minCritSteps.add(line);
            ProjectLogger.logger.trace("Minimal criteria step:             " + line);
        }
    }

    public void readProjectStateSteps() {
        List<String> lines = OracleInicialization.readValidLinesFile(
                OracleInicialization.PROJECT_STATE_STEPS_FILE_NAME);
        if (lines.isEmpty()) {
            ProjectLogger.logger.error("No valid project state step in the file");
            throw new IllegalArgumentException("No valid project state step in the file");
        }

        for (String line : lines) {
            projectStateSTeps.add(line);
            ProjectLogger.logger.trace("Project state step:             " + line);
        }
    }
}
