package pstsp.support.tools;

import org.openqa.selenium.WebDriver;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.edge.EdgeDriver;
import org.openqa.selenium.firefox.FirefoxDriver;
import org.openqa.selenium.opera.OperaDriver;
import org.openqa.selenium.opera.OperaOptions;
import pstsp.support.basic.Configurations;

import java.io.File;

/**
 * Class for WebDriver
 * <p>
 * Serves for an initial settings of the chosen web driver
 *
 * @author Pavel Herout
 * @version 2022-02-09
 */
public class Drivers {

  /**
   * supported browser - its name must be the same as in  configuration file @see uis.support.basic.Configurations
   */
  private static final String CHROME_BROWSER = "Chrome";

  /**
   * supported browser - its name must be the same as in configuration file @see pstsp.support.basic.Configurations
   */
  private static final String OPERA_BROWSER = "Opera";

  /**
   * supported browser - its name must be the same as in configuration file @see pstsp.support.basic.Configurations
   */
  private static final String FIREFOX_BROWSER = "Firefox";

  /**
   * supported browser - its name must be the same as in configuration file @see pstsp.support.basic.Configurations
   */
  private static final String EDGE_BROWSER = "Edge";

  /**
   * the value from  configuration file @see Configurations
   */
  public static String WEB_BROWSER_TYPE;

  /**
   * the value from configuration file
   *
   * @see Configurations
   */
  public static String CHROME_DRIVER_URI;

  /**
   * the value from configuration file
   *
   * @see Configurations
   */
  public static String OPERA_DRIVER_URI;

  /**
   * the value from configuration file
   *
   * @see Configurations
   */
  public static String FIREFOX_DRIVER_URI;

  /**
   * the value from configuration file
   *
   * @see Configurations
   */
  public static String OPERA_EXE_URI;

  /**
   * the value from configuration file
   *
   * @see Configurations
   */
  public static String EDGE_DRIVER_URI;

  /**
   * the value from configuration file
   *
   * @see Configurations
   */
  public static String MAXIMIZED_SCREEN;

  /**
   * the value from configuration file
   *
   * @see Configurations
   */
  public static String CLOSE_BROWSER;

  /**
   * WebDriver which is set according to configuration file
   *
   * @see Configurations
   */
  private static WebDriver driver;

  /**
   * Get WebDriver set according to configuration file
   *
   * @return WebDriver
   * @see Configurations
   */
  public static WebDriver getDriver() {
    return driver;
  }

  /**
   * Get type of browser according to configuration file
   *
   * @return type of browser
   * @see Configurations
   */
  public static String getBrowserType() {
    return WEB_BROWSER_TYPE;
  }

  /**
   * Set the proper web driver according to the setting in the config file
   */
  public static void setDriver() {
    if (driver != null) {
      return;
    }

    switch (WEB_BROWSER_TYPE) {
      case CHROME_BROWSER:
        driver = setChromeDriver();
        break;

      case OPERA_BROWSER:
        driver = setOperaDriver();
        break;

      case FIREFOX_BROWSER:
        driver = setFirefoxDriver();
        break;

      case EDGE_BROWSER:
        driver = setEdgeDriver();
        break;

      default:
        throw new UnsupportedOperationException("'" + WEB_BROWSER_TYPE + "' no such browser!");
    }

    if (MAXIMIZED_SCREEN.equals("true")) {
      driver.manage().window().maximize();
    }
  }

  /**
   * quit web driver, eg. close the web browser
   */
  public static void quitWebDriver() {
    if (driver != null) {
      driver.quit();
      driver = null;
    }
  }

  /**
   * initialize WebDriver
   *
   * @return WebDriver=ChromeDriver
   */
  private static WebDriver setChromeDriver() {
    System.setProperty("webdriver.chrome.driver", CHROME_DRIVER_URI);
    return new ChromeDriver();
  }

  /**
   * initialize WebDriver
   *
   * @return WebDriver=FirefoxDriver
   */
  private static WebDriver setFirefoxDriver() {
    System.setProperty("webdriver.gecko.driver", FIREFOX_DRIVER_URI);
    return new FirefoxDriver();
  }

  /**
   * initialize WebDriver
   *
   * @return WebDriver=OperaDriver
   */
  private static WebDriver setOperaDriver() {
    System.setProperty("webdriver.opera.driver", OPERA_DRIVER_URI);
    OperaOptions options = new OperaOptions();
    options.setBinary(new File(OPERA_EXE_URI));
//    options.setExperimentalOption("w3c", true);
    return new OperaDriver(options);
  }

  /**
   * initialize WebDriver
   *
   * @return WebDriver=EdgeDriver
   */
  public static WebDriver setEdgeDriver() {
    System.setProperty("webdriver.edge.driver", EDGE_DRIVER_URI);
    return new EdgeDriver();
  }

}
