package pstsp.support.pageobjects.assignmentmanagement;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.openqa.selenium.devtools.v85.log.Log;
import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.HashSet;
import java.util.Set;

import static org.junit.jupiter.api.Assertions.*;

@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
class AssignmentManagementPageTest {
    Assignment_Management_Page amp;

    @BeforeEach
    void setUp() {
        Login_Actions.loginIfNecessary("garant");
        amp=new SideNavBarGarant_Page().clickOnAssignmentManagementPageLink();
    }

    @Test
    void getAllAssignmnets() {
        amp.getAllAssignmnets().get(0).getEditAction().click();
    }

    @Test
    void createAssignment() {
        Assignment_Create_Page acp = amp.clickOnAddAssignment();
        acp.form.setAssignmentName("Pokusné téma");
        String actual = acp.form.getAssignmentName();
        Check.checkText("Pokusné téma",actual,"");

        acp.form.setAssignmentDesc("sadasdasdasdasdaoidaoisd adhasdoiadwqoiudoiqwuduqd\nsdjasoidjaoisdjhioujhdioqwohdqd\nasdnajdjkadnasdasdasdasdasdasdasdasd");
        String ad = acp.form.getAssignmentDesc();
        Check.checkText("sadasdasdasdasdaoidaoisd adhasdoiadwqoiudoiqwuduqd\nsdjasoidjaoisdjhioujhdioqwohdqd\nasdnajdjkadnasdasdasdasdasdasdasdasd",ad,"");

        acp.form.setOwnerFirstname("Josef");
        String fr = acp.form.getOwnerFirstname();
        Check.checkText("Josef",fr,"");

        acp.form.setOwnerLastname("Zadavatel");
        String ls = acp.form.getOwnerLastname();
        Check.checkText("Zadavatel",ls,"");

        acp.form.setOwnerEmail("josev.zadavatel@example.org");
        String mail = acp.form.getOwnerEmail();
        Check.checkText("josev.zadavatel@example.org",mail,"");

        acp.form.setOwnerPhone("754456852");
        String tel = acp.form.getOwnerPhone();
        Check.checkText("754456852",tel,"");

        acp.form.setOwnerOtherInfo("Jsem zadavatel a přináším vám toto téma");
        String inf = acp.form.getOwnerOtherInfo();
        Check.checkText("Jsem zadavatel a přináším vám toto téma",inf,"");

        acp.form.setTimeNeeded("1300");
        String timeNeeded = acp.form.getTimeNeeded();
        Check.checkText("1300",timeNeeded,"");

        acp.form.setTeamSize("7");
        String teamSize = acp.form.getTeamSize();
        Check.checkText("7",teamSize,"");

        Set<String> profiles = new HashSet<>();
        profiles.add("PHP");
        profiles.add("JavaScript");
        profiles.add("Frontend");
        profiles.add("Backend");
        acp.form.setAssignmentProfile(profiles);
        Set<String> actualProf = acp.form.getAssignmentProfile();
        Check.checkContentsOfTwoSets(actualProf,profiles,"");

        acp.form.setMentor("Pavel Herout");
        String mentor = acp.form.getCurrentMentor();
        Check.checkText("Pavel Herout",mentor,"");

        acp.form.setPeriod("Testovací ročník");
        String period = acp.form.getCurrentPeriod();
        Check.checkText("Testovací ročník",period,"");

        acp.form.setVisibility("Publikováno pro všechny");
        String visibility = acp.form.getCurrentVisibility();
        Check.checkText("Publikováno pro všechny",visibility,"");
        acp.form.clickOnBackBTN();
        Check.checkPage(Assignment_Management_Page.PAGE_ID);
    }
}