package pstsp.support.pageobjects.login;

import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.openqa.selenium.By;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;
import pstsp.support.basic.Url;
import pstsp.support.pageobjects.commonparts.HeaderBar_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;
import pstsp.support.tools.Drivers;

import java.time.Duration;

@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
public class HeaderBarTest {

  static HeaderBar_Page hbPage;

  @BeforeAll
  static void setUpBeforeAll() {
    Click.openUrlAndWait(Url.URL_LOGIN);
    Login_Page loginPage = new Login_Page();
    loginPage.setUsername("mentor");
    loginPage.setPassword("tsp");
    loginPage.clickOnLoginButton();

    new WebDriverWait(Drivers.getDriver(), Duration.ofSeconds(1)).
            until(ExpectedConditions.visibilityOfAllElementsLocatedBy(
                    By.id(HeaderBar_Page.USER_NAME)));
    hbPage = new HeaderBar_Page();
  }

  @Test
  @DisplayName("TC_FullName")
  void fullName() {
    String actual = hbPage.getLoggedUserFullName();
    Check.checkText("Pan Mentor", actual,
            HeaderBar_Page.USER_NAME);
  }

  @Test
  @DisplayName("TC_Role")
  void role() {
    String actual = hbPage.getLoggedUserRole();
    Check.checkText("Mentor", actual,
            HeaderBar_Page.USER_NAME);
  }

  @Test
  void resetDB() {
    hbPage.clickOnResetDB();
  }
}
