package pstsp.support.pageobjects.project;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.basic.Url;
import pstsp.support.pageobjects.commonparts.SideNavBarLeader_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.selenium_utils.MyAlert;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.ArrayList;
import java.util.Arrays;

@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
public class EditLinksTest {

    Edit_Links_Page editLinksPage;

    @BeforeEach
    void setUp() {
        Login_Actions.loginIfNecessary("leader");
        SideNavBarLeader_Page sn = new SideNavBarLeader_Page();

        editLinksPage = sn.clickOnProjectPageLink().clickOnEditLinksBtn();
    }

    @Test
    @DisplayName("TC_StoragePlaceholder")
    void storagePlaceholderText() {
        String actual = editLinksPage.getStorageInputPlaceholderText();
        Check.checkPlaceholder(Edit_Links_Page.TXT_STORAGE_INPUT_PLACEHOLDER,
                actual, Edit_Links_Page.STORAGE_INPUT);
    }

    @Test
    @DisplayName("TC_ManagementPlaceholder")
    void managementPlaceholderText() {
        String actual = editLinksPage.getManagementInputPlaceholderText();
        Check.checkPlaceholder(Edit_Links_Page.TXT_MANAGEMENT_INPUT_PLACEHOLDER,
                actual, Edit_Links_Page.MANAGEMENT_INPUT);
    }

    @Test
    @DisplayName("TC_ProductionPlaceholder")
    void productionPlaceholderText() {
        String actual = editLinksPage.getProductionInputPlaceholderText();
        Check.checkPlaceholder(Edit_Links_Page.TXT_PRODUCTION_INPUT_PLACEHOLDER,
                actual, Edit_Links_Page.PRODUCTION_INPUT);
    }

    @Test
    @DisplayName("TC_OtherPlaceholder")
    void otherPlaceholderText() {
        String actual = editLinksPage.getOtherInputPlaceholderText();
        Check.checkPlaceholder(Edit_Links_Page.TXT_OTHER_INPUT_PLACEHOLDER,
                actual, Edit_Links_Page.OTHER_INPUT);
    }

    @Test
    @DisplayName("TC_Complex_Set")
    void complexValuesSet(){
        editLinksPage.setStorage("https://guthib.com/");
        editLinksPage.setManagement("https://github.com/");
        editLinksPage.setProduction("https://pstsp.hintik.cz/");
        editLinksPage.setOther(Arrays.asList("PSTSP;https://pstsp.hintik.cz/",
                "SPTPS;https://pstsp.hintik.cz/",
                "PPPPP;https://pstsp.hintik.cz/"));

        editLinksPage.clickOnSubmitButton();
        MyAlert.getAlert().closeAlert();
    }

}
