package pstsp.support.pageobjects.project;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.pageobjects.commonparts.SideNavBarLeader_Page;
import pstsp.support.services.entities.ProjectLink;
import pstsp.support.services.entities.storage.ProjectTable;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.List;

@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
class ProjectPageTest {

    Project_Page project_page;

    @BeforeEach
    void setUp() {
        Login_Actions.loginIfNecessary("leader");
        SideNavBarLeader_Page sn = new SideNavBarLeader_Page();

        this.project_page = sn.clickOnProjectPageLink();
    }

    @Test
    void getLeaderTableMinCritTest() {
        ProjectTable minCrit = project_page.getMinimalCriteriaLeaderTable();
        minCrit.getRowList().forEach(e -> System.out.println(e));
    }

    @Test
    void getLeaderTableUsedExpTest() {
        ProjectTable usedExp = project_page.getUsedExpLeaderTable();
        usedExp.getRowList().forEach(e -> System.out.println(e));
    }

    @Test
    void getLeaderTableProjectStateTest() {
        ProjectTable projState = project_page.getProjectStateLeaderTable();
        projState.getRowList().forEach(e -> System.out.println(e));
    }

    @Test
    void setLeaderTableMinCritTest(){
        ProjectTable before = project_page.getMinimalCriteriaLeaderTable();
        int choice = 2;
        int row = before.getIndexForStepName("Testování");
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row,choice);
        ProjectTable after = project_page.getMinimalCriteriaLeaderTable();
        row = after.getIndexForStepName("Testování");
        String actualColor = after.getActualValueEnabled(row);

        Check.checkText(expectedColor, actualColor,"BARVA");

    }

    @Test
    void setLeaderTableUsedExpTest(){
        ProjectTable before = project_page.getUsedExpLeaderTable();
        int choice = 2;
        int row = before.getIndexForStepNameAndTextInfo("KIV/OKS","Mimofunkční");
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row,choice);
        ProjectTable after = project_page.getUsedExpLeaderTable();
        row = after.getIndexForStepNameAndTextInfo("KIV/OKS","Mimofunkční");
        String actualColor = after.getActualValueEnabled(row);
        Check.checkText(expectedColor, actualColor,"BARVA");

    }

    @Test
    void setLeaderTableProjectStateTest(){
        ProjectTable before = project_page.getProjectStateLeaderTable();
        int row = before.getIndexForStepName("Výběr vhodných nástrojů pro vývoj i vedení projektu");
        int choice = 1;
        String expectedColor = before.getColorForChoice(choice);
        before.setStateValue(row,choice);
        ProjectTable after = project_page.getProjectStateLeaderTable();
        row = after.getIndexForStepName("Výběr vhodných nástrojů pro vývoj i vedení projektu");
        String actualColor = after.getActualValueEnabled(row);

        Check.checkText(expectedColor, actualColor,"BARVA");

    }

    @Test
    void clickOnEditLinksTest(){
        project_page.clickOnEditLinksBtn();
        Check.checkPage(Edit_Links_Page.PAGE_ID);

    }

    @Test
    void clickOnAddExperienceButton(){
        project_page.openAddExpModal();

    }

    @Test
    void getRequiredLinks(){
        List<ProjectLink> links = project_page.getRequiredLinks();
        links.forEach(a -> System.out.println(a.toString()));
    }

    @Test
    void getOptionalLinks(){
        List<ProjectLink> links = project_page.getOptionalLinks();
        links.forEach(a -> System.out.println(a.toString()));
    }

    @Test
    void getAssignmentName(){
        String expected = "Syntéza lidského hlasu";
        String actual = project_page.getAssignmentName();
        Check.checkText(expected,actual,Project_Page.ASSIGNMENT_NAME);
    }

    @Test
    void getTeamName(){
        String expected = "Nejlepší kodéři";
        String actual = project_page.getTeamName();
        Check.checkText(expected,actual,Project_Page.TEAM_NAME);
    }


}