package pstsp.support.pageobjects.team;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.basic.Const;
import pstsp.support.selenium_utils.MyAlert;
import pstsp.support.services.team.Team_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.HashSet;
import java.util.Set;


@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
class EditTeamPageTest {

    Edit_Team_Page editTeamPage;
    @BeforeEach
    void setUp() {
        Team_Page teamPage = Team_Actions.goToTeamPageAsLeader("leader");
        this.editTeamPage = teamPage.clickOnTeamEditButton();
    }

    @Test
    @DisplayName("TC_GET_NAME")
    void getTeamName() {
        String actual = this.editTeamPage.getTeamName();
        Check.checkText("Nejlepší kodéři",actual,Edit_Team_Page.TEAM_NAME_T);
    }

    @Test
    void setTeamName() {
        String expected = "Pokusný tým";
        this.editTeamPage.setTeamName(expected);
        String actual = editTeamPage.getTeamName();
        Check.checkText(expected,actual,Edit_Team_Page.TEAM_NAME_T);
    }

    @Test
    void getTeamLeaderName() {
        String expected = "Pan Vedoucí (AxxBxxxxP)";
        String actual = this.editTeamPage.getTeamLeaderInfo();
        Check.checkText(expected, actual,Edit_Team_Page.TEAM_LEADER_NAME_T);
    }

    @Test
    void isTeamLeaderNameEnabled() {
        boolean actual = this.editTeamPage.isTeamLeaderNameReadOnly();
        Check.checkIsReadOnly(actual,Edit_Team_Page.TEAM_LEADER_NAME_T);
    }

    @Test
    void setTeamMembers() {
        Set<String> expected = new HashSet<>();
        expected.add("David BUBIK (A19B0015P)");
        expected.add("Michaela BENEŠOVÁ (A19B0008P)");

        this.editTeamPage.setTeamMembers(expected);
        Set<String> actual = this.editTeamPage.getTeamMembers();

        Check.checkContentsOfTwoSets(actual, expected,"Students from edit select are not the same");
    }

    @Test
    void getTeamMembers() {
        Set<String> expected = new HashSet<>();
        expected.add("David BUBIK (A19B0015P)");
        expected.add("Michaela BENEŠOVÁ (A19B0008P)");
        expected.add("Pavel ČÁCHA (A19B0022P)");
        expected.add("Jan CHODORA (A19B0066P)");
        Set<String> actual = this.editTeamPage.getTeamMembers();
        Check.checkContentsOfTwoSets(actual,expected,"Students from edit select are not the same");
    }

    @Test
    void setTeamComplete() {
        this.editTeamPage.setTeamComplete();
        boolean actual = this.editTeamPage.isTeamComplete();
        Check.checkBoolean(true,actual,Edit_Team_Page.TEAM_COMPLETE_S);
    }

    @Test
    void setTeamInComplete() {
        this.editTeamPage.setTeamInComplete();
        boolean actual = this.editTeamPage.isTeamComplete();
        Check.checkBoolean(false,actual,Edit_Team_Page.TEAM_COMPLETE_S);
    }

    @Test
    void isTeamComplete() {
        boolean actual = this.editTeamPage.isTeamComplete();
        Check.checkBoolean(true,actual,Edit_Team_Page.TEAM_COMPLETE_S);
    }

    @Test
    void clickOnSubmitBTN() {
        String expected = "Nejlepší kodéři";
        editTeamPage.setTeamName(expected);
        editTeamPage.clickOnSubmitBTN();
        Team_Page a = new Team_Page();
        String actual = a.getTeamName();
        MyAlert.getAlert().closeAlert();
        Check.checkText(expected,actual, Const.BASE_TITLE_ID);
    }

    @Test
    void clickOnBackBTN() {
        editTeamPage.clickOnBackBTN();
        Check.checkPage(Team_Page.PAGE_ID);
    }
}