package pstsp.support.pageobjects.team;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.selenium_utils.MyAlert;
import pstsp.support.services.team.Team_Actions;
import pstsp.support.test_oracle.storage.UsersSet;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

import static org.junit.jupiter.api.Assertions.*;
@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
class EditTeamRolesPageTest {
    Edit_Team_Roles_Page editTeamRolesPage;
    @BeforeEach
    void setUp() {
        Team_Page teamPage = Team_Actions.goToTeamPageAsLeader("leader");
        this.editTeamRolesPage = teamPage.clickOnEditTeamRoles();
    }

    @Test
    void getStudentLabelText() {
        String expected = "Jakub CHURAVÝ (A18B0214P)";
        String actual = editTeamRolesPage.getStudentLabelText(5);
        Check.checkText(expected,actual,Edit_Team_Roles_Page.ROLES_PREFIX_SELECT+5);
    }

    @Test
    void getSelectedValuesTest() {
        Set<String> expected0 = new HashSet<>();
        expected0.add("Programátor");
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(0),expected0,"Roles arent as expected for order " + 0);
        Set<String> expected1 = new HashSet<>();
        expected1.add("Programátor");
        expected1.add("Dokumentarista");
        expected1.add("Tester");
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(1),expected1,"Roles arent as expected for order " + 1);
        Set<String> expected2 = new HashSet<>();
        expected2.add("Programátor");
        expected2.add("Dokumentarista");
        expected2.add("Grafik");
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(2),expected2,"Roles arent as expected for order " + 2);
        Set<String> expected3 = new HashSet<>();
        expected3.add("Grafik");
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(3),expected3,"Roles arent as expected for order " + 3);
        Set<String> expected4 = new HashSet<>();
        expected4.add("Grafik");
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(4),expected4,"Roles arent as expected for order " + 4);
        Set<String> expected5 = new HashSet<>();
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(5),expected5,"Roles arent as expected for order " + 5);
    }

    @Test
    void getSelectedValuesTestInvalid() {
        assertThrows(IllegalArgumentException.class, () -> editTeamRolesPage.getSelectedProfiles(8));
    }

    @Test
    void setValuesByVisibleTextTest() {
        Set<String> values = new HashSet<>();
        values.add("Dokumentarista");
        values.add("Programátor");
        values.add("Grafik");
        editTeamRolesPage.selectValuesByVisibleText(0,values);
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(0),values,"Roles arent as expected for order " + 0);
        editTeamRolesPage.selectValuesByVisibleText(1,values);
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(1),values,"Roles arent as expected for order " + 1);
        editTeamRolesPage.selectValuesByVisibleText(2,values);
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(2),values,"Roles arent as expected for order " + 2);
        editTeamRolesPage.selectValuesByVisibleText(3,values);
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(3),values,"Roles arent as expected for order " + 3);
        editTeamRolesPage.selectValuesByVisibleText(4,values);
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(4),values,"Roles arent as expected for order " + 4);
        editTeamRolesPage.selectValuesByVisibleText(5,values);
        Check.checkContentsOfTwoSets(editTeamRolesPage.getSelectedProfiles(5),values,"Roles arent as expected for order " + 5);
    }

    @Test
    void clickOnBackBTNTest() {
        editTeamRolesPage.clickOnBackBTN();
        Check.checkPage(Team_Page.PAGE_ID);

    }

    @Test
    void clickOnSubmitBTNTest() {
        editTeamRolesPage.clickOnSubmitBTN();
        MyAlert.getAlert().closeAlert();
    }

    @Test
    void scenarioTest() {
        int order = 5;
        Set<String> values = new HashSet<>();
        values.add("Programátor");
        editTeamRolesPage.selectValuesByVisibleText(order,values);
        editTeamRolesPage.clickOnSubmitBTN();
        MyAlert.getAlert().closeAlert();
        Team_Page pg = new Team_Page();
        pg.getTeamMembers();
        Check.checkContentsOfTwoSets(pg.getTeamMembers().getData().get(order).getRoles(),values, "Roles arent as expected");
    }

    @Test
    void getOptionsTest(){

        System.out.println(editTeamRolesPage.getAllAvailableOptions(0).toString());
    }
}