package pstsp.support.pageobjects.team;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import pstsp.support.services.entities.Meeting;
import pstsp.support.services.entities.storage.StudentStorage;
import pstsp.support.services.team.Team_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
public class TeamPageTest {

    Team_Page teamPage;

    @BeforeEach
    void setUp() {
        this.teamPage = Team_Actions.goToTeamPageAsLeader("leader");
    }

    @Test
    @DisplayName("TC_TABLE_CONTENT")
    void tableContent() {
        StudentStorage students = teamPage.getTeamMembers();
        students.printStudents();
    }

    @Test
    @DisplayName("TC_NAME")
    void getName() {
        String name = teamPage.getTeamName();
        Check.checkText("Nejlepší kodéři",name,Team_Page.PAGE_ID);
    }

    @Test
    @DisplayName("TC_ASSIGNMENT_NAME")
    void getAssignmentName() {
        String aName = teamPage.getAssignmentName();
        Check.checkText("Syntéza lidského hlasu",aName,Team_Page.TEAM_ASSIGNMENT_NAME);
    }

    @Test
    @DisplayName("TC_TEAM_PROFILE_EDIT_CLICK")
    void teamProfileEditClick() {
        teamPage.clickOnTeamProfileEditButton();
        Check.checkPage(Edit_Team_Profile_Page.PAGE_ID);
    }

    @Test
    @DisplayName("TC_TEAM_EDIT_CLICK")
    void teamEditClick() {
        teamPage.clickOnTeamEditButton();
        Check.checkPage(Edit_Team_Page.PAGE_ID);
    }

    @Test
    void getCompletionState(){
        String expected = "Tým hledá členy";
        String actual = teamPage.getTeamCompletionState();
        Check.checkText(expected,actual,Team_Page.COMPLETE_TEAM_STATE);
    }

    @Test
    void getTeamProfiles(){
        Set<String> expected = new HashSet<>();
        expected.add("Java");
        expected.add("JavaScript");
        Set<String> actual = teamPage.getTeamProfile();
        Check.checkContentsOfTwoSets(actual,expected,"Profile badges aren't as expected.");
    }
    @Test
    void getAllMeetings(){
        List<Meeting> meetingList = teamPage.getAllMeetings();
        System.out.println(meetingList);
    }

    @Test
    void hasAssignment(){
        boolean expected = true;
        boolean actual = teamPage.hasAssignment();
        Check.checkBoolean(expected, actual,Team_Page.TEAM_ASSIGNMENT_NAME);
    }

    @Test
    void openMeetingModal(){
        Team_Page_Meeting_Modal modal = teamPage.openMeetingModal();
    }

    @Test
    void clickOnEditTeamRoles(){
        teamPage.clickOnEditTeamRoles();
        Check.checkPage(Edit_Team_Roles_Page.PAGE_ID);
    }
}
