package pstsp.support.pageobjects.teammanagement;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.openqa.selenium.WebElement;
import pstsp.support.pageobjects.commonparts.SideNavBarGarant_Page;
import pstsp.support.selenium_utils.Click;
import pstsp.support.services.login.Login_Actions;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.HashSet;
import java.util.Set;

@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
class TeamManagEditPageTest {

    Team_Manag_Edit_Page editPage;

    @BeforeEach
    void setUp() {
        Login_Actions.loginIfNecessary("garant");
        Team_Management_Page tmp = new SideNavBarGarant_Page().clickOnTeamManagementPageLink();
        WebElement editButton = tmp.getTeamManagementTable().get(0).getTeam();
        Click.clickAndWaitId(editButton, Team_Manag_Edit_Page.PAGE_ID);
        editPage = new Team_Manag_Edit_Page();
    }

    @Test
    @DisplayName("TC_GET_NAME")
    void getTeamName() {
        String actual = this.editPage.getTeamName();
        Check.checkText("Mazáci", actual, Team_Manag_Edit_Page.TEAM_NAME_T);
    }

    @Test
    void setTeamName() {
        String expected = "Pokusný tým";
        this.editPage.setTeamName(expected);
        String actual = editPage.getTeamName();
        Check.checkText(expected, actual, Team_Manag_Edit_Page.TEAM_NAME_T);
    }

    @Test
    void getTeamLeaderName() {
        String expected = "Jan HINTERHOLZINGER (A19B0052P)";
        String actual = this.editPage.getTeamLeaderInfo();
        Check.checkText(expected, actual, Team_Manag_Edit_Page.TEAM_LEADER_NAME_T);
    }

    @Test
    void isTeamLeaderNameEnabled() {
        boolean actual = this.editPage.isTeamLeaderNameReadOnly();
        Check.checkIsReadOnly(actual, Team_Manag_Edit_Page.TEAM_LEADER_NAME_T);
    }

    @Test
    void setTeamMembers() {
        Set<String> expected = new HashSet<>();
        expected.add("Dominik JEŽ (A19B0078P)");
        expected.add("Michal DVOŘÁK (A19B0032P)");

        this.editPage.setTeamMembers(expected);
        Set<String> actual = this.editPage.getTeamMembers();

        Check.checkContentsOfTwoSets(actual, expected, "Students from edit select are not the same");
    }

    @Test
    void getTeamMembers() {
        Set<String> expected = new HashSet<>();
        expected.add("Daniel CÍFKA (A19B0021P)");
        expected.add("Ondřej MATURA (A19B0135P)");
        expected.add("Duy Anh TRAN (A20B0257P)");
        expected.add("Tomáš VYKYDAL (A19B0229P)");
        Set<String> actual = this.editPage.getTeamMembers();
        Check.checkContentsOfTwoSets(actual, expected, "Students from edit select are not the same");
    }

    @Test
    void setTeamComplete() {
        this.editPage.setTeamComplete();
        boolean actual = this.editPage.isTeamComplete();
        Check.checkBoolean(true, actual, Team_Manag_Edit_Page.TEAM_COMPLETE_S);
    }

    @Test
    void setTeamInComplete() {
        this.editPage.setTeamInComplete();
        boolean actual = this.editPage.isTeamComplete();
        Check.checkBoolean(false, actual, Team_Manag_Edit_Page.TEAM_COMPLETE_S);
    }

    @Test
    void isTeamComplete() {
        boolean actual = this.editPage.isTeamComplete();
        Check.checkBoolean(true, actual, Team_Manag_Edit_Page.TEAM_COMPLETE_S);
    }

    //@Test
    //void clickOnSubmitBTN() {
    //    String expected = "Nejlepší kodéři";
    //    editTeamPage.setTeamName(expected);
    //    editTeamPage.clickOnSubmitBTN();
    //    Team_Page a = new Team_Page();
    //    String actual = a.getTeamName();
    //    MyAlert.getAlert().closeAlert();
    //    Check.checkText(expected,actual, Const.BASE_TITLE_ID);
    //}

    @Test
    public void setCredit1DT() {
        editPage.setCredit1DT("31032023");
        editPage.setCredit1DT("");
        System.out.println("a");
    }

    @Test
    public void setCredit2DT() {
        editPage.setCredit2DT("28022024");
    }

    @Test
    public void getCreditDate(){
        System.out.println(editPage.getCredit1Date() + " " + editPage.getCredit2Date());
    }
    @Test
    public void setCreditTest() {
        editPage.setCredit1DT("10062022");
        editPage.setCredit2DT("18122022");
        editPage.clickOnCreditSubmitBTN();
        Check.checkAndCloseAlert(true);
    }

    @Test
    public void getAllDefences() {
        editPage.getAllDefences().forEach(System.out::println);
    }

}