package pstsp.support.services.project;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.Arguments;
import org.junit.jupiter.params.provider.MethodSource;
import pstsp.support.pageobjects.project.Project_Page;
import pstsp.support.test_oracle.storage.ProjectPageStepList;
import pstsp.support.test_utils.Check;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Stream;

@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
class ProjectLeaderActionsTest {

    @Test
    void goToProjectPageAsLeader() {
        Project_Leader_Actions.goToProjectPageAsLeader("leader");
        Check.checkPage(Project_Page.PAGE_ID);
    }

    @ParameterizedTest(name = "{index}: Step: {0} - choice: {1}")
    @MethodSource("streamForMinCritSteps")
    void editMinCritTableParameterTest(String step, int choice) {
        Project_Leader_Actions.editMinCritTblSuccess(step,choice,"motlm","mentor");
    }

    static Stream<Arguments> streamForMinCritSteps() {
        List<String> minCritList = ProjectPageStepList.getInstance().getAllMinimalCriteriaSteps();
        List<Arguments> args = new ArrayList<>();
        for (String step: minCritList) {
            for(int i = 0; i < 4; i++){
                args.add(Arguments.of(step,i));
            }
        }
        return args.stream();
    }

    @ParameterizedTest(name = "{index}: Step: {0} - choice: {1}")
    @MethodSource("streamForProjectStateSteps")
    void editProjectStateTableParameterTest(String step, int choice) {
        Project_Leader_Actions.editProjStateTblSuccess(step,choice,"motlm","mentor");
    }

    static Stream<Arguments> streamForProjectStateSteps() {
        List<String> minCritList = ProjectPageStepList.getInstance().getAllProjectStateSteps();
        List<Arguments> args = new ArrayList<>();
        for (String step: minCritList) {
            for(int i = 0; i < 4; i++){
                args.add(Arguments.of(step,i));
            }
        }
        return args.stream();
    }

    @Test
    void editMinCritTblAsLeaderSuccess() {
        Project_Leader_Actions.editMinCritTblSuccess("Testování",2,"motlm","mentor");
    }

    @Test
    void editUsedExpTblAsLeaderSuccess(){
        Project_Leader_Actions.editUsedExpTblSuccess("KIV/PSA","něco",2,"motlm","mentor");
    }

    @Test
    void addUsedExp(){
        Project_Leader_Actions.addUsedExpSuccess("KIV/ZSWI","Plánování vývoje software","motlm");
    }

    @Test
    void editProjStateTblAsLeaderSuccess() {
        Project_Leader_Actions.editProjStateTblSuccess("Závěrečná schůzka s mentorem a zadavatelem",2,"motlm","mentor");
    }

    @Test
    void setProjectUrls(){
        List<String> otherUrls = new ArrayList<>();
        otherUrls.add("PSTSP;https://pstsp.hintik.cz/");
        otherUrls.add("GUTHIB;https://guthib.com/");
        otherUrls.add("PPPPP;https://pstsp.hintik.cz/");

        Project_Leader_Actions.setProjectUrls("https://github.com/","","https://pstsp.hintik.cz/", otherUrls, "motlm");
    }

}