package pstsp.support.services.team;

import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.Arguments;
import org.junit.jupiter.params.provider.MethodSource;
import pstsp.support.pageobjects.team.Team_Page_Meeting_Modal;
import pstsp.support.test_oracle.storage.ProjectPageStepList;
import pstsp.support.test_utils.TestEvaluation;
import pstsp.support.test_utils.TestSetting;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Stream;

@ExtendWith(TestSetting.class)
@ExtendWith(TestEvaluation.class)
public class TeamActionsTest {

    @Test
    void succesChangeName() {
        String expected = "Nejlepší kodéři";
        Team_Actions.editTeamNameAsLeaderSuccess(expected, "leader");
    }

    @Test
    void succesChangeTeamMembers() {
        Set<String> expected = new HashSet<>();
        expected.add("Jan CHODORA (A19B0066P)");
        expected.add("Václav HRABÍK (A19B0061P)");
        expected.add("Pavel ČÁCHA (A19B0022P)");
        expected.add("Michaela BENEŠOVÁ (A19B0008P)");
        expected.add("David BUBIK (A19B0015P)");
        Team_Actions.editTeamMembersAsLeaderSuccess(expected, "leader");
    }

    @Test
    void setComplete() {
        Team_Actions.setTeamCompleteAsLeaderSuccess("leader");
    }

    @Test
    void setInComplete() {
        Team_Actions.setTeamInCompleteAsLeaderSuccess("leader");
    }
    @Test
    void setTeamMemberRole() {
        String student = "Pan Vedoucí (AxxBxxxxP)";
        Set<String> expectedRoles = new HashSet<>();
        Team_Actions.setTeamMemberRoleAsLeaderSuccess(student,expectedRoles,"leader");
    }
    @Test
    void setTeamProfile() {
        Set<String> expectedProfile = new HashSet<>();
        expectedProfile.add("PHP");
        expectedProfile.add("Frontend");
        expectedProfile.add("JavaScript");
        expectedProfile.add("Backend");
        Team_Actions.setTeamProfileAsLeaderSuccess(expectedProfile,"leader");
    }

    @Test
    void meetingTest() {
        Team_Actions.addMeetingAsLeaderSuccess("26.4.2022 13:51","CrossCafé","Oslava obhájení projektu",
                Team_Page_Meeting_Modal.SELECT_OPTION_INTERN,"leader", "mentor");
    }

    @Test
    void meetingMentorTest() {
        Team_Actions.addMeetingAsMentorSuccess("28.4.2022 13:51","Studovna FAV","Průběžná schůzka týmu s mentorem",
                Team_Page_Meeting_Modal.SELECT_OPTION_MENTOR,"Tři skvělí programátoři", "mentor");
    }

    @Test
    void meetingCheckMentorTest() {
        Team_Actions.addMeetingAsLeaderSuccess("31.3.2022 13:51","CrossCafé","Team building",
                Team_Page_Meeting_Modal.SELECT_OPTION_MENTOR,"motlm", "mentor");
    }

    @Test
    void deleteInterrest() {
        Team_Actions.deleteTopicInterrestAsLeaderSuccess("Administrativní klient pro systém SensLog","Velmi nízký","stricz", "mentor");
    }

    @Test
    void editMeetingDescription() {
        Team_Actions.editMeetingTopicDescriptionAsLeaderSuccess("25.4.2022 13:51","Schůzka byla OK","leader");
    }

    @Test
    void editMeetingDescriptionAsMentor() {
        Team_Actions.editMeetingTopicDescriptionAsMentorSuccess("28.4.2022 13:51","Schůzka byla OK","Tři skvělí programátoři", "mentor");
    }

    @Test
    void testCheck() {
        Team_Actions.goToTeamPageAsLeader("stricz");
        Team_Check.checkDeletedTopicInterrest( "Administrativní klient pro systém SensLog","Čtyři stateční","Velmi nízký","mentor");
    }

}
