package pstsp.support.test_oracle;

import org.junit.jupiter.api.*;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.Arguments;
import org.junit.jupiter.params.provider.MethodSource;
import pstsp.support.basic.Configurations;
import pstsp.support.test_oracle.storage.ProjectPageStepList;
import pstsp.support.test_oracle.storage.UsersSet;
import pstsp.support.tools.Drivers;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Stream;

import static org.junit.jupiter.api.Assertions.*;

public class ReadProjectPageStepsTest {
    @BeforeEach
    void setUp() {
        Configurations.getInstance().setConfiguration();
    }

    @AfterAll
    static void tearDownAfterAll() {
        Drivers.quitWebDriver();
    }

    @Test
    @DisplayName("read minimalCriteriaStep file")
    void readMinCritFile() {
        assertDoesNotThrow(() -> ProjectPageStepList.getInstance().readMinimalCriteriaSteps());
    }

    @Test
    @DisplayName("read projectStateStep file")
    void readProjStateFile() {
        assertDoesNotThrow(() -> ProjectPageStepList.getInstance().getAllProjectStateSteps());
    }

    @Test
    @DisplayName("number of minCritSteps")
    void numberOfMinCritSteps() {
        int expected = 6;
        int actual = ProjectPageStepList.getInstance().getAllMinimalCriteriaSteps().size();
        assertEquals(expected, actual, "wrong number of minCritSteps");
    }

    @Test
    @DisplayName("number of projectStateSteps")
    void numberOfProjStateSteps() {
        int expected = 11;
        int actual = ProjectPageStepList.getInstance().getAllProjectStateSteps().size();
        assertEquals(expected, actual, "wrong number of projStateSteps");
    }

    @Test
    @Tag("ERROR")
    // prejmenovat MINIMAL_CRITERIA_STEPS_FILE_NAME v OracleInicialization
    @DisplayName("empty list - minimal_criteria_steps-error1.txt")
    void emptyMinCritList() {
        assertThrows(IllegalArgumentException.class, () -> ProjectPageStepList.getInstance().readMinimalCriteriaSteps());
    }

    @Test
    @Tag("ERROR")
    // prejmenovat PROJECT_STATE_STEPS_FILE_NAME v OracleInicialization
    @DisplayName("empty list - project_state_steps-error1.txt")
    void emptyProjStateList() {
        assertThrows(IllegalArgumentException.class, () -> ProjectPageStepList.getInstance().readProjectStateSteps());
    }



}
