package pstsp.support.test_oracle;

import org.junit.jupiter.api.*;
import pstsp.support.basic.Configurations;
import pstsp.support.test_oracle.storage.UsersSet;
import pstsp.support.tools.Drivers;

import static org.junit.jupiter.api.Assertions.*;

public class ReadUsersTest {
  @BeforeEach
  void setUp() {
    Configurations.getInstance().setConfiguration();
  }

  @AfterAll
  static void tearDownAfterAll() {
    Drivers.quitWebDriver();
  }

  @Test
  @DisplayName("read user file")
  void readUserFile() {
    assertDoesNotThrow(() -> UsersSet.getInstance().readUsers());
  }

  @Test
  @DisplayName("number of users")
  void numberOfUsers() {
    int expexted = 2;
    int actual = UsersSet.getInstance().getAllUsers().size();
    assertEquals(expexted, actual, "wrong number of users");
  }

  @Test
  @Tag("ERROR")
  // prejmenovat USERS_FILE_NAME v OracleInicialization
  @DisplayName("empty list - users_list-error1.txt")
  void emptyList() {
    assertThrows(IllegalArgumentException.class, () -> UsersSet.getInstance().readUsers());
  }

  @Test
  @Tag("ERROR")
  // prejmenovat USERS_FILE_NAME v OracleInicialization
  @DisplayName("missing part of data - users_list-error2.txt")
  void missingPart() {
    assertThrows(IllegalArgumentException.class, () -> UsersSet.getInstance().readUsers());
  }

  @Test
  @Tag("ERROR")
  // prejmenovat USERS_FILE_NAME v OracleInicialization
  @DisplayName("missing part of full name - users_list-error3.txt")
  void missingPartOfFullName() {
    assertThrows(IllegalArgumentException.class, () -> UsersSet.getInstance().readUsers());
  }

  @Test
  @Tag("ERROR")
  // prejmenovat USERS_FILE_NAME v OracleInicialization
  @DisplayName("wrong order - users_list-error4.txt")
  void wrongOrder() {
    String expexted = "Mentor Pan";
    String actual = UsersSet.getInstance().getUserByUsername("mentor").getFullName();
    assertEquals(expexted, actual, "wrong order of parts of a name");
  }
}
