const STYLES = {
    display: {
        none: 'none', table_cell: 'table-cell', table_row: 'table-row'
    }
};


const pSBC = (p, c0, c1, l) => {
    let r, g, b, P, f, t, h, i = parseInt, m = Math.round, a = typeof (c1) == "string";
    if (typeof (p) != "number" || p < -1 || p > 1 || typeof (c0) != "string" || (c0[0] != 'r' && c0[0] != '#') || (c1 && !a)) return null;
    if (!this.pSBCr) this.pSBCr = (d) => {
        let n = d.length, x = {};
        if (n > 9) {
            [r, g, b, a] = d = d.split(","), n = d.length;
            if (n < 3 || n > 4) return null;
            x.r = i(r[3] == "a" ? r.slice(5) : r.slice(4)), x.g = i(g), x.b = i(b), x.a = a ? parseFloat(a) : -1
        } else {
            if (n == 8 || n == 6 || n < 4) return null;
            if (n < 6) d = "#" + d[1] + d[1] + d[2] + d[2] + d[3] + d[3] + (n > 4 ? d[4] + d[4] : "");
            d = i(d.slice(1), 16);
            if (n == 9 || n == 5) x.r = d >> 24 & 255, x.g = d >> 16 & 255, x.b = d >> 8 & 255, x.a = m((d & 255) / 0.255) / 1000; else x.r = d >> 16, x.g = d >> 8 & 255, x.b = d & 255, x.a = -1
        }
        return x
    };
    h = c0.length > 9, h = a ? c1.length > 9 ? true : c1 == "c" ? !h : false : h, f = this.pSBCr(c0), P = p < 0, t = c1 && c1 != "c" ? this.pSBCr(c1) : P ? {
        r: 0, g: 0, b: 0, a: -1
    } : {r: 255, g: 255, b: 255, a: -1}, p = P ? p * -1 : p, P = 1 - p;
    if (!f || !t) return null;
    if (l) r = m(P * f.r + p * t.r), g = m(P * f.g + p * t.g), b = m(P * f.b + p * t.b); else r = m((P * f.r ** 2 + p * t.r ** 2) ** 0.5), g = m((P * f.g ** 2 + p * t.g ** 2) ** 0.5), b = m((P * f.b ** 2 + p * t.b ** 2) ** 0.5);
    a = f.a, t = t.a, f = a >= 0 || t >= 0, a = f ? a < 0 ? t : t < 0 ? a : a * P + t * p : 0;
    if (h) return "rgb" + (f ? "a(" : "(") + r + "," + g + "," + b + (f ? "," + m(a * 1000) / 1000 : "") + ")"; else return "#" + (4294967296 + r * 16777216 + g * 65536 + b * 256 + (f ? m(a * 255) : 0)).toString(16).slice(1, f ? undefined : -2)
}

class TableRenderer {

    constructor(tableDirection) {
        this.tableProcessor = new TableProcessor(tableDirection);
        this.tableDirection = tableDirection;
    }

    collapseAll() {
        const elementList = this.tableProcessor.getElementList();
        for (let element of elementList) {
            if (this.tableProcessor.getElementDepth(element) !== 0) {
                if (this.tableDirection === TableDirection.ROW) {
                    element.style.display = STYLES.display.none;
                } else {
                    element.ths.style.display = STYLES.display.none;
                    for (let td of element.tds) {
                        td.style.display = STYLES.display.none;
                    }

                }
            }
        }
    }

    showElement(element) {
        const parent = this.tableProcessor.findParent(element);
        if (this.tableDirection === TableDirection.ROW) {
            element.style.display = STYLES.display.table_row;
        } else {
            element.ths.style.display = STYLES.display.table_cell;
            for (let td of element.tds) {
                td.style.display = STYLES.display.table_cell;
            }
        }
        if (parent) {
            this.showElement(parent);
        }
    }

    rollDownChildren(element) {
        const children = this.tableProcessor.findChildren(element);

        for (let child of children) {
            if (this.tableDirection === TableDirection.ROW) {
                child.style.display = STYLES.display.table_row
            } else {
                child.ths.style.display = STYLES.display.table_cell;
                for (let td of child.tds) {
                    td.style.display = STYLES.display.table_cell;
                }
            }
        }
    }

    rollUpChildren(element) {
        if (!element) {
            return;
        }
        const children = this.tableProcessor.findChildren(element);
        for (let child of children) {
            this.rollUpChildren(child);
            if (this.tableDirection === TableDirection.ROW) {
                child.style.display = STYLES.display.none;
            } else {
                child.ths.style.display = STYLES.display.none;
                for (let td of child.tds) {
                    td.style.display = STYLES.display.none;
                }
            }
        }
    }

    colorizeTable(startColor) {
        const elementList = this.tableProcessor.getElementList();
        for (let element of elementList) {
            const depth = this.tableProcessor.getElementDepth(element);

            const firstTd = this.tableProcessor.tableDirection == TableDirection.ROW ? element.children[0] : element.ths;
            firstTd.style.backgroundColor = pSBC(0.1 * depth, startColor);
        }
    }
}

const tableRowRenderer = new TableRenderer(TableDirection.ROW);
const tableColumnRenderer = new TableRenderer(TableDirection.COLUMN);

// Default collapse of table
tableRowRenderer.collapseAll();
tableColumnRenderer.collapseAll();

// Set action listener on click
tableRowRenderer.tableProcessor.getElementList().forEach(rowElement => {
    let expanded = false;
    rowElement.addEventListener('click', (e) => {
        if (expanded) {
            tableRowRenderer.rollUpChildren(rowElement);
            expanded = !expanded;
        } else {
            tableRowRenderer.rollDownChildren(rowElement);
            expanded = !expanded;
        }
    });
});

// Set action listener on click
tableColumnRenderer.tableProcessor.getElementList().forEach(columnElement => {
    let expanded = false;
    columnElement.ths.addEventListener('click', (e) => {
        if (expanded) {
            tableColumnRenderer.rollUpChildren(columnElement);
            expanded = !expanded;
        } else {
            tableColumnRenderer.rollDownChildren(columnElement);
            expanded = !expanded;
        }
    });
});

// Colorized all
tableRowRenderer.colorizeTable("#777e85");
tableColumnRenderer.colorizeTable("#5d735d");