const TableDirection = {
    ROW: 0, COLUMN: 1
};

const Attrs = {
    INDEX: "index", DEPTH: "vdepth", FILTER: "filter", FILTER_VALUE: "filter-value"
};

class TableProcessor {

    constructor(tableDirection) {
        this.tableDirection = tableDirection;
    }

    getElementList() {
        let i = 0;
        const elementList = [];
        let tempElementList = [];
        if (this.tableDirection === TableDirection.ROW) {
            tempElementList = document.querySelectorAll(`tr`);
        } else if (this.tableDirection === TableDirection.COLUMN) {
            tempElementList = document.querySelectorAll('th');
        }
        for (let element of tempElementList) {
            if (this.getElementIndex(element) !== -1) {
                if (this.tableDirection === TableDirection.ROW) {
                    elementList.push(element);
                } else {
                    const columnElement = {
                        ths: element, tds: document.querySelectorAll(`table tr > td:nth-child(${i + 1})`)
                    };
                    elementList.push(columnElement);
                }
            }
            i++;
        }
        return elementList;
    }

    findElementByIndex(searchedIndex) {
        const elementList = this.getElementList();
        for (let i = 0; i < elementList.length; i++) {
            let tableElement = elementList[i];
            let index = this.getElementIndex(tableElement);
            if (index === searchedIndex) {
                return tableElement;
            }
        }
        return null;
    }

    findParent(element) {
        let index = this.getElementIndex(element);
        let depth = this.getElementDepth(element);

        let elementList = this.getElementList();
        for (let i = index; i >= 0; i--) {
            const currentElement = elementList[i];
            const currentDepth = this.getElementDepth(currentElement);
            if (depth - 1 === currentDepth) {
                return currentElement;
            }
        }
        return null;
    }

    findSiblings(element) {
        const siblingElementArray = [];
        const parentElement = this.findParent(element);

        const parentIndex = this.getElementIndex(parentElement);
        const parentDepth = this.getElementDepth(parentElement);
        const elementArray = this.getElementList();

        if (parentElement === null) {
            return [];
        }

        for (let i = parentIndex + 1; i < elementArray.length; i++) {
            const currentElement = elementArray[i];
            const currentElementDepth = this.getElementDepth(currentElement);
            if (currentElementDepth === parentDepth) {
                break;
            }
            siblingElementArray.push(currentElement);
        }
        return siblingElementArray;
    }

    findChildren(element) {
        const children = [];

        const parentIndex = this.getElementIndex(element);
        const parentDepth = this.getElementDepth(element);
        const elementArray = this.getElementList();


        for (let i = parentIndex + 1; i < elementArray.length; i++) {
            const child = this.findElementByIndex(i);
            const childrenDepth = this.getElementDepth(child);
            if (parentDepth === childrenDepth - 1) {
                children.push(child);
            } else if (parentDepth === childrenDepth) {
                break;
            }
        }
        return children;
    }

    getElementIndex(element) {
        if (element === null) {
            return -1;
        }
        if (this.tableDirection === TableDirection.ROW) {
            return parseInt(element.getAttribute(Attrs.INDEX) ? element.getAttribute(Attrs.INDEX) : -1);
        } else if (element.hasOwnProperty("ths") && element.hasOwnProperty("tds")) {
            return parseInt(element.ths.getAttribute(Attrs.INDEX) ? element.ths.getAttribute(Attrs.INDEX) : -1);
        } else {
            return parseInt(element.getAttribute(Attrs.INDEX) ? element.getAttribute(Attrs.INDEX) : -1);
        }
        return -1;
    }

    getElementDepth(element) {
        if (element === null) {
            return -1;
        }
        if (this.tableDirection === TableDirection.ROW) {
            return parseInt(element.getAttribute(Attrs.DEPTH) ? element.getAttribute(Attrs.DEPTH) : -1);
        } else if (element.hasOwnProperty("ths") && element.hasOwnProperty("tds")) {
            if (element.hasOwnProperty("ths") && element.hasOwnProperty("tds")) {
                return parseInt(element.ths.getAttribute(Attrs.DEPTH) ? element.ths.getAttribute(Attrs.DEPTH) : -1);
            }
        } else {
            return parseInt(element.getAttribute(Attrs.DEPTH) ? element.getAttribute(Attrs.DEPTH) : -1);
        }
    }
}